@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -24,7 +24,15 @@ extern "C" {
 
 #include "med_versioned_proto.h"
 #include "med_versioned_hdfi.h"
+
+#if ! defined(MED_HAVE_FORTRAN)
+#error "There must be a configuration error, fortran should be either enabled or diasabled, hence MED_HAVE_FORTRAN  macro must be defined."
+#error "Verify that you include med_versioned.h after med_config.h, thanks."
+#endif
+
+#if MED_HAVE_FORTRAN == 1
 #include "med_versioned_cfi.h"
+#endif
 
 #ifdef __cplusplus
 }
