@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -19,13 +19,13 @@
 #ifndef MEDC_WIN_DLL_H
 #define MEDC_WIN_DLL_H
 
-#ifdef WIN32
-# ifdef MEDC_DLL_EXPORTS
+#if !defined(MED3_USESTATIC) && defined(PPRO_NT)
+# ifdef medC_EXPORTS
 #  define MEDC_EXPORT __declspec( dllexport )
 # else
 #  define MEDC_EXPORT __declspec( dllimport )
 # endif
-#else
+# else
 # define MEDC_EXPORT
 #endif
 
