@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -174,9 +174,9 @@ med_err _MEDfichierNo(med_idt id, unsigned long * fileno);
 /* Filtres */
 extern MEDC_EXPORT
 med_err _MEDfilterEntityFullIGlobalCr(const med_idt          fid,
-				const med_int          nbofentity,
-				const med_int          nbofvaluesperentity,
-				const med_int          nbofconstituentpervalue,
+				const med_int          nentity,
+				const med_int          nvaluesperentity,
+				const med_int          nconstituentpervalue,
 				const med_int          constituentselect,
 				const med_storage_mode storagemode,
 				const char * const     profilename,
@@ -185,9 +185,9 @@ med_err _MEDfilterEntityFullIGlobalCr(const med_idt          fid,
 				med_filter*    const filter);
 extern MEDC_EXPORT
 med_err _MEDfilterEntityFullICompactCr(const med_idt          fid,
-				       const med_int          nbofentity,
-				       const med_int          nbofvaluesperentity,
-				       const med_int          nbofconstituentpervalue,
+				       const med_int          nentity,
+				       const med_int          nvaluesperentity,
+				       const med_int          nconstituentpervalue,
 				       const med_int          constituentselect,
 				       const med_storage_mode storagemode,
 				       const char * const     profilename,
@@ -196,9 +196,9 @@ med_err _MEDfilterEntityFullICompactCr(const med_idt          fid,
 				       med_filter*    const   filter);
 extern MEDC_EXPORT
 med_err _MEDfilterEntityNoIGlobalCr(const med_idt          fid,
-				    const med_int          nbofentity,
-				    const med_int          nbofvaluesperentity,
-				    const med_int          nbofconstituentpervalue,
+				    const med_int          nentity,
+				    const med_int          nvaluesperentity,
+				    const med_int          nconstituentpervalue,
 				     const med_int          constituentselect,
 				    const med_storage_mode storagemode,
 				    const char * const     profilename,
@@ -208,9 +208,9 @@ med_err _MEDfilterEntityNoIGlobalCr(const med_idt          fid,
 
 extern MEDC_EXPORT
 med_err _MEDfilterEntityNoICompactCr(const med_idt          fid,
-				     const med_int          nbofentity,
-				     const med_int          nbofvaluesperentity,
-				     const med_int          nbofconstituentpervalue,
+				     const med_int          nentity,
+				     const med_int          nvaluesperentity,
+				     const med_int          nconstituentpervalue,
 				     const med_int          constituentselect,
 				     const med_storage_mode storagemode,
 				     const char * const     profilename,
@@ -220,34 +220,34 @@ med_err _MEDfilterEntityNoICompactCr(const med_idt          fid,
 
 /* extern MEDC_EXPORT */
 /* med_err _MEDselectAllEntities(const med_idt          fid, */
-/* 			      const med_int          nbofentity, */
-/* 			      const med_int          nbofvaluesperentity, */
-/* 			      const med_int          nbofconstituentpervalue, */
+/* 			      const med_int          nentity, */
+/* 			      const med_int          nvaluesperentity, */
+/* 			      const med_int          nconstituentpervalue, */
 /* 			      const med_int          constituentselect, */
 /* 			      med_filter*    const   filter); */
 
 
 extern MEDC_EXPORT
 med_err _MEDselectAllEntitiesFullI(const med_idt          fid,
-				   const med_int          nbofentity,
-				   const med_int          nbofvaluesperentity,
-				   const med_int          nbofconstituentpervalue,
+				   const med_int          nentity,
+				   const med_int          nvaluesperentity,
+				   const med_int          nconstituentpervalue,
 				   const med_int          constituentselect,
 				   med_filter*    const   filter);
 
 extern MEDC_EXPORT
 med_err _MEDselectAllEntitiesNoI(const med_idt          fid,
-				 const med_int          nbofentity,
-				 const med_int          nbofvaluesperentity,
-				 const med_int          nbofconstituentpervalue,
+				 const med_int          nentity,
+				 const med_int          nvaluesperentity,
+				 const med_int          nconstituentpervalue,
 				 const med_int          constituentselect,
 				 med_filter*    const   filter);
 
 extern MEDC_EXPORT
 med_err _MEDfilterBlockOfEntityFullICompactCr(const med_idt          fid,
-					      const med_int          nbofentity,
-					      const med_int          nbofvaluesperentity,
-					      const med_int          nbofconstituentpervalue,
+					      const med_int          nentity,
+					      const med_int          nvaluesperentity,
+					      const med_int          nconstituentpervalue,
 					      const med_int          constituentselect,
 					      const med_storage_mode storagemode,
 					      const char * const     profilename,
@@ -260,9 +260,9 @@ med_err _MEDfilterBlockOfEntityFullICompactCr(const med_idt          fid,
 
 extern MEDC_EXPORT
 med_err _MEDfilterBlockOfEntityFullIGlobalCr(const med_idt          fid,
-					      const med_int          nbofentity,
-					      const med_int          nbofvaluesperentity,
-					      const med_int          nbofconstituentpervalue,
+					      const med_int          nentity,
+					      const med_int          nvaluesperentity,
+					      const med_int          nconstituentpervalue,
 					      const med_int          constituentselect,
 					      const med_storage_mode storagemode,
 					      const char * const     profilename,
@@ -274,9 +274,9 @@ med_err _MEDfilterBlockOfEntityFullIGlobalCr(const med_idt          fid,
 					      med_filter*    const   filter);
 extern MEDC_EXPORT
 med_err _MEDfilterBlockOfEntityNoIGlobalCr(const med_idt          fid,
-					      const med_int          nbofentity,
-					      const med_int          nbofvaluesperentity,
-					      const med_int          nbofconstituentpervalue,
+					      const med_int          nentity,
+					      const med_int          nvaluesperentity,
+					      const med_int          nconstituentpervalue,
 					      const med_int          constituentselect,
 					      const med_storage_mode storagemode,
 					      const char * const     profilename,
@@ -288,9 +288,9 @@ med_err _MEDfilterBlockOfEntityNoIGlobalCr(const med_idt          fid,
 					      med_filter*    const   filter);
 extern MEDC_EXPORT
 med_err _MEDfilterBlockOfEntityNoICompactCr(const med_idt          fid,
-					      const med_int          nbofentity,
-					      const med_int          nbofvaluesperentity,
-					      const med_int          nbofconstituentpervalue,
+					      const med_int          nentity,
+					      const med_int          nvaluesperentity,
+					      const med_int          nconstituentpervalue,
 					      const med_int          constituentselect,
 					      const med_storage_mode storagemode,
 					      const char * const     profilename,
