@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -25,7 +25,7 @@
 extern "C" {
 #endif
 
-/* type fonction MED pour le versionement des APIs */
+/* Type fonction MED pour le versionement des APIs */
 typedef void (*MedFuncType)(int,...) ;
 
 extern MEDC_EXPORT
@@ -34,10 +34,20 @@ MedFuncType    _MEDversionedApi3(const char * const name, const med_int majeur,
 
 extern MEDC_EXPORT
 med_access_mode _MEDmodeAcces (med_idt oid);
+extern MEDC_EXPORT
+med_err         _MEDsetModeAcces(med_idt fid, med_access_mode mode);
 
 extern MEDC_EXPORT
-med_err _MEDsetModeAcces(med_idt fid, med_access_mode mode);
+med_err           _MEDfileVersionSetCache(const med_idt oid,const med_file_version v);
+extern MEDC_EXPORT
+med_file_version  _MEDfileVersion(const med_idt oid);
 
+extern MEDC_EXPORT
+med_bool _MEDfieldChecked(const med_idt oid,const char * const fieldname);
+extern MEDC_EXPORT
+med_err _MEDfieldCheckedSetCache(const med_idt      oid,
+				 const char * const fieldname,
+				 const med_bool         ischecked);
 
 /* CHAINES DE CARACTERES FORTRAN => C */
 extern MEDC_EXPORT
@@ -72,8 +82,8 @@ _MEDgetDatasetParameter(const med_data_type         meddatatype,
 			const med_entity_type       entitytype,
 			const med_geometry_type     geotype,
 			const med_connectivity_mode cmode,
-			med_int * const             nbofvalueperentity,
-			med_int * const             nbofconstituentpervalue);
+			med_int * const             nvalueperentity,
+			med_int * const             nconstituentpervalue);
 
 extern MEDC_EXPORT med_err
 _MEDgetDatatype(med_internal_type  * const datatype,
@@ -92,17 +102,27 @@ _MEDgetGeometricParameter(const med_entity_type       entitytype,
 			  med_int * const             nndes);
 
 extern MEDC_EXPORT med_err
-_MEDgetGeometryTypeName(char * const geotypename,med_geometry_type geotype);
+_MEDgetDynGeometricParameter(const med_idt fid,
+			     const med_entity_type       entitytype,
+			     const med_geometry_type     geotype,
+			     med_int * const             entdim,
+			     med_int * const             nnodes,
+			     med_int * const             ncells);
 
+extern MEDC_EXPORT med_err
+_MEDgetInternalGeometryTypeName(char * const geotypename,med_geometry_type geotype);
+
+extern MEDC_EXPORT med_err
+_MEDgetExternalGeometryTypeName(char * const geotypename,med_geometry_type geotype);
 
 extern MEDC_EXPORT med_err
 _MEDmeshtypeCompatibility(const med_data_type meddatatype,
 			  const med_mesh_type meshtype );
 
 extern MEDC_EXPORT med_err
-_MEDsetFilter(const med_int nbofspaces, const med_idt* const memspace,
-	      const med_idt *const diskspace, const med_int nbofentity,
-	      const med_int nbofvaluesperentity, const med_int nbofconstituentpervalue,
+_MEDsetFilter(const med_int nspaces, const med_idt* const memspace,
+	      const med_idt *const diskspace, const med_int nentity,
+	      const med_int nvaluesperentity, const med_int nconstituentpervalue,
 	      const med_int constituentselect, const med_switch_mode switchmode,
 	      const med_int filterarraysize, const med_int profilearraysize, const med_storage_mode storagemode,
 	      const char* const profilename, med_filter* const filter);
@@ -115,7 +135,15 @@ extern MEDC_EXPORT med_err
 MEDversionLire(med_idt fid, med_int *majeur, med_int *mineur, med_int *release);
 
 extern MEDC_EXPORT
-med_geometry_type MEDgetGeometricTypeFromName(const char * const keycharpart);
+med_geometry_type MEDgetGeometryTypeFromName(const char * const keycharpart);
+
+extern MEDC_EXPORT
+med_err _MEDgetSupportMeshNbOfEntities(med_idt                   fid,
+				       const char * const        smeshname,
+				       med_entity_type * const   smeshentitype,
+				       med_geometry_type * const smeshgeotype,
+				       char * const              smeshgeotypename,
+				       med_int * const           smeshnentity);
 
 /* Gestion des messages d'erreur */
 /* extern MEDC_EXPORT */
