@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -32,8 +32,8 @@
 #define nedffamc231 F77_FUNC(edffamc231,EDFFAMC231)
 #define nedffamc232 F77_FUNC(edffamc232,EDFFAMC232)
 
-void MEDC_EXPORT nedffamc231(int foo,...);
-void MEDC_EXPORT nedffamc232(int foo,...);
+void nedffamc231(int foo,...);
+void nedffamc232(int foo,...);
 
 
 #endif
