@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -18,13 +18,18 @@
 #include <med.h>
 #include <med_config.h>
 #include <stdlib.h>
+
+#ifdef PPRO_NT
+#define F_OK 0
+#else
 #include <unistd.h>
+#endif
 
 #define nedfexit F77_FUNC(edfexit,EDFEXIT)
 
 #ifdef PPRO_NT
-med_int 
-__stdcall EDFEXIT(med_int *ret )
+med_int
+ EDFEXIT(med_int *ret )
 #else
 med_int
 nedfexit(med_int *ret)
