@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -87,7 +87,7 @@ From Fortran call of following C functions :
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFCRE(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFCRE(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *ftype, med_int *ncomp, char *cname, unsigned int bidon2, med_int *cnamelen,
 		  char *cuname, unsigned int bidon3, med_int *cunamelen,
 		  char *dtunit, unsigned int bidon4, med_int *dtunitlen,
@@ -143,7 +143,7 @@ nmfdfcre(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFRVW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFRVW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt,
 		  med_int *etype, med_int *gtype, med_int *swm,
 		  med_int *cs, med_int *n, med_float *val)
@@ -188,7 +188,7 @@ nmfdfrvw(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFIVW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFIVW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt,
 		  med_int *etype, med_int *gtype, med_int *swm,
 		  med_int *cs, med_int *n, med_int *val)
@@ -232,19 +232,19 @@ nmfdfivw(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFRPW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFRPW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt,
 		  med_int *etype, med_int *gtype, 
 		  med_int *stm, char *pname, unsigned int bidon2, med_int *pnamelen,  
-		  char *lname, unsigned int bidon3, med_int *lnamelen, 
+		  char *lname, unsigned int bidon3, med_int *lnamelen,
 		  med_int *swm,med_int *cs, med_int *n, med_float *val)
 #else
 med_int
 nmfdfrpw(med_int *fid, char *fname, med_int *fnamelen,
 	 med_int *numdt, med_int *numit, med_float *dt,
-	 med_int *etype, med_int *gtype, 
-	 med_int *stm, char *pname, med_int *pnamelen,  
-	 char *lname, med_int *lnamelen, 
+	 med_int *etype, med_int *gtype,
+	 med_int *stm, char *pname, med_int *pnamelen,
+	 char *lname, med_int *lnamelen,
 	 med_int *swm,med_int *cs, med_int *n, med_float *val)
 #endif
 {
@@ -267,13 +267,13 @@ nmfdfrpw(med_int *fid, char *fname, med_int *fnamelen,
   if (!_fn3)
     return(-1);
 
-  _ret = (med_int)  MEDfieldValueWithProfileWr((const med_idt) *fid, 
-					       _fn1, 
+  _ret = (med_int)  MEDfieldValueWithProfileWr((const med_idt) *fid,
+					       _fn1,
 					       (med_int) *numdt,
-					       (med_int) *numit, 
+					       (med_int) *numit,
 					       (med_float) *dt,
-					       _etype, 
-					       _gtype, 
+					       _etype,
+					       _gtype,
 					       _stm,
 					       _fn2,
 					       _fn3,
@@ -293,7 +293,7 @@ nmfdfrpw(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFIPW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFIPW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt,
 		  med_int *etype, med_int *gtype, 
 		  med_int *stm, char *pname, unsigned int bidon2, med_int *pnamelen,  
@@ -354,7 +354,7 @@ nmfdfipw(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFRAW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFRAW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt,
 		  med_int *etype, med_int *gtype,
 		  char *lname, unsigned int bidon2, med_int *lnamelen, 
@@ -405,7 +405,7 @@ nmfdfraw(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFIAW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFIAW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt,
 		  med_int *etype, med_int *gtype,
 		  char *lname, unsigned int bidon2, med_int *lnamelen, 
@@ -456,7 +456,7 @@ nmfdfiaw(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFNFD(med_int *fid)
+MFDFNFD(med_int *fid)
 #else
 med_int 
 nmfdfnfd(med_int *fid)
@@ -472,7 +472,7 @@ nmfdfnfd(med_int *fid)
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFNFC(med_int *fid, med_int *ind)
+MFDFNFC(med_int *fid, med_int *ind)
 #else
 med_int 
 nmfdfnfc(med_int *fid, med_int *ind)
@@ -489,7 +489,7 @@ nmfdfnfc(med_int *fid, med_int *ind)
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFNCN(med_int *fid,  
+MFDFNCN(med_int *fid,  
 		  char* fname, unsigned int bidon1, med_int *fnamelen)
 #else
 med_int 
@@ -516,7 +516,7 @@ nmfdfncn(med_int *fid,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFFDI(med_int *fid, med_int *it, char *fname, unsigned int bidon1, 
+MFDFFDI(med_int *fid, med_int *it, char *fname, unsigned int bidon1, 
 		  char*mname, unsigned int bidon2,
 		  med_int *localmesh, med_int *type,
 		  char *cname, unsigned int bidon3, 
@@ -579,7 +579,7 @@ nmfdffdi(med_int *fid, med_int *it, char *fname,char *mname,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFFIN(med_int *fid, char *fname, unsigned int bidon1,med_int *fnamelen,
+MFDFFIN(med_int *fid, char *fname, unsigned int bidon1,med_int *fnamelen,
 		  char*mname, unsigned int bidon2,
 		  med_int *localmesh, med_int *type,
 		  char *cname, unsigned int bidon3, 
@@ -648,7 +648,7 @@ nmfdffin(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFCSI(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
+MFDFCSI(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *it, med_int *numdt, med_int *numit, med_float *dt)
 #else
 med_int
@@ -678,7 +678,7 @@ nmfdfcsi(med_int *fid, char* fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFCMI(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
+MFDFCMI(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *it, med_int *numdt, med_int *numit, med_float *dt, med_int *meshnumdt, med_int *meshnumit)
 #else
 med_int
@@ -710,7 +710,7 @@ nmfdfcmi(med_int *fid, char* fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFCMW(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
+MFDFCMW(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_int *meshnumdt, med_int *meshnumit)
 #else
 med_int
@@ -742,7 +742,7 @@ nmfdfcmw(med_int *fid, char* fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFNPF(med_int *fid, char*fname, unsigned int bidon1, med_int *fnamelen,
+MFDFNPF(med_int *fid, char*fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_int *etype, med_int *gtype,
 		  char *dpname, unsigned int bidon2, char *dlname, unsigned int bidon3)
 #else
@@ -783,7 +783,7 @@ nmfdfnpf(med_int *fid, char*fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFNVA(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFNVA(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_int *etype, med_int *gtype)
 #else
 med_int 
@@ -815,7 +815,7 @@ nmfdfnva(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFNVP(med_int *fid, char*fname, unsigned int bidon1, med_int *fnamelen,
+MFDFNVP(med_int *fid, char*fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_int *etype, med_int *gtype,
 		  med_int *pit, med_int *stm, char *pname, unsigned int bidon2, 
 		  med_int *psize, char *lname, unsigned int bidon3, med_int *nip)
@@ -863,7 +863,7 @@ nmfdfnvp(med_int *fid, char*fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFNPN(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
+MFDFNPN(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_int *etype, med_int *gtype,
 		  char *pname, unsigned int bidon2, med_int *pnamelen, med_int *stm, 
 		  med_int *psize, char *lname, unsigned int bidon3, med_int *nip)
@@ -914,7 +914,7 @@ nmfdfnpn(med_int *fid, char* fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFRVR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFRVR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, 
 		  med_int *etype, med_int *gtype, med_int *swm,
 		  med_int *cs, med_float *val)
@@ -957,7 +957,7 @@ nmfdfrvr(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFIVR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFIVR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit,
 		  med_int *etype, med_int *gtype, med_int *swm,
 		  med_int *cs, med_int *val)
@@ -999,7 +999,7 @@ nmfdfivr(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFRPR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFRPR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit,
 		  med_int *etype, med_int *gtype, 
 		  med_int *stm, char *pname, unsigned int bidon2, med_int *pnamelen,  
@@ -1050,7 +1050,7 @@ nmfdfrpr(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFIPR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFIPR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit,
 		  med_int *etype, med_int *gtype, 
 		  med_int *stm, char *pname, unsigned int bidon2, med_int *pnamelen,  
@@ -1101,7 +1101,7 @@ nmfdfipr(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFRAR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFRAR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit,
 		  med_int *etype, med_int *gtype,
 		  unsigned char **flt, med_float *val)
@@ -1141,7 +1141,7 @@ nmfdfrar(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFIAR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFIAR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit,
 		  med_int *etype, med_int *gtype,
 		  unsigned char **flt, med_int *val)
@@ -1182,7 +1182,7 @@ nmfdfiar(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFINW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFINW(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  char *iname, unsigned int bidon2, med_int *inamelen)
 #else
 med_int
@@ -1216,7 +1216,7 @@ nmfdfinw(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFNIN(med_int *fid, 
+MFDFNIN(med_int *fid, 
 		  char *fname, unsigned int bidon1, med_int *fnamelen)
 #else
 med_int 
@@ -1241,7 +1241,7 @@ nmfdfnin(med_int *fid,char *fname, med_int *fnamelen)
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFINI(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFINI(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *it, char *iname, unsigned int bidon2)
 #else
 med_int
@@ -1271,7 +1271,7 @@ nmfdfini(med_int *fid, char *fname, med_int *fnamelen, med_int *it, char *iname)
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFOCI(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
+MFDFOCI(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *it, med_int *numdt, med_int *numit, med_float *dt,
 		  med_int *nmesh, char *mname, unsigned int bidon2, med_int *lmesh,
 		  med_int *mnumdt, med_int *mnumit)
@@ -1315,7 +1315,7 @@ nmfdfoci(med_int *fid, char* fname,med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFONP(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
+MFDFONP(med_int *fid, char* fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_int *etype, med_int *gtype,
 		  med_int *it, char *mname, unsigned int bidon2,
 		  char *dpname, unsigned int bidon3, char *dlname, unsigned int bidon4)
@@ -1363,7 +1363,7 @@ nmfdfonp(med_int *fid, char*fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MFDFONV(med_int *fid, char*fname, unsigned int bidon1, med_int *fnamelen,
+MFDFONV(med_int *fid, char*fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit, med_int *etype, med_int *gtype,
 		  char* mname,  unsigned int bidon2, med_int *mnamelen,
 		  med_int *pit, med_int *stm, char *pname, unsigned int bidon3, 
@@ -1420,7 +1420,7 @@ nmfdfonv(med_int *fid, char*fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFORR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFORR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit,
 		  med_int *etype, med_int *gtype,
 		  char *mname, unsigned int bidon2, med_int *mnamelen,
@@ -1479,11 +1479,11 @@ nmfdforr(med_int *fid, char *fname, med_int *fnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MFDFOIR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
+MFDFOIR(med_int *fid, char *fname, unsigned int bidon1, med_int *fnamelen,
 		  med_int *numdt, med_int *numit,
 		  med_int *etype, med_int *gtype, 
 		  char *mname, unsigned int bidon2, med_int *mnamelen,
-		  med_int *stm, char *pname, unsigned int bidon2, med_int *pnamelen,  
+		  med_int *stm, char *pname, unsigned int bidon3, med_int *pnamelen,  
 		  med_int *swm, med_int *cs, med_int *val)
 #else
 med_int
