@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -67,15 +67,18 @@ From Fortran call of following C functions :
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFCRE(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFCRE(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  med_int * mdim,
 		  char *smname, unsigned int bidon2, med_int *smnamelen,
 		  med_int *setype, med_int *sgtype)
 #else
 med_int 
-nmsefcre(med_int *fid, char *mname, med_int *mnamelen, med_int * mdim,
+nmsefcre(med_int *fid, 
+         char *mname, med_int *mnamelen, 
+         med_int * mdim,
 	 char *smname, med_int *smnamelen,
-	 med_int *setype, med_int *sgtype)
+	 med_int *setype, 
+         med_int *sgtype)
 #endif
 {
   med_int _ret;
@@ -108,7 +111,7 @@ nmsefcre(med_int *fid, char *mname, med_int *mnamelen, med_int * mdim,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFNSE(med_int *fid)
+MSEFNSE(med_int *fid)
 #else
 med_int 
 nmsefnse (med_int *fid)
@@ -124,8 +127,8 @@ nmsefnse (med_int *fid)
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFSEI(med_int *fid, med_int *it, 
-		  char *mname, unsigned int bidon1
+MSEFSEI(med_int *fid, med_int *it, 
+		  char *mname, unsigned int bidon1,
 		  med_int *mgtype, med_int * mdim,
 		  char *smname, unsigned int bidon2,
 		  med_int *setype, med_int *snnode, med_int *sncell,
@@ -178,7 +181,7 @@ nmsefsei(med_int *fid, med_int *it,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFSIN(med_int *fid, 
+MSEFSIN(med_int *fid, 
 		  char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *mgtype, med_int * mdim,
 		  char *smname, unsigned int bidon2,
@@ -236,7 +239,7 @@ nmsefsin(med_int *fid,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFSEN(med_int *fid, med_int *mgtype, char *mname, unsigned int bidon)
+MSEFSEN(med_int *fid, med_int *mgtype, char *mname, unsigned int bidon)
 #else
 med_int 
 nmsefsen(med_int *fid, med_int *mgtype, char *mname)
@@ -260,7 +263,7 @@ nmsefsen(med_int *fid, med_int *mgtype, char *mname)
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFSGT(med_int *fid, char *mname, unsigned int bidon,med_int *mnamelen)
+MSEFSGT(med_int *fid, char *mname, unsigned int bidon,med_int *mnamelen)
 #else
 med_int 
 nmsefsgt(med_int *fid, char *mname, med_int *mnamelen)
@@ -285,7 +288,7 @@ nmsefsgt(med_int *fid, char *mname, med_int *mnamelen)
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFVAC(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFVAC(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *atype, med_int *anc)
 #else
@@ -322,7 +325,7 @@ nmsefvac(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFVNI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFVNI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *atype, med_int *anc)
 #else
@@ -361,7 +364,7 @@ nmsefvni(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFVAI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFVAI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  med_int *it, char *aname, unsigned int bidon2,
 		  med_int *atype, med_int *anc)
 #else
@@ -397,7 +400,7 @@ nmsefvai(med_int *fid, char *mname, med_int *mnamelen, med_int *it,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFASZ(med_int *atype)
+MSEFASZ(med_int *atype)
 #else
 med_int 
 nmsefasz(med_int *atype)
@@ -414,7 +417,7 @@ nmsefasz(med_int *atype)
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFRAW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFRAW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *atype, med_int *anc,
 		  med_int *setype, med_float *val)
@@ -456,7 +459,7 @@ nmsefraw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFIAW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFIAW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *atype, med_int *anc,
 		  med_int *setype, med_int *val)
@@ -499,7 +502,7 @@ nmsefiaw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFSAW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFSAW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *atype, med_int *anc, med_int *setype, 
 		  char *val, unsigned int bidon3, med_int *vallen)
@@ -515,6 +518,19 @@ nmsefsaw(med_int *fid, char *mname, med_int *mnamelen,
   char *_fn1, *_fn2,*_fn3;
   med_attribute_type _atype = (med_attribute_type) *atype;
   med_entity_type _setype = (med_entity_type) *setype;
+  int _nentity=0; 
+  med_geometry_type _geotype=0;
+  med_int _modeldim=0;
+  char _supportmeshname[MED_NAME_SIZE+1]="";
+  med_entity_type _entitytype=0;
+  med_int _nnode=0;
+  med_int _ncell=0; 
+  med_geometry_type _sgeotype=0; 
+  med_int _nconstatt=0; 
+  med_bool _anyprofile=0;
+  med_int _nvaratt=0;
+  med_bool _coordinatechangement=MED_FALSE;
+  med_bool _geotransformation=MED_FALSE;
 
   _fn1 = _MED2cstring((char *) mname, (int) *mnamelen);
   if (!_fn1)
@@ -524,10 +540,41 @@ nmsefsaw(med_int *fid, char *mname, med_int *mnamelen,
   if (!_fn2)
     return(-1);
 
-  _fn3 = _MED2cstring((char *) val, (int) *vallen);
+  /* on recupere le nom du maillage support */
+  _ret = MEDstructElementInfoByName((med_idt) *fid,
+				    _fn1,
+				    &_geotype, 
+				    &_modeldim,
+                                    _supportmeshname, 
+				    &_entitytype, 
+				    &_nnode, 
+				    &_ncell,
+                                    &_sgeotype, 
+				    &_nconstatt, 
+				    &_anyprofile, 
+				    &_nvaratt);
+  if (_ret < 0)
+    return (-1);
+  
+  /* on recupere le nombre d'entite dans le maillage support :
+     MED_NODE ou MED_CELL */
+  _nentity = MEDmeshnEntity((med_idt) *fid, 
+			    _supportmeshname, 
+			    MED_NO_DT, 
+			    MED_NO_IT, 
+			    _setype, 
+			    _sgeotype,
+			    MED_COORDINATE, 
+			    MED_NO_CMODE,
+			    &_coordinatechangement,
+			    &_geotransformation);
+  if (_nentity < 0)
+    return (-1); 
+  
+  _fn3 = _MED1cstring((char *) val, (int) *vallen*_nentity, (int) *anc*_nentity*MED_NAME_SIZE);
   if (!_fn3)
     return(-1);
-
+  
   _ret = (med_int) MEDstructElementConstAttWr((const med_idt) *fid, 
 					      _fn1, 
 					      _fn2, 
@@ -540,7 +587,6 @@ nmsefsaw(med_int *fid, char *mname, med_int *mnamelen,
   _MEDcstringFree(_fn2);
   _MEDcstringFree(_fn3);
 
-
   return _ret;
 }
 
@@ -548,7 +594,7 @@ nmsefsaw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFRPW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFRPW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *atype, med_int *anc,
 		  med_int *setype, 
@@ -602,7 +648,7 @@ nmsefrpw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFIPW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFIPW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *atype, med_int *anc,
 		  med_int *setype, 
@@ -655,7 +701,7 @@ nmsefipw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFSPW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFSPW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *atype, med_int *anc, med_int *setype, 
 		  char *pname, unsigned int bidon3, med_int *pnamelen,
@@ -673,6 +719,19 @@ nmsefspw(med_int *fid, char *mname, med_int *mnamelen,
   char *_fn1, *_fn2,*_fn3, *_fn4;
   med_attribute_type _atype = (med_attribute_type) *atype;
   med_entity_type _setype = (med_entity_type) *setype;
+  int _nentity=0; 
+  med_geometry_type _geotype=0;
+  med_int _modeldim=0;
+  char _supportmeshname[MED_NAME_SIZE+1]="";
+  med_entity_type _entitytype=0;
+  med_int _nnode=0;
+  med_int _ncell=0; 
+  med_geometry_type _sgeotype=0; 
+  med_int _nconstatt=0; 
+  med_bool _anyprofile=0;
+  med_int _nvaratt=0;
+  med_bool _coordinatechangement=MED_FALSE;
+  med_bool _geotransformation=MED_FALSE;
 
   _fn1 = _MED2cstring((char *) mname, (int) *mnamelen);
   if (!_fn1)
@@ -686,7 +745,50 @@ nmsefspw(med_int *fid, char *mname, med_int *mnamelen,
   if (!_fn3)
     return(-1);
 
-  _fn4 = _MED2cstring((char *) val, (int) *vallen);
+  /* on recupere le nom du maillage support */
+  _ret = MEDstructElementInfoByName((med_idt) *fid,
+				    _fn1,
+				    &_geotype, 
+				    &_modeldim,
+                                    _supportmeshname, 
+				    &_entitytype, 
+				    &_nnode, 
+				    &_ncell,
+                                    &_sgeotype, 
+				    &_nconstatt, 
+				    &_anyprofile, 
+				    &_nvaratt);
+  if (_ret < 0)
+    return (-1);
+  
+  /* on recupere le nombre d'entite dans le maillage support :
+     MED_NODE ou MED_CELL */
+  if (_setype == MED_NODE)
+    _nentity = MEDmeshnEntity((med_idt) *fid, 
+			      _supportmeshname, 
+			      MED_NO_DT, 
+			      MED_NO_IT, 
+			      _setype, 
+			      _sgeotype,
+			      MED_COORDINATE, 
+			      MED_NO_CMODE,
+			      &_coordinatechangement,
+			      &_geotransformation);
+  else
+    _nentity = MEDmeshnEntity((med_idt) *fid, 
+			      _supportmeshname, 
+			      MED_NO_DT, 
+			      MED_NO_IT, 
+			      _setype, 
+			      _sgeotype,
+			      MED_CONNECTIVITY, 
+			      MED_NODAL,
+			      &_coordinatechangement,
+			      &_geotransformation);
+  if (_nentity < 0)
+    return (-1); 
+  
+  _fn4 = _MED1cstring((char *) val, (int) *vallen*_nentity, (int) *anc*_nentity*MED_NAME_SIZE);
   if (!_fn4)
     return(-1);
 
@@ -711,10 +813,10 @@ nmsefspw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFCNI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFCNI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *atype, med_int *anc,
-		  med_int *setype, char *pname, med_int *psize)
+		  med_int *setype, char *pname, unsigned int bidon3, med_int *psize)
 #else
 med_int 
 nmsefcni(med_int *fid, char *mname, med_int *mnamelen, 
@@ -759,11 +861,11 @@ nmsefcni(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFCAI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFCAI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  med_int *it,
 		  char *aname, unsigned int bidon2,
 		  med_int *atype, med_int *anc,
-		  med_int *setype, char *pname, med_int *psize)
+		  med_int *setype, char *pname, unsigned int bidon3 ,med_int *psize)
 #else
 med_int 
 nmsefcai(med_int *fid, char *mname, med_int *mnamelen, 
@@ -808,7 +910,7 @@ nmsefcai(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFRAR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFRAR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_float *val)
 #else
@@ -843,7 +945,7 @@ nmsefrar(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFIAR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFIAR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *val)
 #else
@@ -879,7 +981,7 @@ nmsefiar(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MSEFSAR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
+MSEFSAR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  char *val, unsigned int bidon3)
 #else
