@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -79,7 +79,8 @@ From Fortran call of following C functions :
 - MEDmeshEntityInfo
 - MEDmeshNodeCoordinateTrsfRd        
 - MEDmeshNodeCoordinateTrsfWr
-
+- MEDmeshEntityAttributeAdvancedWr
+- MEDmeshEntityAttributeAdvancedRd
 */
 
 #define nmmhfcre F77_FUNC(mmhfcre,MMHFCRE) 
@@ -141,12 +142,15 @@ From Fortran call of following C functions :
 #define nmmhfeni F77_FUNC(mmhfeni,MMHFENI)
 #define nmmhftfw F77_FUNC(mmhftfw,MMHFTFW)
 #define nmmhftfr F77_FUNC(mmhftfr,MMHFTFR)
-
+#define nmmhfaaw F77_FUNC(mmhfaaw,MMHFAAW)
+#define nmmhfaar F77_FUNC(mmhfaar,MMHFAAR)
+#define nmmhfasw F77_FUNC(mmhfasw,MMHFASW)
+#define nmmhfasr F77_FUNC(mmhfasr,MMHFASR)
 
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCRE(med_int *fid, char *mname, unsigned int bidon, 
+MMHFCRE(med_int *fid, char *mname, unsigned int bidon, 
                   med_int *mnamelen, med_int * sdim, med_int * mdim, med_int *mtype,
 		  char *desc, unsigned int bidon2, med_int *desclen,
 		  char *dtunit, unsigned int bidon3, med_int *dtunitlen,
@@ -201,7 +205,7 @@ nmmhfcre(med_int *fid, char *mname, med_int *mnamelen, med_int * sdim,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MMHFNMH(med_int *fid)
+MMHFNMH(med_int *fid)
 #else
 med_int
 nmmhfnmh(med_int *fid)
@@ -217,7 +221,7 @@ nmmhfnmh(med_int *fid)
 
 #ifdef PPRO_NT
 med_int
-__stdcall MMHFNAN(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen)
+MMHFNAN(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen)
 #else
 med_int
 nmmhfnan(med_int *fid, char *mname, med_int *mnamelen)
@@ -240,7 +244,7 @@ nmmhfnan(med_int *fid, char *mname, med_int *mnamelen)
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFNAX(med_int *fid, med_int *it)
+MMHFNAX(med_int *fid, med_int *it)
 #else
 med_int 
 nmmhfnax(med_int *fid, med_int *it)
@@ -256,7 +260,7 @@ nmmhfnax(med_int *fid, med_int *it)
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFMHI(med_int *fid, med_int *it, char*mname, unsigned int bidon, 
+MMHFMHI(med_int *fid, med_int *it, char*mname, unsigned int bidon, 
                   med_int * sdim, med_int * mdim, med_int *mtype,
 		  char *desc, unsigned int bidon2,
 		  char *dtunit, unsigned int bidon3, 
@@ -316,13 +320,13 @@ nmmhfmhi(med_int *fid, med_int *it, char *mname, med_int * sdim,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MMHFMIN(med_int *fid, char*mname, unsigned int bidon, med_int *mnamelen
-                  med_int * sdim, med_int * mdim, med_int *mtype,
-		  char *desc, unsigned int bidon2,
-		  char *dtunit, unsigned int bidon3,
-		  med_int *stype, med_int *nstep, med_int *atype,
-		  char *aname, unsigned int bidon4,
-		  char *aunit, unsigned int bidon5)
+MMHFMIN(med_int *fid, char*mname, unsigned int bidon, med_int *mnamelen,
+        med_int * sdim, med_int * mdim, med_int *mtype,
+		char *desc, unsigned int bidon2,
+		char *dtunit, unsigned int bidon3,
+		med_int *stype, med_int *nstep, med_int *atype,
+		char *aname, unsigned int bidon4,
+		char *aunit, unsigned int bidon5)
 #else
 med_int
 nmmhfmin(med_int *fid, char *mname, med_int *mnamelen, med_int * sdim,
@@ -381,7 +385,7 @@ nmmhfmin(med_int *fid, char *mname, med_int *mnamelen, med_int * sdim,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MMHFUNW(med_int *fid, char *uname, unsigned int bidon, med_int *unamelen)
+MMHFUNW(med_int *fid, char *uname, unsigned int bidon, med_int *unamelen)
 #else
 med_int
 nmmhfunw(med_int *fid, char *uname, med_int *unamelen)
@@ -405,8 +409,8 @@ nmmhfunw(med_int *fid, char *uname, med_int *unamelen)
 
 #ifdef PPRO_NT
 med_int
-__stdcall MMHFUNR(med_int *fid, char*mname, unsigned int bidon, med_int *mnamelen,
-		  char *uname, unsigned int bidon)
+MMHFUNR(med_int *fid, char*mname, unsigned int bidon, med_int *mnamelen,
+		  char *uname, unsigned int bidon1)
 #else
 med_int
 nmmhfunr(med_int *fid, char*mname, med_int *mnamelen,
@@ -434,7 +438,7 @@ nmmhfunr(med_int *fid, char*mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int
-__stdcall MMHFATW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFATW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *nin, med_int *nvn, med_int *nnc)
 #else
 med_int
@@ -462,7 +466,7 @@ nmmhfatw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFATR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFATR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *nin, med_int *nvn, med_int *nnc)
 #else
 med_int 
@@ -490,7 +494,7 @@ nmmhfatr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFGTW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFGTW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *gtype)
 #else
 med_int 
@@ -519,7 +523,7 @@ nmmhfgtw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFGTR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFGTR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *gtype)
 #else
 med_int 
@@ -547,7 +551,7 @@ nmmhfgtr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFGSW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFGSW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt, med_int *gstruct)
 #else
 med_int 
@@ -575,7 +579,7 @@ nmmhfgsw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFGSR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFGSR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *gstruct)
 #else
 med_int 
@@ -602,7 +606,7 @@ nmmhfgsr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCOW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFCOW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt, med_int *swm,
 		  med_int *n, med_float *coo)
 #else
@@ -632,7 +636,7 @@ nmmhfcow(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCOR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFCOR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *swm,
 		  med_float *coo)
 #else
@@ -661,7 +665,7 @@ nmmhfcor(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCPW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFCPW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt, 
 		  med_int *smode, char *pname, unsigned int bidon2, med_int *pnamelen,
 		  med_int *swm, med_int *dim, med_int *n, med_float *coo)
@@ -699,7 +703,7 @@ nmmhfcpw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCPR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFCPR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit,  
 		  med_int *smode, char *pname, unsigned int bidon2, med_int *pnamelen,
 		  med_int *swm, med_int *dim, med_float *coo)
@@ -736,7 +740,7 @@ nmmhfcpr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFGCW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFGCW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt, 
 		  med_int *axis, med_int *size, med_float *index)
 #else
@@ -765,7 +769,7 @@ nmmhfgcw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFGCR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFGCR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, 
 		  med_int *axis, med_float *index)
 #else
@@ -794,7 +798,7 @@ nmmhfgcr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFENW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFENW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
 		  med_int *n, med_int *num)
 #else
@@ -830,7 +834,7 @@ nmmhfenw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFENR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFENR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
 		  med_int *num)
 #else
@@ -866,7 +870,7 @@ nmmhfenr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFFNW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFFNW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
 		  med_int *n, med_int *num)
 #else
@@ -898,7 +902,7 @@ nmmhffnw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFFNR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFFNR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
 		  med_int *num)
 #else
@@ -930,7 +934,7 @@ nmmhffnr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFEAW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFEAW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
 		  med_int *n, char *ename, unsigned int bidon2, med_int *enamelen)
 #else
@@ -966,9 +970,9 @@ nmmhfeaw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFEAR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFEAR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
-		  char *ename)
+		  char *ename, unsigned int bidon2)
 #else
 med_int 
 nmmhfear(med_int *fid, char *mname, med_int *mnamelen,
@@ -1017,7 +1021,7 @@ nmmhfear(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFNME(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFNME(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
 		  med_int *datatype, med_int *cmode, med_int *chgt, med_int *tsf) 
 #else
@@ -1057,7 +1061,7 @@ nmmhfnme(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCYW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFCYW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float* dt,
 		  med_int *entype, med_int *geotype, med_int *cmode, 
 		  med_int *swm, med_int *n, med_int *connectivity)
@@ -1100,7 +1104,7 @@ nmmhfcyw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCYR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFCYR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, 
 		  med_int *entype, med_int *geotype, med_int *cmode, 
 		  med_int *swm, med_int *connectivity)
@@ -1140,7 +1144,7 @@ nmmhfcyr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFYPW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFYPW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float* dt,
 		  med_int *entype, med_int *geotype, med_int *cmode,
 		  med_int *stmode, char *pname, unsigned int bidon2,med_int *pnamelen,
@@ -1194,7 +1198,7 @@ nmmhfypw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFYPR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFYPR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, 
 		  med_int *entype, med_int *geotype, med_int *cmode, 
 		  med_int *stmode, char* pname, unsigned int bidon2, med_int *pnamelen,
@@ -1248,10 +1252,10 @@ nmmhfypr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFNEP(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFNEP(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
 		  med_int *datatype, med_int *cmode, 
-		  med_int *stmode, char* pname, med_int *psize,
+		  med_int *stmode, char* pname, unsigned int bidon1, med_int *psize,
 		  med_int *chgt, med_int *tsf) 
 #else
 med_int 
@@ -1306,7 +1310,7 @@ nmmhfnep(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFNOW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFNOW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt, med_int *swm,
 		  med_int *n, med_float *coo,
 		  med_int *iname, char*nname, unsigned int bidon2, med_int *nnamelen,
@@ -1359,9 +1363,9 @@ nmmhfnow(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFNOR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFNOR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *swm,med_float *coo,
-		  med_int *iname, char*nname,
+		  med_int *iname, char*nname, unsigned int bidon,
 		  med_int *inum, med_int *num, med_int *ifam, med_int *fam)
 #else
 med_int 
@@ -1419,7 +1423,7 @@ nmmhfnor(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFELW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFELW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt,  med_int *entype, med_int *geotype,
 		  med_int *cmode, med_int *swm, 
 		  med_int *n, med_int *connectivity,
@@ -1482,11 +1486,11 @@ nmmhfelw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFELR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFELR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
 		  med_int *cmode, med_int *swm, 
 		  med_int *connectivity,
-		  med_int *iname, char*nname,
+		  med_int *iname, char*nname, unsigned int bidon,
 		  med_int *inum, med_int *num, med_int *ifam, med_int *fam)
 #else
 med_int 
@@ -1552,7 +1556,7 @@ nmmhfelr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCAW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFCAW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt,
 		  unsigned char **flt, med_float *coo)
 #else
@@ -1586,7 +1590,7 @@ nmmhfcaw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCAR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFCAR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, unsigned char **flt,
 		  med_float *coo)
 #else
@@ -1620,7 +1624,7 @@ nmmhfcar(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFYAW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFYAW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float* dt,
 		  med_int *entype, med_int *geotype,  med_int *cmode, unsigned char **flt,
 		  med_int *connectivity)
@@ -1662,7 +1666,7 @@ nmmhfyaw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFYAR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFYAR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, 
 		  med_int *entype, med_int *geotype, med_int *cmode, 
 		  unsigned char **flt, med_int *connectivity)
@@ -1704,7 +1708,7 @@ nmmhfyar(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFPGW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFPGW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float* dt,
 		  med_int *entype, med_int *cmode, 
 		  med_int *indexsize, med_int *index, med_int *connectivity)
@@ -1744,7 +1748,7 @@ nmmhfpgw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFPGR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFPGR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, 
 		  med_int *entype, med_int *cmode, 
 		  med_int *index,
@@ -1784,7 +1788,7 @@ nmmhfpgr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFPHW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFPHW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float* dt,
 		  med_int *entype, med_int *cmode, 
 		  med_int *findexsize, med_int *findex,
@@ -1831,7 +1835,7 @@ nmmhfphw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFPHR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFPHR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit,
 		  med_int *entype, med_int *cmode, 
 		  med_int *findex,
@@ -1873,7 +1877,7 @@ nmmhfphr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFGNW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFGNW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
 		  med_int *n, med_int *num)
 #else
@@ -1909,7 +1913,7 @@ nmmhfgnw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFGNR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFGNR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *geotype,
 		  med_int *num)
 #else
@@ -1943,7 +1947,7 @@ nmmhfgnr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCSC(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFCSC(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt1, med_int *numit1, 
 		  med_int *numdt2, med_int *numit2, med_float *dt2)
 #else
@@ -1976,7 +1980,7 @@ nmmhfcsc(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCSI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFCSI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *csit, med_int *numdt, med_int *numit, med_float *dt)
 #else
 med_int 
@@ -2008,7 +2012,7 @@ nmmhfcsi(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFCSR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFCSR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt)
 #else
 med_int 
@@ -2038,7 +2042,7 @@ nmmhfcsr(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFSTR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFSTR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *stype)
 #else
 med_int 
@@ -2067,7 +2071,7 @@ nmmhfstr(med_int *fid, char *mname, med_int *mnamelen,med_int *stype)
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFRAW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFRAW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *geotype, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *n, med_float *val)
@@ -2109,7 +2113,7 @@ nmmhfraw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFIAW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFIAW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *geotype, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *n, med_int *val)
@@ -2151,7 +2155,7 @@ nmmhfiaw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFSAW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFSAW(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *geotype, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *n, char *val, unsigned int bidon3, med_int *vallen)
@@ -2166,6 +2170,9 @@ nmmhfsaw(med_int *fid, char *mname, med_int *mnamelen,
   med_int _ret; 
   char *_fn1, *_fn2, *_fn3;
   med_geometry_type _gtype = (med_geometry_type) *geotype;
+  char _modelname[MED_NAME_SIZE+1]="";
+  med_int _ncomp=0;
+  med_attribute_type _type; 
 
   _fn1 = _MED2cstring((char *) mname, (int) *mnamelen);
   if (!_fn1)
@@ -2175,7 +2182,25 @@ nmmhfsaw(med_int *fid, char *mname, med_int *mnamelen,
   if (!_fn2)
     return(-1);
 
-  _fn3 = _MED2cstring((char *) val, (int) *vallen);
+  /* nom de l'element de structure */
+  _ret = MEDstructElementName((med_idt) *fid, 
+			      _gtype, 
+			      _modelname);
+  if (_ret < 0)
+    return (-1);
+
+  /* nombre de composante de l'attribut */
+  _ret = MEDstructElementVarAttInfoByName((med_idt) *fid,
+					  _modelname,
+					  _fn2,
+					  &_type, 
+					  &_ncomp);
+  if (_ncomp < 0)
+    return (-1);
+
+  _fn3 = _MED1cstring(val, 
+		      (int) *vallen*_ncomp,
+		      (int) *n*_ncomp*MED_NAME_SIZE);
   if (!_fn3)
     return(-1);
 
@@ -2199,7 +2224,7 @@ nmmhfsaw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFRAR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFRAR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *geotype, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_float *val)
@@ -2240,7 +2265,7 @@ nmmhfrar(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFIAR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFIAR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *geotype, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  med_int *val)
@@ -2282,7 +2307,7 @@ nmmhfiar(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFSAR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
+MMHFSAR(med_int *fid, char *mname, unsigned int bidon1, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *geotype, 
 		  char *aname, unsigned int bidon2, med_int *anamelen,
 		  char *val, unsigned int bidon3)
@@ -2299,15 +2324,12 @@ nmmhfsar(med_int *fid, char *mname, med_int *mnamelen,
   char *_fs3;
   med_geometry_type _gtype = (med_geometry_type) *geotype;
   med_attribute_type _atype;
-  med_int _nacomp;
-  med_geometry_type _mgeotype, _gctype;
-  med_geometry_type _sgtype;
-  med_int _mdim, _nnode, _ncell;
-  char _meshname[MED_NAME_SIZE+1]="";
-  med_entity_type _etype;
-  med_int _ncatt, _nvatt;
-  med_bool _ap;
+  med_int _nacomp=0;
   med_int _size=0;
+  med_int _n;
+  med_bool _coordinatechangement=MED_FALSE;
+  med_bool _geotransformation=MED_FALSE;
+  char _modelname[MED_NAME_SIZE+1]="";
 
   _fn1 = _MED2cstring((char *) mname, (int) *mnamelen);
   if (!_fn1)
@@ -2317,32 +2339,40 @@ nmmhfsar(med_int *fid, char *mname, med_int *mnamelen,
   if (!_fn2)
     return(-1);
 
-  if (MEDstructElementInfoByName((med_idt) *fid, 
-				 _fn1, 
-				 &_mgeotype, 
-				 &_mdim,
-                                 _meshname, 
-				 &_etype, 
-				 &_nnode, 
-				 &_ncell,
-                                 &_gctype, 
-				 &_ncatt, 
-				 &_ap, 
-				 &_nvatt)  < 0) 
-    return -1;
+  /* on recupere le nom du modle de structure */
+  _ret = MEDstructElementName((med_idt) *fid, 
+			      _gtype, 
+			      _modelname);   
+  if (_ret < 0)
+    return (-1);
 
+  /* on recupere le nombre de composante de l'attribut */
   if (MEDstructElementVarAttInfoByName((med_idt ) *fid, 
-				       _fn1,  
+				       _modelname,  
 				       _fn2, 
 				       &_atype, 
 				       &_nacomp) < 0) 
     return -1;
 
+ /* On recupere le nombre d'element correspondant
+    au type de modele de structure dans le maillage
+    de calcul 
+  */
+  _n =  MEDmeshnEntity((med_idt) *fid, 
+		       _fn1, 
+		       (med_int) *numdt,
+		       (med_int) *numit, 
+		       MED_STRUCT_ELEMENT,
+		       _gtype,
+		       MED_CONNECTIVITY, 
+		       MED_NODAL,
+		       &_coordinatechangement,
+		       &_geotransformation);
+  if (_n < 0)
+    return -1;
+
   /* memory allocation */
-  if (_etype == MED_NODE)
-    _size = _nnode*_nacomp*MED_NAME_SIZE*sizeof(char);
-  else
-    _size = _ncell*_nacomp*MED_NAME_SIZE*sizeof(char);
+  _size = _n*_nacomp*MED_NAME_SIZE*sizeof(char);
   _fs3 = (char *) malloc(_size+1);
   *_fs3='\0';
   if (!_fs3)
@@ -2369,7 +2399,7 @@ nmmhfsar(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFENI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFENI(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_int *entype, med_int *it, 
 		  char *geoname, unsigned int bidon1, med_int *geotype)
 #else
@@ -2409,7 +2439,7 @@ nmmhfeni(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFTFW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+MMHFTFW(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
 		  med_int *numdt, med_int *numit, med_float *dt, med_float *tsf)
 #else
 med_int 
@@ -2439,8 +2469,8 @@ nmmhftfw(med_int *fid, char *mname, med_int *mnamelen,
 
 #ifdef PPRO_NT
 med_int 
-__stdcall MMHFTFR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
-		  med_int *numit, med_float *dt, med_float *tsf)
+MMHFTFR(med_int *fid, char *mname, unsigned int bidon, med_int *mnamelen,
+		med_int *numdt, med_int *numit, med_float *tsf)
 #else
 med_int 
 nmmhftfr(med_int *fid, char *mname, med_int *mnamelen,
@@ -2464,3 +2494,215 @@ nmmhftfr(med_int *fid, char *mname, med_int *mnamelen,
 
   return(_ret); 
 }
+
+
+
+
+#ifdef PPRO_NT
+med_int 
+MMHFAAW(med_int *fid, 
+		  char *mname, unsigned int bidon, med_int *mnamelen,
+		  med_int *datatype, 
+		  med_int *numdt, 
+		  med_int *numit,
+		  med_int *entype, 
+		  med_int *geotype,  
+		  unsigned char **flt,
+		  med_int *val)
+#else
+med_int 
+nmmhfaaw(med_int *fid, 
+	 char *mname, med_int *mnamelen,
+	 med_int *datatype,
+	 med_int *numdt, 
+	 med_int *numit, 
+	 med_int *entype,
+	 med_int *geotype, 
+	 unsigned char **flt, 
+	 med_int *val)
+#endif
+{
+  med_int _ret; 
+  char *_fn1;
+  med_entity_type _etype = (med_entity_type) *entype;
+  med_geometry_type _gtype = (med_geometry_type) *geotype;
+  med_data_type _datatype = (med_data_type) *datatype;
+  med_filter *_filter = (med_filter*) *flt; 
+
+  _fn1 = _MED2cstring((char *) mname, (int) *mnamelen);
+  if (!_fn1)
+    return(-1);
+
+  _ret = (med_int) MEDmeshEntityAttributeAdvancedWr((med_idt) *fid, 
+						    _fn1,
+						    _datatype,
+						    (med_int) *numdt,
+						    (med_int) *numit, 
+						    _etype, 
+						    _gtype,
+						    _filter,
+						    (med_int *) val);
+
+  _MEDcstringFree(_fn1);
+
+  return (_ret);
+}
+
+
+
+#ifdef PPRO_NT
+med_int 
+MMHFAAR(med_int *fid, 
+		  char *mname, unsigned int bidon, med_int *mnamelen,
+		  med_int *datatype, 
+		  med_int *numdt, 
+		  med_int *numit,
+		  med_int *entype, 
+		  med_int *geotype,  
+		  unsigned char **flt,
+		  med_int *val)
+#else
+med_int 
+nmmhfaar(med_int *fid, 
+	 char *mname, med_int *mnamelen,
+	 med_int *datatype,
+	 med_int *numdt, 
+	 med_int *numit, 
+	 med_int *entype,
+	 med_int *geotype, 
+	 unsigned char **flt, 
+	 med_int *val)
+#endif
+{
+  med_int _ret; 
+  char *_fn1;
+  med_entity_type _etype = (med_entity_type) *entype;
+  med_geometry_type _gtype = (med_geometry_type) *geotype;
+  med_data_type _datatype = (med_data_type) *datatype;
+  med_filter *_filter = (med_filter*) *flt; 
+
+  _fn1 = _MED2cstring((char *) mname, (int) *mnamelen);
+  if (!_fn1)
+    return(-1);
+
+  _ret = (med_int) MEDmeshEntityAttributeAdvancedRd((med_idt) *fid, 
+						    _fn1,
+						    _datatype,
+						    (med_int) *numdt,
+						    (med_int) *numit, 
+						    _etype, 
+						    _gtype,
+						    _filter,
+						    (med_int *) val);
+
+  _MEDcstringFree(_fn1);
+
+  return (_ret);
+}
+
+
+
+
+
+#ifdef PPRO_NT
+med_int 
+MMHFASW(med_int *fid, 
+		  char *mname, unsigned int bidon, med_int *mnamelen,
+		  med_int *datatype, 
+		  med_int *numdt, 
+		  med_int *numit,
+		  med_int *entype, 
+		  med_int *geotype,  
+		  unsigned char **flt,
+		  char *val)
+#else
+med_int 
+nmmhfasw(med_int *fid, 
+	 char *mname, med_int *mnamelen,
+	 med_int *datatype,
+	 med_int *numdt, 
+	 med_int *numit, 
+	 med_int *entype,
+	 med_int *geotype, 
+	 unsigned char **flt, 
+	 char *val)
+#endif
+{
+  med_int _ret; 
+  char *_fn1;
+  med_entity_type _etype = (med_entity_type) *entype;
+  med_geometry_type _gtype = (med_geometry_type) *geotype;
+  med_data_type _datatype = (med_data_type) *datatype;
+  med_filter *_filter = (med_filter*) *flt; 
+
+  _fn1 = _MED2cstring((char *) mname, (int) *mnamelen);
+  if (!_fn1)
+    return(-1);
+
+  _ret = (med_int) MEDmeshEntityAttributeAdvancedWr((med_idt) *fid, 
+						    _fn1,
+						    _datatype,
+						    (med_int) *numdt,
+						    (med_int) *numit, 
+						    _etype, 
+						    _gtype,
+						    _filter,
+						    val);
+
+  _MEDcstringFree(_fn1);
+
+  return (_ret);
+}
+
+
+
+
+#ifdef PPRO_NT
+med_int 
+MMHFASR(med_int *fid, 
+		  char *mname, unsigned int bidon, med_int *mnamelen,
+		  med_int *datatype, 
+		  med_int *numdt, 
+		  med_int *numit,
+		  med_int *entype, 
+		  med_int *geotype,  
+		  unsigned char **flt,
+		  char *val)
+#else
+med_int 
+nmmhfasr(med_int *fid, 
+	 char *mname, med_int *mnamelen,
+	 med_int *datatype,
+	 med_int *numdt, 
+	 med_int *numit, 
+	 med_int *entype,
+	 med_int *geotype, 
+	 unsigned char **flt, 
+	 char *val)
+#endif
+{
+  med_int _ret; 
+  char *_fn1;
+  med_entity_type _etype = (med_entity_type) *entype;
+  med_geometry_type _gtype = (med_geometry_type) *geotype;
+  med_data_type _datatype = (med_data_type) *datatype;
+  med_filter *_filter = (med_filter*) *flt; 
+
+  _fn1 = _MED2cstring((char *) mname, (int) *mnamelen);
+  if (!_fn1)
+    return(-1);
+
+  _ret = (med_int) MEDmeshEntityAttributeAdvancedRd((med_idt) *fid, 
+						    _fn1,
+						    _datatype,
+						    (med_int) *numdt,
+						    (med_int) *numit, 
+						    _etype, 
+						    _gtype,
+						    _filter,
+						    val);
+
+  _MEDcstringFree(_fn1);
+
+  return (_ret);
+}
