@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -40,11 +40,12 @@ MEDmeshnAxisByName (const med_idt fid,
   int     dummy=0;
   med_int fret=-1;
   med_int majeur, mineur, release;
+  med_bool isasupportmesh = MED_FALSE;
   MedFuncType func;
 
-  MEDversionLire(fid, &majeur, &mineur, &release);
+  MEDfileNumVersionRd(fid, &majeur, &mineur, &release);
   func = _MEDversionedApi3(name,majeur,mineur,release);
   if ( func != (MedFuncType) NULL )
-    func (dummy, fid, meshname  , &fret);
+    func (dummy, fid, meshname, isasupportmesh, &fret);
   return fret;
 }
