@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -24,39 +24,19 @@
 
 
 void  _MEDfieldValueAdvancedWr30(int dummy,...) {
-  va_list params;
-  va_start(params,dummy);
-
-  const med_idt               fid              = va_arg(params, const  med_idt);
-  const char * const          fieldname        = va_arg(params, const  char * const );
-  const med_int               numdt            = va_arg(params, const  med_int);
-  const med_int               numit            = va_arg(params, const  med_int);
-  const med_float             dt               = va_arg(params, const  med_float);
-  const med_entity_type       entitytype       = va_arg(params, const  med_entity_type);
-  const med_geometry_type     geotype          = va_arg(params, const  med_geometry_type);
-  const med_storage_mode      storagemode      = va_arg(params, const  med_storage_mode);
-  const char * const          profilename      = va_arg(params, const  char * const );
-  const char * const          localizationname = va_arg(params, const  char * const );
-  const med_switch_mode       switchmode       = va_arg(params, const  med_switch_mode);
-  const med_int               componentselect  = va_arg(params, const  med_int);
-  const med_filter* const     filter           = va_arg(params, const  med_filter* const );
-  const med_int               nbofentity       = va_arg(params, const  med_int);
-  const unsigned char* const  value            = va_arg(params, const  unsigned char * const );
-  med_err *                   fret             = va_arg(params, med_err *);
-
 
   med_access_mode       _MED_ACCESS_MODE;
   med_err               _ret=-1;
   med_idt               _gid=0,_locgid=0,_datagroup1=0,_datagroup2=0,_datagroup3=0;
-  med_int               _nbofconstituentpervalue=0, _profilearraysize=0;
+  med_int               _nconstituentpervalue=0, _profilearraysize=0;
   med_bool              _defaultprofileexist=MED_FALSE,_defaultlocalizationexist=MED_FALSE;
   med_bool              _attexist=MED_FALSE;
 /*   med_bool              _profilparameterexist=MED_FALSE; */
   med_bool              _profilehaschanged=MED_FALSE,_filterparameterexist=MED_FALSE;
-  med_int               _nbofvaluesperentity=0,_nbofsectiongeotype=0,_nbofsectioncell=1;
+  med_int               _nvaluesperentity=0,_nsectioncell=1;
   med_field_type        _fieldtype=0;
   med_int               _intfieldtype=0;
-  med_geometry_type     _locgeotype=0,_sectiongeotype=0;
+  med_geometry_type     _locgeotype=0;
   med_int               _intlocgeotype=0;
   char _gidname           [MED_TAILLE_CHA+MED_NAME_SIZE+1]="";
   char _datagroupname1    [2*MED_MAX_PARA+1]="";
@@ -75,6 +55,46 @@ void  _MEDfieldValueAdvancedWr30(int dummy,...) {
   med_int                    _MED_NO_IT = MED_NO_IT;
   med_bool                   _chgt=MED_FALSE,_trsf=MED_FALSE;
 
+
+  MED_VARGS_DECL(const, med_idt               , , fid              );
+  MED_VARGS_DECL(const, char * , const          , fieldname        );
+  MED_VARGS_DECL(const, med_int               , , numdt            );
+  MED_VARGS_DECL(const, med_int               , , numit            );
+  MED_VARGS_DECL(const, med_float             , , dt               );
+  MED_VARGS_DECL(const, med_entity_type       , , entitytype       );
+  MED_VARGS_DECL(const, med_geometry_type     , , geotype          );
+  MED_VARGS_DECL(const, med_storage_mode      , , storagemode      );
+  MED_VARGS_DECL(const, char * , const          , profilename      );
+  MED_VARGS_DECL(const, char * , const          , localizationname );
+  MED_VARGS_DECL(const, med_switch_mode       , , switchmode       );
+  MED_VARGS_DECL(const, med_int               , , componentselect  );
+  MED_VARGS_DECL(const, med_filter* , const     , filter           );
+  MED_VARGS_DECL(const, med_int               , , nentity       );
+  MED_VARGS_DECL(const, unsigned char*, const   , value            );
+  MED_VARGS_DECL(, med_err *                   ,, fret             );
+
+  va_list params;
+  va_start(params,dummy);
+
+  MED_VARGS_DEF(const, med_idt               , , fid              );
+  MED_VARGS_DEF(const, char * , const          , fieldname        );
+  MED_VARGS_DEF(const, med_int               , , numdt            );
+  MED_VARGS_DEF(const, med_int               , , numit            );
+  MED_VARGS_DEF(const, med_float             , , dt               );
+  MED_VARGS_DEF(const, med_entity_type       , , entitytype       );
+  MED_VARGS_DEF(const, med_geometry_type     , , geotype          );
+  MED_VARGS_DEF(const, med_storage_mode      , , storagemode      );
+  MED_VARGS_DEF(const, char * , const          , profilename      );
+  MED_VARGS_DEF(const, char * , const          , localizationname );
+  MED_VARGS_DEF(const, med_switch_mode       , , switchmode       );
+  MED_VARGS_DEF(const, med_int               , , componentselect  );
+  MED_VARGS_DEF(const, med_filter* , const     , filter           );
+  MED_VARGS_DEF(const, med_int               , , nentity       );
+  MED_VARGS_DEF(const, unsigned char*, const   , value            );
+  MED_VARGS_DEF(, med_err *                   ,, fret             );
+
+
+
 if (_MEDcheckVersion30(fid) < 0) goto ERROR;
 
   if (filter) {
@@ -82,9 +102,9 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
   }
   else {
     _filter=&_tmpfilter;
-    (*_filter).nbofentity              = nbofentity;
-/*   (*_filter).nbofvaluesperentity     = nbofvaluesperentity; */
-/*   (*_filter).nbofconstituentpervalue = nbofconstituentpervalue; */
+    (*_filter).nentity              = nentity;
+/*   (*_filter).nvaluesperentity     = nvaluesperentity; */
+/*   (*_filter).nconstituentpervalue = nconstituentpervalue; */
     (*_filter).constituentselect       = componentselect;
     (*_filter).switchmode              = switchmode;
     (*_filter).storagemode             = storagemode;
@@ -123,19 +143,19 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
 
   /* Lecture de l'attribut MED_NOM_NCO */
   /* Cohérence de l'attribut MED_NOM_NCO avec le filtre*/
-  if (_MEDattrEntierLire(_gid,MED_NOM_NCO,&_nbofconstituentpervalue) < 0) {
+  if (_MEDattrEntierLire(_gid,MED_NOM_NCO,&_nconstituentpervalue) < 0) {
     MED_ERR_(_ret,MED_ERR_READ,MED_ERR_ATTRIBUTE,MED_ERR_FIELD_MSG);
     SSCRUTE(fieldname);SSCRUTE(MED_NOM_NCO);goto ERROR;
   }
 
   if (_filterparameterexist) {
-    if ((*_filter).nbofconstituentpervalue != _nbofconstituentpervalue ) {
+    if ((*_filter).nconstituentpervalue != _nconstituentpervalue ) {
       MED_ERR_(_ret,MED_ERR_NOTEQUAL,MED_ERR_ATTRIBUTE,MED_ERR_VALUE_MSG);
-      ISCRUTE((*_filter).nbofconstituentpervalue); ISCRUTE(_nbofconstituentpervalue );
+      ISCRUTE((*_filter).nconstituentpervalue); ISCRUTE(_nconstituentpervalue );
       goto ERROR;
     }
   } else {
-    (*_filter).nbofconstituentpervalue = _nbofconstituentpervalue;
+    (*_filter).nconstituentpervalue = _nconstituentpervalue;
   }
 
 
@@ -149,7 +169,6 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
   _fieldtype = (med_field_type) (_intfieldtype);
 
 
-  /* MODEL : Remontée du datagroup2 en datagroup1 */
   /*
    * Creation/Ouverture du datagroup de niveau 2 <numdt>.<numit>
    */
@@ -234,7 +253,7 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
 	ISCRUTE_int(geotype);goto ERROR;
       }
     } else {
-      if ( _MEDgetGeometryTypeName(_geotypename,geotype) < 0) {
+      if ( _MEDgetInternalGeometryTypeName(_geotypename,geotype) < 0) {
 	MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
 	ISCRUTE_int(geotype);SSCRUTE(fieldname);goto ERROR;
       }
@@ -314,7 +333,7 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
 
   /*L'attribut MED_NOM_PFL du datagroup2 est crée après le datagroup profilename
    en cas d'erreur de création */
-  /*TODO: IL faudra gérer la suppression d'un profil si nbofentity==0 et *val=0
+  /*TODO: IL faudra gérer la suppression d'un profil si nentity==0 et *val=0
     TODO: Vérifier alors qu'il n'est pas le profil par défaut sinon proposer une API
     TODO: pour changer le profil par défaut.*/
   if ( !_defaultprofileexist )
@@ -332,10 +351,10 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
     }
   }
   /*Cree ou ouvre l'attribut MED_NOM_NBR */
-  if ( _MEDattributeIntWr(_datagroup3,MED_NOM_NBR,&((*_filter).nbofentity)) < 0) {
+  if ( _MEDattributeIntWr(_datagroup3,MED_NOM_NBR,&((*_filter).nentity)) < 0) {
     MED_ERR_(_ret,MED_ERR_WRITE,MED_ERR_ATTRIBUTE,MED_ERR_FIELD_MSG);
     SSCRUTE(fieldname);SSCRUTE(_datagroupname1);SSCRUTE(_datagroupname2);SSCRUTE(_profilename);
-    SSCRUTE(MED_NOM_NBR);ISCRUTE((*_filter).nbofentity);goto ERROR;
+    SSCRUTE(MED_NOM_NBR);ISCRUTE((*_filter).nentity);goto ERROR;
   }
 
   /* Lit le nombre de points d'intégation et vérifie   */
@@ -355,12 +374,12 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
       MED_ERR_(_ret,MED_ERR_NOTNULL,MED_ERR_PARAMETER,localizationname);
       ISCRUTE_int(entitytype);goto ERROR;
     }
-    _nbofvaluesperentity = geotype % 100;
+    _nvaluesperentity = geotype % 100;
   } else if (! strcmp(localizationname,MED_GAUSS_ELNO)) {
     /* TODO: générer une erreur si on est en présence d'un élément de structure.*/
     /* Les points de Gauss sont définis sur les noeuds de l'element (mot cle) */
     /* le nombre de points de Gauss est egal au nombre de noeuds de l'element */
-    _nbofvaluesperentity = geotype % 100;
+    _nvaluesperentity = geotype % 100;
     /*Impose t'on une localisation, sinon test si "" ?*/
   } else if (strlen(localizationname))  {
     strcat(_locgidname,localizationname);
@@ -370,9 +389,9 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
       goto ERROR;
     }
 
-    if (_MEDattrEntierLire(_locgid,MED_NOM_NBR,&_nbofvaluesperentity) < 0) {
+    if (_MEDattrEntierLire(_locgid,MED_NOM_NBR,&_nvaluesperentity) < 0) {
       MED_ERR_(_ret,MED_ERR_READ,MED_ERR_ATTRIBUTE,MED_ERR_LOCALIZATION_MSG);
-      SSCRUTE(localizationname);SSCRUTE(MED_NOM_NBR);ISCRUTE(_nbofvaluesperentity);goto ERROR;
+      SSCRUTE(localizationname);SSCRUTE(MED_NOM_NBR);ISCRUTE(_nvaluesperentity);goto ERROR;
     }
 
 
@@ -389,35 +408,15 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
 
       if (strlen(_sectionmeshname) ) {
 
-	if ( (_nbofsectiongeotype = MEDmeshnEntity(fid,_sectionmeshname,MED_NO_DT,MED_NO_IT,
-					    MED_CELL,MED_ALL_GEOTYPE,MED_CONNECTIVITY,MED_NODAL,
-					    &_chgt,&_trsf) )  < 0) {
-	  MED_ERR_(_ret,MED_ERR_CALL,MED_ERR_API,"MEDmeshnEntity");
-	  ISCRUTE(_nbofsectiongeotype);goto ERROR;
-	}
-
-	if ( (_nbofsectiongeotype != 1 ) ) {
-	  MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_RANGE,""); ISCRUTE(_nbofsectiongeotype); goto ERROR;
-	}
-
-
-	if ( MEDmeshEntityInfo( fid,_sectionmeshname,MED_NO_DT,MED_NO_IT,
-				MED_CELL, 1, _sectiongeotypename,
-				&_sectiongeotype ) < 0 ) {
-	  MED_ERR_(_ret,MED_ERR_CALL,MED_ERR_API,"MEDmeshEntityInfo");
-	  SSCRUTE(_sectiongeotypename);ISCRUTE_int(_sectiongeotype);goto ERROR;
-	}
-
-	if ( (_nbofsectioncell = MEDmeshnEntity(fid,_sectionmeshname,MED_NO_DT,MED_NO_IT,
-					       MED_CELL,_sectiongeotype,MED_CONNECTIVITY,MED_NODAL,
-					       &_chgt,&_trsf) )  < 0) {
-	  MED_ERR_(_ret,MED_ERR_CALL,MED_ERR_API,"MEDmeshnEntity");
-	  ISCRUTE(_nbofsectioncell);goto ERROR;
+	if ( _MEDgetSupportMeshNbOfEntities(fid,_sectionmeshname,NULL,NULL,NULL,
+					    &_nsectioncell) < 0) {
+	  MED_ERR_(_ret,MED_ERR_CALL,MED_ERR_API,"_MEDgetSupportMeshNbOfEntities");
+	  SSCRUTE(_sectionmeshname);ISCRUTE(_nsectioncell);goto ERROR;
 	}
       }
     }
 
-    _nbofvaluesperentity*=_nbofsectioncell;
+    _nvaluesperentity*=_nsectioncell;
 
     if (_MEDattrEntierLire(_locgid,MED_NOM_GEO,&_intlocgeotype) < 0) {
       MED_ERR_(_ret,MED_ERR_READ,MED_ERR_ATTRIBUTE,MED_ERR_LOCALIZATION_MSG);
@@ -431,11 +430,11 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
       ISCRUTE_int(geotype);goto ERROR;
     }
   }  else  {
-    _nbofvaluesperentity = MED_NO_IPOINT_INTERNAL ;
+    _nvaluesperentity = MED_NO_IPOINT_INTERNAL ;
   }
 /*   strcpy(_localizationname,localizationname); */
 
-  if (!_filterparameterexist) (*_filter).nbofvaluesperentity=_nbofvaluesperentity;
+  if (!_filterparameterexist) (*_filter).nvaluesperentity=_nvaluesperentity;
 
 
 
@@ -449,10 +448,10 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
 
   /* Cree ou ouvre l'attribut MED_NOM_NGA         */
   /* Ecriture de l'attribut portant le nombre de points de gauss  */
-  if ( _MEDattributeIntWr(_datagroup3,MED_NOM_NGA,&_nbofvaluesperentity) < 0) {
+  if ( _MEDattributeIntWr(_datagroup3,MED_NOM_NGA,&_nvaluesperentity) < 0) {
     MED_ERR_(_ret,MED_ERR_WRITE,MED_ERR_ATTRIBUTE,MED_ERR_FIELD_MSG);
     SSCRUTE(fieldname);SSCRUTE(_datagroupname1);SSCRUTE(_datagroupname2);SSCRUTE(_profilename);
-    SSCRUTE(MED_NOM_NGA);ISCRUTE(_nbofvaluesperentity);goto ERROR;
+    SSCRUTE(MED_NOM_NGA);ISCRUTE(_nvaluesperentity);goto ERROR;
   }
 
   /* TODO : ?MODE ECRASEMENT ?*/
@@ -469,9 +468,9 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
   if (!_filterparameterexist) {
 
 #ifdef _DEBUG_
-    ISCRUTE((*_filter).nbofentity              );
-    ISCRUTE((*_filter).nbofvaluesperentity     );
-    ISCRUTE((*_filter).nbofconstituentpervalue );
+    ISCRUTE((*_filter).nentity              );
+    ISCRUTE((*_filter).nvaluesperentity     );
+    ISCRUTE((*_filter).nconstituentpervalue );
     ISCRUTE((*_filter).constituentselect       );
     ISCRUTE_int((*_filter).switchmode              );
     ISCRUTE((*_filter).filterarraysize         );
@@ -480,8 +479,8 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
     SSCRUTE((*_filter).profilename             );
 #endif
 
-    if ( MEDfilterEntityCr(fid, (*_filter).nbofentity,         (*_filter).nbofvaluesperentity,
-			   (*_filter).nbofconstituentpervalue, (*_filter).constituentselect,
+    if ( MEDfilterEntityCr(fid, (*_filter).nentity,         (*_filter).nvaluesperentity,
+			   (*_filter).nconstituentpervalue, (*_filter).constituentselect,
 			   (*_filter).switchmode,              (*_filter).storagemode, 
 			   (*_filter).profilename, MED_UNDEF_SIZE, NULL, &_paramfilter) < 0 ) {
       MED_ERR_(_ret,MED_ERR_CREATE,MED_ERR_FILTER,MED_ERR_INTERNAL_MSG);
@@ -556,8 +555,6 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
 
  ERROR:
 
-/*   if ( _defaultprofileexist ) { free(pfltab); free(pfltabtmp);} */
-
   if (!_filterparameterexist) {
     if ( MEDfilterClose(_filter) < 0 ) {
       MED_ERR_(_ret,MED_ERR_CLOSE,MED_ERR_FILTER,MED_ERR_FIELD_MSG);
