@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -30,27 +30,6 @@
 
 void _MEDmeshAdvancedRd236(int dummy, ...)
 {
-  va_list params;
-  va_start(params,dummy);
-
-  const med_idt               fid         = va_arg(params, const med_idt               );
-  const char*  const          meshname 	  = va_arg(params, const char*  const          );
-  const med_data_type         meddatatype = va_arg(params, const med_data_type         );
-  const char*  const          datasetname = va_arg(params, const char*  const          );
-  const med_internal_type     datatype 	  = va_arg(params, const med_internal_type     );
-  const med_int               numdt 	  = va_arg(params, const med_int               );
-  const med_int               numit 	  = va_arg(params, const med_int               );
-  const med_entity_type       entitytype  = va_arg(params, const med_entity_type       );
-  const med_geometry_type     geotype 	  = va_arg(params, const med_geometry_type     );
-  const med_connectivity_mode cmode 	  = va_arg(params, const med_connectivity_mode );
-  const med_storage_mode      storagemode = va_arg(params, const med_storage_mode      );
-  const char * const          profilename = va_arg(params, const char * const          );
-  const med_switch_mode       switchmode  = va_arg(params, const med_switch_mode       );
-  const med_int               dimselect   = va_arg(params, const med_int               );
-  const med_filter * const    filter 	  = va_arg(params, const med_filter * const    );
-  unsigned char* const        value	  = va_arg(params,       unsigned char* const  );
-  med_err *                   fret        = va_arg(params,        med_err *);
-
   med_access_mode       _MED_ACCESS_MODE;
   med_err               _ret=-1;
   med_idt               _meshid=0;
@@ -64,24 +43,66 @@ void _MEDmeshAdvancedRd236(int dummy, ...)
   med_bool              _filterparameterexist=MED_FALSE;
   med_filter *          _filter           = NULL;
   med_filter            _tmpfilter        = MED_FILTER_INIT;
-  med_int               _nbofconstituentpervalue=0,_spacedim=0;
-  med_internal_type     _datatype=datatype;
-  med_int               _nbofvalueperentity=0;
+  med_int               _nconstituentpervalue=0,_spacedim=0;
+  med_internal_type     _datatype;
+  med_int               _nvalueperentity=0;
   med_mesh_type         _meshtype=MED_UNDEF_MESH_TYPE;
   med_int               _intmeshtype=0;
   med_bool              _isasupportmesh=MED_FALSE;
   med_int               _intgridtype=0;
   med_grid_type         _gridtype=MED_UNDEF_GRID_TYPE;
 
+
+  MED_VARGS_DECL(const, med_idt               , , fid         );
+  MED_VARGS_DECL(const, char*  , const          , meshname    );
+  MED_VARGS_DECL(const, med_data_type         , , meddatatype );
+  MED_VARGS_DECL(const, char*  , const          , datasetname );
+  MED_VARGS_DECL(const, med_internal_type     , , datatype    );
+  MED_VARGS_DECL(const, med_int               , , numdt       );
+  MED_VARGS_DECL(const, med_int               , , numit       );
+  MED_VARGS_DECL(const, med_entity_type       , , entitytype  );
+  MED_VARGS_DECL(const, med_geometry_type     , , geotype     );
+  MED_VARGS_DECL(const, med_connectivity_mode , , cmode       );
+  MED_VARGS_DECL(const, med_storage_mode      , , storagemode );
+  MED_VARGS_DECL(const, char * , const          , profilename );
+  MED_VARGS_DECL(const, med_switch_mode       , , switchmode  );
+  MED_VARGS_DECL(const, med_int               , , dimselect   );
+  MED_VARGS_DECL(const, med_filter * , const    , filter      );
+  MED_VARGS_DECL(,unsigned char*, const         , value       );
+  MED_VARGS_DECL(, med_err *                   ,, fret        );
+
+  va_list params;
+  va_start(params,dummy);
+
+  MED_VARGS_DEF(const, med_idt               , , fid         );
+  MED_VARGS_DEF(const, char*  , const          , meshname           );
+  MED_VARGS_DEF(const, med_data_type         , , meddatatype );
+  MED_VARGS_DEF(const, char*  , const          , datasetname );
+  MED_VARGS_DEF(const, med_internal_type     , , datatype           );
+  MED_VARGS_DEF(const, med_int               , , numdt           );
+  MED_VARGS_DEF(const, med_int               , , numit           );
+  MED_VARGS_DEF(const, med_entity_type       , , entitytype  );
+  MED_VARGS_DEF(const, med_geometry_type     , , geotype           );
+  MED_VARGS_DEF(const, med_connectivity_mode , , cmode           );
+  MED_VARGS_DEF(const, med_storage_mode      , , storagemode );
+  MED_VARGS_DEF(const, char * , const          , profilename );
+  MED_VARGS_DEF(const, med_switch_mode       , , switchmode  );
+  MED_VARGS_DEF(const, med_int               , , dimselect   );
+  MED_VARGS_DEF(const, med_filter * , const    , filter           );
+  MED_VARGS_DEF(,unsigned char*, const         , value       );
+  MED_VARGS_DEF(, med_err *                   ,, fret        );
+
+  _datatype=datatype;
+
   if (filter) {
     _filter=(med_filter*)(filter); _filterparameterexist=MED_TRUE;
   }
   else {
     _filter=&_tmpfilter;
 /*  Inutilisé en lecture 2.3.x*/
-/*     (*_filter).nbofentity              = nbofentity; */
-    (*_filter).nbofvaluesperentity     = 1;
-/*   (*_filter).nbofconstituentpervalue = nbofconstituentpervalue; */
+/*     (*_filter).nentity              = nentity; */
+    (*_filter).nvaluesperentity     = 1;
+/*   (*_filter).nconstituentpervalue = nconstituentpervalue; */
     (*_filter).constituentselect       = dimselect;
     (*_filter).switchmode              = switchmode;
     (*_filter).storagemode             = storagemode;
@@ -185,28 +206,28 @@ void _MEDmeshAdvancedRd236(int dummy, ...)
 /*       ISCRUTE_int(meddatatype);ISCRUTE_int(_intmeshtype);goto ERROR; */
 /*     } */
 
-  if ( ! (_nbofvalueperentity && _nbofconstituentpervalue) )
+  if ( ! (_nvalueperentity && _nconstituentpervalue) )
     if ( _MEDgetDatasetParameter( meddatatype, _spacedim, entitytype, geotype, cmode,
-				  &_nbofvalueperentity,&_nbofconstituentpervalue) < 0 ) {
+				  &_nvalueperentity,&_nconstituentpervalue) < 0 ) {
       MED_ERR_(_ret,MED_ERR_CALL,MED_ERR_API,"_MEDgetDatasetParameter");
-      ISCRUTE_int(meddatatype);ISCRUTE_int(cmode);ISCRUTE(_nbofvalueperentity);
-      ISCRUTE(_nbofconstituentpervalue);goto ERROR;
+      ISCRUTE_int(meddatatype);ISCRUTE_int(cmode);ISCRUTE(_nvalueperentity);
+      ISCRUTE(_nconstituentpervalue);goto ERROR;
     }
 
   if (_filterparameterexist) {
-    if ((*_filter).nbofconstituentpervalue != _nbofconstituentpervalue ) {
+    if ((*_filter).nconstituentpervalue != _nconstituentpervalue ) {
       MED_ERR_(_ret,MED_ERR_NOTEQUAL,MED_ERR_ATTRIBUTE,MED_ERR_VALUE_MSG);
-      ISCRUTE((*_filter).nbofconstituentpervalue); ISCRUTE(_nbofconstituentpervalue );
+      ISCRUTE((*_filter).nconstituentpervalue); ISCRUTE(_nconstituentpervalue );
       goto ERROR;
     }
-    if ((*_filter).nbofvaluesperentity != _nbofvalueperentity ) {
+    if ((*_filter).nvaluesperentity != _nvalueperentity ) {
       MED_ERR_(_ret,MED_ERR_NOTEQUAL,MED_ERR_ATTRIBUTE,MED_ERR_VALUE_MSG);
-      ISCRUTE((*_filter).nbofvaluesperentity); ISCRUTE(_nbofvalueperentity );
+      ISCRUTE((*_filter).nvaluesperentity); ISCRUTE(_nvalueperentity );
       goto ERROR;
     }
   } else {
-    (*_filter).nbofconstituentpervalue = _nbofconstituentpervalue;
-    (*_filter).nbofvaluesperentity     = _nbofvalueperentity;
+    (*_filter).nconstituentpervalue = _nconstituentpervalue;
+    (*_filter).nvaluesperentity     = _nvalueperentity;
   }
 
 
@@ -234,7 +255,7 @@ void _MEDmeshAdvancedRd236(int dummy, ...)
     if (strlen(_geotypename))
       strncpy(_datagroupname3,_geotypename,MED_NAME_SIZE+1);
     else
-      if ( _MEDgetGeometryTypeName(_datagroupname3,geotype) < 0) {
+      if ( _MEDgetInternalGeometryTypeName(_datagroupname3,geotype) < 0) {
 	MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
 	ISCRUTE_int(geotype);SSCRUTE(meshname);SSCRUTE(_datagroupname2);
 	goto ERROR;
@@ -298,7 +319,7 @@ void _MEDmeshAdvancedRd236(int dummy, ...)
     COORDINATE_LABEL:
       if (_MEDdatasetNumLire(_datagroup,_datasetname,MED_FLOAT64,
 				    (med_mode_switch) (*_filter).switchmode ,
-				    (med_size)        (*_filter).nbofconstituentpervalue,
+				    (med_size)        (*_filter).nconstituentpervalue,
 				    (med_size)        (*_filter).constituentselect,
 				    (med_size)        (*_filter).filterarraysize,
 				    MED_COMPACT,MED_PFL_NON_COMPACT,
@@ -363,7 +384,7 @@ void _MEDmeshAdvancedRd236(int dummy, ...)
 #if defined(HAVE_F77INT64)
       if ( _MEDdatasetNumLire(_datagroup,_datasetname,MED_INT64,
 			      (med_mode_switch) (*_filter).switchmode ,
-			      (med_size) (*_filter).nbofconstituentpervalue,
+			      (med_size) (*_filter).nconstituentpervalue,
 			      (med_size) (*_filter).constituentselect,
 			      (med_size) (*_filter).filterarraysize,MED_COMPACT,MED_PFL_NON_COMPACT,
 			      (*_filter).filterarray23v30,
@@ -372,7 +393,7 @@ void _MEDmeshAdvancedRd236(int dummy, ...)
 #else
       if ( _MEDdatasetNumLire(_datagroup,_datasetname,MED_INT32,
 			      (med_mode_switch) (*_filter).switchmode ,
-			      (med_size) (*_filter).nbofconstituentpervalue,
+			      (med_size) (*_filter).nconstituentpervalue,
 			      (med_size) (*_filter).constituentselect,
 			      (med_size) (*_filter).filterarraysize,MED_COMPACT,MED_PFL_NON_COMPACT,
 			      (*_filter).filterarray23v30,
