@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -38,7 +38,7 @@ med_err _MEDmeshAdvancedWr(const med_idt               fid,
 			   const med_switch_mode       switchmode,
 			   const med_int               dimselect,
 			   const med_filter * const    filter,
-			   const med_int               nbofentity,
+			   const med_int               nentity,
 			   const void * const          value)
 {
   med_access_mode       _MED_ACCESS_MODE;
@@ -66,14 +66,14 @@ med_err _MEDmeshAdvancedWr(const med_idt               fid,
   med_filter *          _filter           = NULL;
   med_filter            _tmpfilter        = MED_FILTER_INIT;
   med_filter            _paramfilter      = MED_FILTER_INIT;
-  med_int               _nbofconstituentpervalue=0,_spacedim=0;
+  med_int               _nconstituentpervalue=0,_spacedim=0;
   med_sorting_type      _sortingtype=0;
   med_int               _intsortingtype=0;
   med_int               _false=0,_true=1,_not_the_first_cstp=_false;
   /*   med_int               _profilearraysize=0; */
   med_internal_type     _datatype=datatype;
-  med_int               _nbofvalueperentity=0;
-  med_int               _nbofentity=0;
+  med_int               _nvalueperentity=0;
+  med_int               _nentity=0;
   med_int               _intmeshtype=0;
   med_int               _medintgeotype = geotype;
   med_geometry_type     _sgeotype      = MED_NONE;
@@ -81,6 +81,7 @@ med_err _MEDmeshAdvancedWr(const med_idt               fid,
   med_bool              _chgt=MED_FALSE,_trsf=MED_FALSE;
   med_bool              _isasupportmesh=MED_FALSE;
   char                  _supportmeshname[MED_NAME_SIZE+1]="";
+  med_bool              _attributeexist=MED_FALSE;
 
 if (_MEDcheckVersion30(fid) < 0) goto ERROR;
 
@@ -89,9 +90,9 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
   }
   else {
     _filter=&_tmpfilter;
-    (*_filter).nbofentity              = nbofentity;
-    (*_filter).nbofvaluesperentity     = 1;
-    /*   (*_filter).nbofconstituentpervalue = nbofconstituentpervalue; */
+    (*_filter).nentity              = nentity;
+    (*_filter).nvaluesperentity     = 1;
+    /*   (*_filter).nconstituentpervalue = nconstituentpervalue; */
     (*_filter).constituentselect       = dimselect;
     (*_filter).switchmode              = switchmode;
     (*_filter).storagemode             = storagemode;
@@ -181,21 +182,19 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
       _sgeotype = _medintsgeotype;
 
       if (strlen(_supportmeshname) )
-	if ( (_nbofvalueperentity = MEDmeshnEntity(fid,_supportmeshname,MED_NO_DT,MED_NO_IT,
+	if ( (_nvalueperentity = MEDmeshnEntity(fid,_supportmeshname,MED_NO_DT,MED_NO_IT,
 						   MED_CELL,_sgeotype,MED_CONNECTIVITY,MED_NODAL,
 						   &_chgt,&_trsf) )  < 0) {
 	  MED_ERR_(_ret,MED_ERR_CALL,MED_ERR_API,"MEDmeshnEntity");
-	  ISCRUTE(_nbofvalueperentity);goto ERROR;
+	  ISCRUTE(_nvalueperentity);goto ERROR;
 	}
 
-      if (!_nbofvalueperentity) _nbofvalueperentity=1;
-
-      /*
-       * REM : Les routines ayant besoin du nombre de noeuds sont implémentées
-       spécifiquement.
-      */
-
-      if (!_nbofconstituentpervalue) _nbofconstituentpervalue=1;
+      if (_nvalueperentity ) {
+	if (!_nconstituentpervalue) _nconstituentpervalue=_sgeotype%100;
+      } else {
+	_nvalueperentity=1;
+	if (!_nconstituentpervalue) _nconstituentpervalue=1;
+      }
 
     }
   }
@@ -205,13 +204,13 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
 					  _geotypename,
 					  datasetname,
 					  (med_attribute_type* const) &_datatype,
-					  &_nbofconstituentpervalue
+					  &_nconstituentpervalue
 					  ) < 0) {
       MED_ERR_(_ret,MED_ERR_CALL,MED_ERR_API,"MEDstructElementVarAttInfoByName");
       ISCRUTE_int(geotype);SSCRUTE(datasetname);
-      ISCRUTE_int(_datatype);ISCRUTE(_nbofconstituentpervalue);goto ERROR;
+      ISCRUTE_int(_datatype);ISCRUTE(_nconstituentpervalue);goto ERROR;
     }
-    _nbofvalueperentity=1;
+    _nvalueperentity=1;
   }
 
   /* FIN TODO structelem*/
@@ -247,30 +246,30 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
       ISCRUTE_int(meddatatype);ISCRUTE(_intmeshtype);goto ERROR;
     }
 
-  if ( ! (_nbofvalueperentity && _nbofconstituentpervalue) )
+  if ( ! (_nvalueperentity && _nconstituentpervalue) )
     if ( _MEDgetDatasetParameter( meddatatype, _spacedim, entitytype, geotype, cmode,
-				  &_nbofvalueperentity,&_nbofconstituentpervalue) < 0 ) {
+				  &_nvalueperentity,&_nconstituentpervalue) < 0 ) {
       MED_ERR_(_ret,MED_ERR_CALL,MED_ERR_API,"_MEDgetDatasetParameter");
-      ISCRUTE_int(meddatatype);ISCRUTE_int(cmode);ISCRUTE(_nbofvalueperentity);
-      ISCRUTE(_nbofconstituentpervalue);goto ERROR;
+      ISCRUTE_int(meddatatype);ISCRUTE_int(cmode);ISCRUTE(_nvalueperentity);
+      ISCRUTE(_nconstituentpervalue);goto ERROR;
     }
 
-  /*     ISCRUTE(_nbofconstituentpervalue); */
+  /*     ISCRUTE(_nconstituentpervalue); */
 
   if (_filterparameterexist) {
-    if ((*_filter).nbofconstituentpervalue != _nbofconstituentpervalue ) {
+    if ((*_filter).nconstituentpervalue != _nconstituentpervalue ) {
       MED_ERR_(_ret,MED_ERR_NOTEQUAL,MED_ERR_ATTRIBUTE,MED_ERR_VALUE_MSG);
-      ISCRUTE((*_filter).nbofconstituentpervalue); ISCRUTE(_nbofconstituentpervalue );
+      ISCRUTE((*_filter).nconstituentpervalue); ISCRUTE(_nconstituentpervalue );
       goto ERROR;
     }
-    if ((*_filter).nbofvaluesperentity != _nbofvalueperentity ) {
+    if ((*_filter).nvaluesperentity != _nvalueperentity ) {
       MED_ERR_(_ret,MED_ERR_NOTEQUAL,MED_ERR_ATTRIBUTE,MED_ERR_VALUE_MSG);
-      ISCRUTE((*_filter).nbofvaluesperentity); ISCRUTE(_nbofvalueperentity );
+      ISCRUTE((*_filter).nvaluesperentity); ISCRUTE(_nvalueperentity );
       goto ERROR;
     }
   } else {
-    (*_filter).nbofconstituentpervalue = _nbofconstituentpervalue;
-    (*_filter).nbofvaluesperentity     = _nbofvalueperentity;
+    (*_filter).nconstituentpervalue = _nconstituentpervalue;
+    (*_filter).nvaluesperentity     = _nvalueperentity;
   }
 
 
@@ -335,7 +334,7 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
     if (strlen(_geotypename))
       strncpy(_datagroupname3,_geotypename,MED_NAME_SIZE+1);
     else
-      if ( _MEDgetGeometryTypeName(_datagroupname3,geotype) < 0) {
+      if ( _MEDgetInternalGeometryTypeName(_datagroupname3,geotype) < 0) {
 	MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
 	ISCRUTE_int(geotype);SSCRUTE(meshname);ISCRUTE(numit);ISCRUTE(numdt);
 	SSCRUTE(_datagroupname2);goto ERROR;
@@ -421,9 +420,9 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
   if (!_filterparameterexist) {
 
 #ifdef _DEBUG_
-    ISCRUTE((*_filter).nbofentity              );
-    ISCRUTE((*_filter).nbofvaluesperentity     );
-    ISCRUTE((*_filter).nbofconstituentpervalue );
+    ISCRUTE((*_filter).nentity              );
+    ISCRUTE((*_filter).nvaluesperentity     );
+    ISCRUTE((*_filter).nconstituentpervalue );
     ISCRUTE((*_filter).constituentselect       );
     ISCRUTE_int((*_filter).switchmode              );
     ISCRUTE((*_filter).filterarraysize         );
@@ -432,8 +431,8 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
     SSCRUTE((*_filter).profilename             );
 #endif
 
-    if ( MEDfilterEntityCr(fid, (*_filter).nbofentity,         (*_filter).nbofvaluesperentity,
-			   (*_filter).nbofconstituentpervalue, (*_filter).constituentselect,
+    if ( MEDfilterEntityCr(fid, (*_filter).nentity,         (*_filter).nvaluesperentity,
+			   (*_filter).nconstituentpervalue, (*_filter).constituentselect,
 			   (*_filter).switchmode,              (*_filter).storagemode,
 			   (*_filter).profilename, MED_UNDEF_SIZE, NULL, &_paramfilter) < 0 ) {
       MED_ERR_(_ret,MED_ERR_CREATE,MED_ERR_FILTER,MED_ERR_INTERNAL_MSG);
@@ -443,9 +442,9 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
   }
 
 #ifdef _DEBUG_
-  ISCRUTE((*_filter).nbofentity              );
-  ISCRUTE((*_filter).nbofvaluesperentity     );
-  ISCRUTE((*_filter).nbofconstituentpervalue );
+  ISCRUTE((*_filter).nentity              );
+  ISCRUTE((*_filter).nvaluesperentity     );
+  ISCRUTE((*_filter).nconstituentpervalue );
   ISCRUTE((*_filter).constituentselect       );
   ISCRUTE_int((*_filter).switchmode              );
   ISCRUTE((*_filter).filterarraysize         );
@@ -461,8 +460,8 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
      Obtenir le nbre de particules
   TODO : A remonter dans MEDmeshConne.. avec nentity==0 */
   if ( ( meddatatype == MED_CONNECTIVITY) && (!strcmp(_geotypename,"MED_PARTICLE")) ) {
-    _nbofentity = (*_filter).nbofentity;
-    (*_filter).nbofentity= 0;
+    _nentity = (*_filter).nentity;
+    (*_filter).nentity= 0;
   }
 
   /* Externaliser le choix d'écriture effective du dataset */
@@ -477,7 +476,7 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
     }
 
   if (  ( meddatatype == MED_CONNECTIVITY) && (!strcmp(_geotypename,"MED_PARTICLE")) ) {
-    (*_filter).nbofentity= _nbofentity;
+    (*_filter).nentity= _nentity;
   }
 
 
@@ -494,14 +493,20 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
   /*
    * Creation/Ecriture de l'attribut MED_NOM_GEO (type géométrique des mailles support)
    */
-  if ( entitytype != MED_NODE )
-    if ( _MEDattributeIntWr(_datagroup,MED_NOM_GEO,&_medintgeotype) < 0 ) {
-      MED_ERR_(_ret,MED_ERR_WRITE,MED_ERR_ATTRIBUTE,MED_ERR_MESH_MSG);
-      SSCRUTE(meshname);ISCRUTE(numit);ISCRUTE(numdt);SSCRUTE(_datagroupname2);SSCRUTE(_datagroupname3);
-      SSCRUTE(MED_NOM_PFL);SSCRUTE(MED_NOM_GEO);ISCRUTE(_medintgeotype);
-      goto ERROR;
+  if ( entitytype != MED_NODE ) {
+    if ( _MEDattributeExist(_datagroup, ".",MED_NOM_GEO, &_attributeexist ) < 0 ) {
+      MED_ERR_(_ret,MED_ERR_CALL,MED_ERR_API,"_MEDattributeExist"); goto ERROR;
     }
 
+    if (!_attributeexist) /* MED_ACC_RDEXT */
+      if ( _MEDattributeIntWr(_datagroup,MED_NOM_GEO,&_medintgeotype) < 0 ) {
+	MED_ERR_(_ret,MED_ERR_WRITE,MED_ERR_ATTRIBUTE,MED_ERR_MESH_MSG);
+	SSCRUTE(meshname);ISCRUTE(numit);ISCRUTE(numdt);SSCRUTE(_datagroupname2);SSCRUTE(_datagroupname3);
+	SSCRUTE(MED_NOM_PFL);SSCRUTE(MED_NOM_GEO);ISCRUTE(_medintgeotype);
+	goto ERROR;
+      }
+  }
+
   /*
    * Attribut NBR (nombre de noeuds ou d'elements) sur le dataset
    */
@@ -513,10 +518,10 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
       SSCRUTE(_datagroupname2);SSCRUTE(_datagroupname3);goto ERROR;
     }
 
-    if ( _MEDattributeIntWr(_dataset,MED_NOM_NBR,&((*_filter).nbofentity)) < 0) {
+    if ( _MEDattributeIntWr(_dataset,MED_NOM_NBR,&((*_filter).nentity)) < 0) {
       MED_ERR_(_ret,MED_ERR_WRITE,MED_ERR_ATTRIBUTE,MED_ERR_MESH_MSG);
       SSCRUTE(meshname);ISCRUTE(numit);ISCRUTE(numdt);SSCRUTE(_datagroupname2);SSCRUTE(_datagroupname3);
-      SSCRUTE(MED_NOM_NBR);ISCRUTE((*_filter).nbofentity);goto ERROR;
+      SSCRUTE(MED_NOM_NBR);ISCRUTE((*_filter).nentity);goto ERROR;
     }
   }
 
@@ -580,7 +585,7 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
  ERROR:
 
   if (!_filterparameterexist) {
-    if ( MEDfilterClose(_filter) < 0 ) {
+   if ( MEDfilterClose(_filter) < 0 ) {
       MED_ERR_(_ret,MED_ERR_CLOSE,MED_ERR_FILTER,MED_ERR_MESH_MSG);
       SSCRUTE(meshname);ISCRUTE(numit);ISCRUTE(numdt);SSCRUTE(_datagroupname2);SSCRUTE(_datagroupname3);
       SSCRUTE(_profilename);goto ERROR;
