@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -27,23 +27,6 @@ void
 _MEDmeshnEntity30(int dummy, ...)
 {
 
-  va_list params;
-  va_start(params,dummy);
-
-  const med_idt                fid           = va_arg(params, const med_idt               );
-  const char * const           meshname      = va_arg(params, const char * const          );
-  const med_int                numdt         = va_arg(params, const med_int               );
-  const med_int                numit         = va_arg(params, const med_int               );
-  const med_entity_type        entitytype    = va_arg(params, const med_entity_type       );
-  const med_geometry_type      geotype       = va_arg(params, const med_geometry_type     );
-  const med_data_type          meddatatype   = va_arg(params, const med_data_type         );
-  const med_connectivity_mode  cmode         = va_arg(params, const med_connectivity_mode );
-  const med_storage_mode       storagemode   = va_arg(params, const med_storage_mode      );
-        char     * const       profilename   = va_arg(params, char * const                );
-        med_int  * const       profilesize   = va_arg(params, med_int * const             );
-        med_bool * const       changement    = va_arg(params, med_bool * const            );
-        med_bool * const       transformation= va_arg(params, med_bool * const            );
-        med_int  *             fret          = va_arg(params, med_int *);
 
   med_access_mode       _MED_ACCESS_MODE;
   med_int               _ret=-1,_err=-1;
@@ -64,6 +47,7 @@ _MEDmeshnEntity30(int dummy, ...)
   med_int               _changement=0, _changement_s=0, _transformation=0;
   med_bool              _changement_co     = MED_FALSE;
   med_size              _n=0;
+  med_int               _intn=0;
   med_bool              _isasupportmesh    = MED_FALSE;
   med_bool              _isasoftlink       = MED_FALSE;
   med_bool              _datasetexist      = MED_FALSE;
@@ -74,7 +58,43 @@ _MEDmeshnEntity30(int dummy, ...)
   med_int               _intmeshtype       = 0;
   med_int               _meshdim           = 0;
   int                   _i                 = 0;
-  med_connectivity_mode _cmode             = cmode;
+  med_connectivity_mode _cmode                ;
+
+
+  MED_VARGS_DECL(const, med_idt                , , fid           );
+  MED_VARGS_DECL(const, char * , const           , meshname      );
+  MED_VARGS_DECL(const, med_int                , , numdt         );
+  MED_VARGS_DECL(const, med_int                , , numit         );
+  MED_VARGS_DECL(const, med_entity_type        , , entitytype    );
+  MED_VARGS_DECL(const, med_geometry_type      , , geotype       );
+  MED_VARGS_DECL(const, med_data_type          , , meddatatype   );
+  MED_VARGS_DECL(const, med_connectivity_mode  , , cmode         );
+  MED_VARGS_DECL(const, med_storage_mode       , , storagemode   );
+  MED_VARGS_DECL(, char     *, const       , profilename         );
+  MED_VARGS_DECL(, med_int  *, const       , profilesize         );
+  MED_VARGS_DECL(, med_bool *, const       , changement          );
+  MED_VARGS_DECL(, med_bool *, const       , transformation      );
+  MED_VARGS_DECL(, med_int  *             ,, fret                );
+
+  va_list params;
+  va_start(params,dummy);
+
+  MED_VARGS_DEF(const, med_idt                , , fid           );
+  MED_VARGS_DEF(const, char * , const           , meshname      );
+  MED_VARGS_DEF(const, med_int                , , numdt         );
+  MED_VARGS_DEF(const, med_int                , , numit         );
+  MED_VARGS_DEF(const, med_entity_type        , , entitytype    );
+  MED_VARGS_DEF(const, med_geometry_type      , , geotype       );
+  MED_VARGS_DEF(const, med_data_type          , , meddatatype   );
+  MED_VARGS_DEF(const, med_connectivity_mode  , , cmode         );
+  MED_VARGS_DEF(const, med_storage_mode       , , storagemode   );
+  MED_VARGS_DEF(, char     *, const       , profilename         );
+  MED_VARGS_DEF(, med_int  *, const       , profilesize         );
+  MED_VARGS_DEF(, med_bool *, const       , changement          );
+  MED_VARGS_DEF(, med_bool *, const       , transformation      );
+  MED_VARGS_DEF(, med_int  *             ,, fret                );
+
+  _cmode = cmode;
 
   /*
    * On inhibe le gestionnaire d'erreur HDF 5
@@ -218,7 +238,7 @@ _MEDmeshnEntity30(int dummy, ...)
 	ISCRUTE_int(geotype);goto ERROR;
       }
     } else
-      if ( _MEDgetGeometryTypeName(_datagroupname3,geotype) < 0) {
+      if ( _MEDgetInternalGeometryTypeName(_datagroupname3,geotype) < 0) {
 	MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
 	ISCRUTE_int(geotype);SSCRUTE(meshname);ISCRUTE(numit);ISCRUTE(numdt);
 	SSCRUTE(_datagroupname2);goto ERROR;
@@ -388,13 +408,13 @@ _MEDmeshnEntity30(int dummy, ...)
 
   if ( (_dataset = _MEDdatasetOuvrir(_datagroupf,_datasetname)) < 0) {
     _n=0;_dataset=0;*transformation = (med_bool) MED_FALSE;
-    if ( (numdt != MED_NO_DT) || (numit != MED_NO_IT) ) {
-      MED_ERR_(_ret,MED_ERR_OPEN,MED_ERR_DATASET,_datasetname);
-      SSCRUTE(meshname);ISCRUTE(numit);ISCRUTE(numdt);
-      SSCRUTE(_datagroupname2);SSCRUTE(_datagroupname3);SSCRUTE(_datagroupname4);
-      ISCRUTE_size(_n);
-      goto ERROR;
-    }
+/*     if ( (numdt != MED_NO_DT) || (numit != MED_NO_IT) ) { */
+/*       MED_ERR_(_ret,MED_ERR_OPEN,MED_ERR_DATASET,_datasetname); */
+/*       SSCRUTE(meshname);ISCRUTE(numit);ISCRUTE(numdt); */
+/*       SSCRUTE(_datagroupname2);SSCRUTE(_datagroupname3);SSCRUTE(_datagroupname4); */
+/*       ISCRUTE_size(_n); */
+/*       goto ERROR; */
+/*     } */
     goto SORTIE;
   }
 
@@ -467,12 +487,13 @@ _MEDmeshnEntity30(int dummy, ...)
   /*
    * Attribut NBR (nombre d'entité)
    */
-  if ( _MEDattrEntierLire(_dataset,MED_NOM_NBR,&_n) < 0) {
+  if ( _MEDattrEntierLire(_dataset,MED_NOM_NBR,&_intn) < 0) {
     MED_ERR_(_ret,MED_ERR_READ,MED_ERR_ATTRIBUTE,MED_ERR_MESH_MSG);
     SSCRUTE(meshname);ISCRUTE(numit);ISCRUTE(numdt);
     SSCRUTE(_datagroupname2);SSCRUTE(_datagroupname3);SSCRUTE(_datagroupname4);
     SSCRUTE(_datasetname);SSCRUTE(MED_NOM_NBR);ISCRUTE_size(_n);goto ERROR;
   }
+  _n = _intn;
 
   if (_profilearraysize)
     switch(storagemode) {
