@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -30,13 +30,19 @@
 void
 _MEDnFamily23Attribute236(int dummy,...)
 {
+
+  MED_VARGS_DECL(const, med_idt      , , fid        );
+  MED_VARGS_DECL(const, char* , const  , meshname   );
+  MED_VARGS_DECL(const, int          , , famit      );
+  MED_VARGS_DECL(, med_int *          ,, fret       );
+
   va_list params;
   va_start(params,dummy);
 
-  const med_idt      fid        = va_arg(params, const  med_idt       );
-  const char* const  meshname   = va_arg(params, const  char* const   );
-  const int          famit      = va_arg(params, const  int           );
-  med_int *          fret       = va_arg(params,        med_int*      );
+  MED_VARGS_DEF(const, med_idt      , , fid        );
+  MED_VARGS_DEF(const, char* , const  , meshname   );
+  MED_VARGS_DEF(const, int          , , famit      );
+  MED_VARGS_DEF(, med_int *          ,, fret       );
 
   *fret=MEDnAttribut(fid,(char *) meshname,famit);
 
