@@ -1,6 +1,6 @@
 C*  This file is part of MED.
 C*
-C*  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+C*  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
 C*  MED is free software: you can redistribute it and/or modify
 C*  it under the terms of the GNU Lesser General Public License as published by
 C*  the Free Software Foundation, either version 3 of the License, or
@@ -17,6 +17,7 @@ C
 
       subroutine mmhcre(fid, name, sdim, mdim, mtype, desc, dtunit,
      &                  stype, atype, aname, aunit, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcre
 c
       implicit none
       save
@@ -36,6 +37,7 @@ c
 c
 c
       subroutine mmhnmh( fid , n , cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhnmh
 c
       implicit none
       save
@@ -57,6 +59,7 @@ c
 c
 c
       subroutine mmhnax( fid , it, naxis, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhnax
 c
       implicit none
       save
@@ -77,6 +80,7 @@ c
 c
 c
       subroutine  mmhnan( fid , name, naxis, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhnan
 c
       implicit none
       save
@@ -99,6 +103,7 @@ c
 c
       subroutine mmhmii(fid, it, name, sdim, mdim, mtype, desc, dtunit,
      &                  stype, nstep, atype, aname, aunit, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhmii
 c
       implicit none
       save
@@ -117,6 +122,7 @@ c
 c
       subroutine mmhmin(fid, name, sdim, mdim, mtype, desc, dtunit,
      &                  stype, nstep, atype, aname, aunit, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhmin
 c
       implicit none
       save
@@ -135,6 +141,7 @@ c
 c
 c
       subroutine  mmhunw( fid , name, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhunw
 c
       implicit none
       save
@@ -151,6 +158,7 @@ c
 c
 c
       subroutine  mmhunr( fid , mname, uname, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhunr
 c
       implicit none
       save
@@ -168,6 +176,7 @@ c
 c
 c
       subroutine  mmhatw( fid , name, nin, nvn, nnc, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhatw
 c
       implicit none
       save
@@ -184,6 +193,7 @@ c
 c
 c
       subroutine  mmhatr( fid , name, nin, nvn, nnc, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhatr
 c
       implicit none
       save
@@ -200,6 +210,7 @@ c
 c
 c
       subroutine  mmhgtw( fid , name, gtype, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhgtw
 c
       implicit none
       save
@@ -216,6 +227,7 @@ c
 c
 c
       subroutine  mmhgtr( fid , name, gtype, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhgtr
 c
       implicit none
       save
@@ -232,6 +244,7 @@ c
 c
 c
       subroutine  mmhgsw( fid , name, numdt, numit, dt, st, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhgsw
 c
       implicit none
       save
@@ -250,6 +263,7 @@ c
 c
 c
       subroutine mmhgsr( fid , name, numdt, numit, st, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhgsr
 c
       implicit none
       save
@@ -268,6 +282,7 @@ c
 c
       subroutine  mmhcow( fid , name, numdt, numit, dt, 
      &                    swm, n, coo, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcow
 c
       implicit none
       save
@@ -287,6 +302,7 @@ c
 c
       subroutine  mmhcor( fid , name, numdt, numit,
      &                    swm, coo, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcor
 c
       implicit none
       save
@@ -305,6 +321,7 @@ c
 c
       subroutine  mmhcpw( fid , name, numdt, numit, dt, 
      &                    stm, pname, swm, dim, n, coo, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcpw
 c
       implicit none
       save
@@ -325,6 +342,7 @@ c
 c
       subroutine  mmhcpr( fid , name, numdt, numit,
      &                    stm, pname, swm, dim, coo, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcpr
 c
       implicit none
       save
@@ -344,6 +362,7 @@ c
 c
       subroutine  mmhgcw( fid , name, numdt, numit, dt, 
      &                    axis, size, index, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhgcw
 c
       implicit none
       save
@@ -363,6 +382,7 @@ c
 c
       subroutine  mmhgcr( fid , name, numdt, numit, 
      &                    axis, index, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhgcr
 c
       implicit none
       save
@@ -381,6 +401,7 @@ c
 c
       subroutine  mmhenw(fid,name,numdt,numit,entype,geotype, 
      &                   n,num,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhenw
 c
       implicit none
       save
@@ -400,6 +421,7 @@ c
 c
       subroutine  mmhenr(fid,name,numdt,numit,entype,geotype, 
      &                   num,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhenr
 c
       implicit none
       save
@@ -419,6 +441,7 @@ c
 c
       subroutine  mmhfnw(fid,name,numdt,numit,entype,geotype, 
      &                   n,num,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhfnw
 c
       implicit none
       save
@@ -438,6 +461,7 @@ c
 c
       subroutine  mmhfnr(fid,name,numdt,numit,entype,geotype, 
      &                   num,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhfnr
 c
       implicit none
       save
@@ -456,7 +480,8 @@ c
 c
 c
       subroutine mmheaw(fid,mname,numdt,numit,entype,geotype,
-     &                  n,ename,cret) 
+     &                  n,ename,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmheaw
 c
       implicit none
       save
@@ -475,7 +500,8 @@ c
 c
 c
       subroutine mmhear(fid,mname,numdt,numit,entype,geotype,
-     &                  ename,cret) 
+     &                  ename,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhear
 c
       implicit none
       save
@@ -496,6 +522,7 @@ c
       subroutine mmhnme(fid,name,numdt,numit,
      &                  entype,geotype,datype,cmode,
      &                  chgt,tsf,n,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhnme
 c
       implicit none
       save
@@ -521,6 +548,7 @@ c
 c
       subroutine  mmhcyw(fid,name,numdt,numit,dt,entype,geotype, 
      &                   cmode,swm,n,con,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcyw
 c
       implicit none
       save
@@ -541,6 +569,7 @@ c
 c
       subroutine  mmhcyr(fid,name,numdt,numit,entype,geotype, 
      &                   cmode,swm,con,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcyr
 c
       implicit none
       save
@@ -560,6 +589,7 @@ c
 c
       subroutine  mmhypw(fid,name,numdt,numit,dt,entype,geotype, 
      &                   cmode,stmode,pname,swm,dim,n,con,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhypw
 c
       implicit none
       save
@@ -582,6 +612,7 @@ c
 c
       subroutine  mmhypr(fid,name,numdt,numit,entype,geotype, 
      &                   cmode,stmode,pname,swm,dim,n,con,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhypr
 c
       implicit none
       save
@@ -605,6 +636,7 @@ c
      &                  entype,geotype,datype,cmode,
      &                  stmode,pname,psize,
      &                  chgt,tsf,n,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhnep
 c
       implicit none
       save
@@ -632,6 +664,7 @@ c
       subroutine  mmhnor(fid , name, numdt, numit, 
      &                   swm, coo, iname, nname, inum, num,
      &                   ifam,fam, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhnor
       implicit none
       save
 c
@@ -655,6 +688,7 @@ c
       subroutine  mmhnow(fid, name, numdt, numit, dt,
      &                   swm, n, coo, iname, nname, inum, num,
      &                   ifam, fam, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhnow
 c
       implicit none
       save
@@ -678,6 +712,7 @@ c
       subroutine  mmhelw(fid,name,numdt,numit,dt,entype,geotype, 
      &                   cmode,swm,n,con,iname, nname, inum, num,
      &                   ifam,fam,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhelw
 c
       implicit none
       save
@@ -703,6 +738,7 @@ c
       subroutine  mmhelr(fid,name,numdt,numit,entype,geotype, 
      &                   cmode,swm,con,iname, nname, inum, num,
      &                   ifam,fam,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhelr
 c
       implicit none
       save
@@ -725,6 +761,7 @@ c
 c
       subroutine mmhcaw( fid , name, numdt, numit, dt, 
      &                    flt, coo, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcaw
 c
       implicit none
       save
@@ -745,6 +782,7 @@ c
 c
       subroutine  mmhcar(fid , name, numdt, numit,
      &                   flt, coo, cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcar
 c
       implicit none
       save
@@ -764,6 +802,7 @@ c
 c
       subroutine  mmhyaw(fid,name,numdt,numit,dt,entype,geotype, 
      &                   cmode,flt,con,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhyaw
 c
       implicit none
       save
@@ -785,6 +824,7 @@ c
 c
       subroutine  mmhyar(fid,name,numdt,numit,entype,geotype, 
      &                   cmode,flt,con,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhyar
 c
       implicit none
       save
@@ -805,6 +845,7 @@ c
 c
       subroutine  mmhpgw(fid,name,numdt,numit,dt,entype,
      &                   cmode,isize,index,con,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhpgw
 c
       implicit none
       save
@@ -825,6 +866,7 @@ c
 c
       subroutine  mmhpgr(fid,name,numdt,numit,entype,
      &                   cmode,index,con,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhpgr
 c
       implicit none
       save
@@ -844,6 +886,7 @@ c
 c
       subroutine  mmhphw(fid,name,numdt,numit,dt,entype,
      &                   cmode,fisize,findex,nisize,nindex,con,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhphw
 c
       implicit none
       save
@@ -864,6 +907,7 @@ c
 c
       subroutine  mmhphr(fid,name,numdt,numit,entype,
      &                   cmode,findex,nindex,con,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhphr
 c
       implicit none
       save
@@ -883,6 +927,7 @@ c
 c
       subroutine  mmhgnw(fid,name,numdt,numit,entype,geotype, 
      &                   n,num,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhgnw
 c
       implicit none
       save
@@ -902,6 +947,7 @@ c
 c
       subroutine  mmhgnr(fid,name,numdt,numit,entype,geotype, 
      &                   num,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhgnr
 c
       implicit none
       save
@@ -921,6 +967,7 @@ c
 c
       subroutine  mmhcsc(fid,name,numdt1,numit1,numdt2,numit2,
      &                   dt2,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcsc
 c
       implicit none
       save
@@ -939,6 +986,7 @@ c
 c
 c
       subroutine  mmhcsi(fid,name,csit,numdt,numit,dt,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcsi
 c
       implicit none
       save
@@ -956,6 +1004,7 @@ c
 c
 c
       subroutine  mmhcsr(fid,name,numdt,numit,dt,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhcsr
 c
       implicit none
       save
@@ -973,6 +1022,7 @@ c
 c
 c
       subroutine  mmhstr(fid,name,stype,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhstr
 c
       implicit none
       save
@@ -991,6 +1041,7 @@ c
       subroutine mmhraw(fid,name,numdt,numit,
      &                  geotype,aname,n,
      &                  val,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhraw
 c
       implicit none
       save
@@ -1012,6 +1063,7 @@ c
       subroutine mmhiaw(fid,name,numdt,numit,
      &                  geotype,aname,n,
      &                  val,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhiaw
 c
       implicit none
       save
@@ -1033,6 +1085,7 @@ c
       subroutine mmhsaw(fid,name,numdt,numit,
      &                  geotype,aname,n,
      &                  val,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhsaw
 c
       implicit none
       save
@@ -1054,6 +1107,7 @@ c
       subroutine mmhrar(fid,name,numdt,numit,
      &                  geotype,aname,
      &                  val,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhrar
 c
       implicit none
       save
@@ -1073,6 +1127,7 @@ c
 c
       subroutine mmhiar(fid,name,numdt,numit,
      &                  geotype,aname,val,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhfiar
 c
       implicit none
       save
@@ -1092,6 +1147,7 @@ c
 c
       subroutine mmhsar(fid,name,numdt,numit,
      &                  geotype,aname,val,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhsar
 c
       implicit none
       save
@@ -1112,6 +1168,7 @@ c
 c
       subroutine  mmheni(fid,name,numdt,numit,entype,it, 
      &                   geoname,geotype,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmheni
 c
       implicit none
       save
@@ -1130,6 +1187,7 @@ c
 c
       subroutine  mmhtfw( fid , name, numdt, numit, dt, 
      &                    tsf,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhtfw
 c
       implicit none
       save
@@ -1149,6 +1207,7 @@ c
 c
       subroutine mmhtfr( fid , name, numdt, numit, 
      &                   tsf,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhtfr
 c
       implicit none
       save
@@ -1162,3 +1221,91 @@ c
 c     
       return
       end
+c
+c
+c
+      subroutine mmhaaw(fid,mname,dtype,numdt,numit,entype,geotype,
+     &                  flt,val,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhaaw
+c
+      implicit none
+      save
+c
+      character *(*) mname
+      integer  val(*)
+      integer fid,numdt,numit,entype,geotype
+      integer dtype,n,cret
+      integer mmhfaaw
+      integer*8 flt(*)
+c
+      cret = mmhfaaw(fid,mname,len(mname),dtype,numdt,numit,entype,
+     &               geotype,flt,val)
+c      
+      return
+      end
+c
+c
+c
+      subroutine mmhaar(fid,mname,dtype,numdt,numit,entype,geotype,
+     &                  flt,val,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhaar
+c
+      implicit none
+      save
+c
+      character *(*) mname
+      integer  val(*)
+      integer fid,numdt,numit,entype,geotype
+      integer dtype,n,cret
+      integer mmhfaar
+      integer*8 flt(*)
+c
+      cret = mmhfaar(fid,mname,len(mname),dtype,numdt,numit,entype,
+     &               geotype,flt,val)
+c      
+      return
+      end
+c
+c
+c
+      subroutine mmhasw(fid,mname,dtype,numdt,numit,entype,geotype,
+     &                  flt,val,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhasw
+c
+      implicit none
+      save
+c
+      character *(*) mname
+      character *(*) val
+      integer fid,numdt,numit,entype,geotype
+      integer dtype,n,cret
+      integer mmhfasw
+      integer*8 flt(*)
+c
+      cret = mmhfasw(fid,mname,len(mname),dtype,numdt,numit,entype,
+     &               geotype,flt,val)
+c      
+      return
+      end
+c
+c
+c
+      subroutine mmhasr(fid,mname,dtype,numdt,numit,entype,geotype,
+     &                  flt,val,cret)
+c     DEC$ ATTRIBUTES DLLEXPORT :: mmhasr
+c
+      implicit none
+      save
+c
+      character *(*) mname
+      character *(*) val
+      integer fid,numdt,numit,entype,geotype
+      integer dtype,n,cret
+      integer mmhfasr
+      integer*8 flt(*)
+c
+      cret = mmhfasr(fid,mname,len(mname),dtype,numdt,numit,entype,
+     &               geotype,flt,val)
+c      
+      return
+      end
