@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -26,7 +26,20 @@
 med_err
 _MEDobjectGetName(const med_idt fid,const char * const path,const med_size ind,char *name) {
 
+  med_err _ret=-1;
 
-  return __MEDobjectGetName(fid, path, ind, name, H5_INDEX_NAME, H5_ITER_NATIVE);
+  if ( H5Literate_by_name(fid,path, H5_INDEX_NAME, H5_ITER_INC,
+			  (hsize_t *) &ind, _MEDcopyName, name,H5P_DEFAULT ) < 0 ) {
+    MED_ERR_(_ret,MED_ERR_VISIT,MED_ERR_DATAGROUP,path);
+    H5Eprint1(stderr);
+    goto ERROR;
+  }
+
+/*   return __MEDobjectGetName(fid, path, ind, name, H5_INDEX_NAME, H5_ITER_NATIVE); */
+/*   return __MEDobjectGetName(fid, path, ind, name, H5_INDEX_CRT_ORDER, H5_ITER_NATIVE); */
+
+  _ret = 0;
+ ERROR:
+  return _ret;
 }
 
