@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -39,7 +39,10 @@
 #define MODE_ACCES MED_CREATION
 #endif
 
+#ifndef USER_INTERLACE
 #define USER_INTERLACE MED_FULL_INTERLACE
+#endif
+
 #define USER_MODE MED_COMPACT
  
 int main (int argc, char **argv)
@@ -107,6 +110,28 @@ int main (int argc, char **argv)
   med_int profil1[2] = { 2, 3 };
   med_int profil2[3] = { 1, 3, 5 };
 
+
+  /* Caractéristiques du champ n° 3 */
+  char nomcha3[MED_TAILLE_NOM+1]  = "champ entier 3";
+  char comp3[3*MED_TAILLE_PNOM+1] = "comp1           comp2           ";
+                                   /*123456789012345612345678901234561234567890123456*/
+  char unit3[3*MED_TAILLE_PNOM+1] = "unit1           unit2           ";
+  med_int ncomp3  = 2;
+  med_int nval3 = 5*4;     /*5 valeurs et 4 noeuds par element*/
+  med_int valr3[5*4*2]   = {0,1, 10,11, 20,21, 30,31,
+                            40,41, 50,51, 60,61, 70,71,
+                            80,81, 90,91, 100,101, 110,111,
+                            120,121, 130,131, 140,141, 150,151,
+                            160,161, 170,171, 180,181, 190,191};    /* 2 composantes*/
+  med_int valr3p[3*4*2]  = {0,1, 10,11, 20,21, 30,31,
+                            80,81, 90,91, 100,101, 110,111,
+                            160,161, 170,171, 180,181, 190,191};    /* 2 composantes*/
+
+
+
+
+
+
   /* ouverture du fichier */
   if ((fid = MEDouvrir("test10.med",MODE_ACCES)) < 0){
     MESSAGE("Erreur à l'ouverture du fichier : ");
@@ -162,7 +187,7 @@ int main (int argc, char **argv)
   if ( MEDchampEcr(fid,maa1,nomcha1,(unsigned char*)valr1_1,USER_INTERLACE,nval1_1,gauss1_1,
 		   2,MED_NOPFL,MED_NO_PFLMOD,MED_MAILLE,MED_TRIA6,MED_NOPDT,"",0.0,MED_NONOR ) < 0) {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha1);ISCRUTE(MED_NOPDT);ISCRUTE(MED_NONOR);SSCRUTE(MED_NOPFL);
+    SSCRUTE(nomcha1);ISCRUTE_int(MED_NOPDT);ISCRUTE_int(MED_NONOR);SSCRUTE(MED_NOPFL);
     SSCRUTE(maa1);
     ret = -1;
   };
@@ -172,7 +197,7 @@ int main (int argc, char **argv)
   if ( MEDchampEcr(fid,maa1,nomcha1,(unsigned char*)valr1_1,USER_INTERLACE,nval1_1,gauss1_1,
 		      1,MED_NOPFL,MED_NO_PFLMOD,MED_MAILLE,MED_TRIA6,MED_NOPDT,"",0.0,MED_NONOR) < 0) {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha1);ISCRUTE(MED_NOPDT);ISCRUTE(MED_NONOR);SSCRUTE(MED_NOPFL);
+    SSCRUTE(nomcha1);ISCRUTE_int(MED_NOPDT);ISCRUTE_int(MED_NONOR);SSCRUTE(MED_NOPFL);
     SSCRUTE(maa1);
     ret = -1;
   };
@@ -183,7 +208,7 @@ int main (int argc, char **argv)
   if ( MEDchampEcr(fid,maa2,nomcha1,(unsigned char*)valr1_2,USER_INTERLACE,nval1_2,gauss1_2,
 		      1,MED_NOPFL,MED_NO_PFLMOD,MED_MAILLE,MED_TRIA6,1,"ms",5.5,MED_NONOR) < 0) {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha1);ISCRUTE(1);ISCRUTE(MED_NONOR);SSCRUTE(MED_NOPFL);
+    SSCRUTE(nomcha1);ISCRUTE_int(1);ISCRUTE_int(MED_NONOR);SSCRUTE(MED_NOPFL);
     SSCRUTE(maa2);
     ret = -1;
   };
@@ -193,7 +218,7 @@ int main (int argc, char **argv)
   if ( MEDchampEcr(fid,maa1,nomcha1,(unsigned char*)valr1_1,USER_INTERLACE,nval1_1,gauss1_1,
 		      2,MED_NOPFL,MED_NO_PFLMOD,MED_MAILLE,MED_TRIA6,1,"ms",5.5,MED_NONOR) < 0) {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha1);ISCRUTE(1);ISCRUTE(MED_NONOR);SSCRUTE(MED_NOPFL);
+    SSCRUTE(nomcha1);ISCRUTE_int(1);ISCRUTE_int(MED_NONOR);SSCRUTE(MED_NOPFL);
     SSCRUTE(maa1);
     ret = -1;
   };
@@ -203,7 +228,7 @@ int main (int argc, char **argv)
   if ( MEDchampEcr(fid,maa3,nomcha1,(unsigned char*)valr1_2,USER_INTERLACE,nval1_2,gauss1_2,
 		   1,MED_NOPFL,MED_NO_PFLMOD,MED_MAILLE,MED_TRIA6,1,"ms",5.5,2) < 0) {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha1);ISCRUTE(1);ISCRUTE(2);SSCRUTE(MED_NOPFL);
+    SSCRUTE(nomcha1);ISCRUTE_int(1);ISCRUTE_int(2);SSCRUTE(MED_NOPFL);
     SSCRUTE(maa3);
     ret = -1;
   };
@@ -222,7 +247,7 @@ int main (int argc, char **argv)
   if ( MEDchampEcr(fid,maa1, nomcha1,(unsigned char*)valr1_3p,USER_INTERLACE,nval1_3,MED_NOGAUSS,
 		   MED_ALL,nomprofil1,USER_MODE,MED_MAILLE,MED_TRIA6,2,"ms",5.6,2) < 0) {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha1);ISCRUTE(2);ISCRUTE(2);SSCRUTE(nomprofil1);
+    SSCRUTE(nomcha1);ISCRUTE_int(2);ISCRUTE_int(2);SSCRUTE(nomprofil1);
     SSCRUTE(maa1);SSCRUTE(MED_NOLIEN);
     ret = -1;
   };
@@ -232,7 +257,7 @@ int main (int argc, char **argv)
   if ( MEDchampEcr(fid,maa2, nomcha1,(unsigned char*)valr1_2p,USER_INTERLACE,nval1_2,gauss1_2,
 		   MED_ALL,nomprofil1,USER_MODE,MED_MAILLE,MED_TRIA6,2,"ms",5.6,2) < 0) {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha1);ISCRUTE(2);ISCRUTE(2);SSCRUTE(nomprofil1);
+    SSCRUTE(nomcha1);ISCRUTE_int(2);ISCRUTE_int(2);SSCRUTE(nomprofil1);
     SSCRUTE(maa1);SSCRUTE(MED_NOLIEN);
     ret = -1;
   }; 
@@ -242,7 +267,7 @@ int main (int argc, char **argv)
   if ( MEDchampEcr(fid,maa1,nomcha1,(unsigned char*)valr1_3p,USER_INTERLACE,nval1_3,MED_NOGAUSS,
 		   2,nomprofil1,USER_MODE,MED_MAILLE,MED_TRIA6,3,"ms",5.7,2) < 0)  {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha1);ISCRUTE(2);ISCRUTE(2);SSCRUTE(nomprofil1);
+    SSCRUTE(nomcha1);ISCRUTE_int(2);ISCRUTE_int(2);SSCRUTE(nomprofil1);
     SSCRUTE(maa1);SSCRUTE(MED_NOLIEN);
     ret = -1;
   };
@@ -256,7 +281,7 @@ int main (int argc, char **argv)
   if (MEDchampEcr(fid,maa1,nomcha2,(unsigned char*)valr2,USER_INTERLACE,nval2,MED_NOGAUSS,
 		  1,MED_NOPFL,MED_NO_PFLMOD,MED_ARETE,MED_SEG2,MED_NOPDT,"",0.0,MED_NONOR) < 0)  {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha2);ISCRUTE(MED_NOPDT);ISCRUTE(MED_NONOR);SSCRUTE(MED_NOPFL);
+    SSCRUTE(nomcha2);ISCRUTE_int(MED_NOPDT);ISCRUTE_int(MED_NONOR);SSCRUTE(MED_NOPFL);
     SSCRUTE(maa1);SSCRUTE(MED_NOLIEN);
     ret = -1;
   };
@@ -267,7 +292,7 @@ int main (int argc, char **argv)
   if (MEDchampEcr(fid,maa1,nomcha2,(unsigned char*)valr2,USER_INTERLACE,nval2,MED_NOGAUSS,
                       2,MED_NOPFL,MED_NO_PFLMOD,MED_NOEUD,0,MED_NOPDT,"",0.0,MED_NONOR) < 0)  {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha2);ISCRUTE(MED_NOPDT);ISCRUTE(MED_NONOR);SSCRUTE(MED_NOPFL);
+    SSCRUTE(nomcha2);ISCRUTE_int(MED_NOPDT);ISCRUTE_int(MED_NONOR);SSCRUTE(MED_NOPFL);
     SSCRUTE(maa1);SSCRUTE(MED_NOLIEN);
     ret = -1;
   };
@@ -277,7 +302,7 @@ int main (int argc, char **argv)
   if ( MEDchampEcr(fid,maa1,nomcha2,(unsigned char*)valr2,USER_INTERLACE,nval2,MED_NOGAUSS,
 		   3,MED_NOPFL,MED_NO_PFLMOD,MED_FACE,MED_TRIA6,MED_NOPDT,"",0.0,MED_NONOR) < 0 ) {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha2);ISCRUTE(MED_NOPDT);ISCRUTE(MED_NONOR);SSCRUTE(MED_NOPFL);
+    SSCRUTE(nomcha2);ISCRUTE_int(MED_NOPDT);ISCRUTE_int(MED_NONOR);SSCRUTE(MED_NOPFL);
     SSCRUTE(maa1);SSCRUTE(MED_NOLIEN);
     ret = -1;
   };
@@ -294,11 +319,46 @@ int main (int argc, char **argv)
   if ( MEDchampEcr(fid,maa1,nomcha2,(unsigned char*)valr2p,USER_INTERLACE,nval2,MED_NOGAUSS,
                       3,nomprofil2,USER_MODE,MED_MAILLE,MED_TRIA6,MED_NOPDT,"",0.0,MED_NONOR) < 0 ) {
     MESSAGE("Erreur à l'écriture du champ : ");
-    SSCRUTE(nomcha2);ISCRUTE(MED_NOPDT);ISCRUTE(MED_NONOR);SSCRUTE(MED_NOPFL);
+    SSCRUTE(nomcha2);ISCRUTE_int(MED_NOPDT);ISCRUTE_int(MED_NONOR);SSCRUTE(MED_NOPFL);
     SSCRUTE(maa1);SSCRUTE(MED_NOLIEN);
     ret = -1;
   };
 
+  /* creation du champ entier n°3 */
+  if ( MEDchampCr(fid,nomcha3,MED_INT32,comp3,unit3,ncomp3) < 0) {
+    MESSAGE("Erreur à la création du champ : ");SSCRUTE(nomcha3);
+    ret = -1;
+  };
+  
+  /* Ecriture du champ n° 3 */
+
+  /* enregistre la composante n°1 des éléments de valr3, et n'utilise ni pas de temps ni n° d'ordre */
+  if (MEDchampEcr(fid,maa1,nomcha3,(unsigned char*)valr3,USER_INTERLACE,nval3,MED_NOGAUSS,
+		  1,MED_NOPFL,MED_NO_PFLMOD,MED_NOEUD_MAILLE,MED_QUAD4,MED_NOPDT,"",0.0,MED_NONOR) < 0)  {
+    MESSAGE("Erreur à l'écriture du champ : ");
+    SSCRUTE(nomcha3);ISCRUTE_int(MED_NOPDT);ISCRUTE_int(MED_NONOR);SSCRUTE(MED_NOPFL);
+    SSCRUTE(maa1);SSCRUTE(MED_NOLIEN);
+    ret = -1;
+  };
+
+  /* enregistre les composantes des éléments de valr3, et n'utilise ni pas de temps ni n° d'ordre */
+  if (MEDchampEcr(fid,maa2,nomcha3,(unsigned char*)valr3,USER_INTERLACE,nval3,MED_NOGAUSS,
+		  MED_ALL,MED_NOPFL,MED_NO_PFLMOD,MED_NOEUD_MAILLE,MED_QUAD4,MED_NOPDT,"",0.0,MED_NONOR) < 0)  {
+    MESSAGE("Erreur à l'écriture du champ : ");
+    SSCRUTE(nomcha3);ISCRUTE_int(MED_NOPDT);ISCRUTE_int(MED_NONOR);SSCRUTE(MED_NOPFL);
+    SSCRUTE(maa2);SSCRUTE(MED_NOLIEN);
+    ret = -1;
+  };
+
+  /* enregistre les composantes des éléments de valr3, et n'utilise ni pas de temps ni n° d'ordre */
+  if (MEDchampEcr(fid,maa3,nomcha3,(unsigned char*)valr3p,USER_INTERLACE,nval3,MED_NOGAUSS,
+		  MED_ALL,nomprofil2,USER_MODE,MED_NOEUD_MAILLE,MED_QUAD4,MED_NOPDT,"",0.0,MED_NONOR) < 0)  {
+    MESSAGE("Erreur à l'écriture du champ : ");
+    SSCRUTE(nomcha3);ISCRUTE_int(MED_NOPDT);ISCRUTE_int(MED_NONOR);SSCRUTE(nomprofil2);
+    SSCRUTE(maa3);SSCRUTE(MED_NOLIEN);
+    ret = -1;
+  };
+
 
   /* fermeture du fichier */
   if ( MEDfermer(fid) < 0 ) ret=-1;
