@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -41,35 +41,35 @@ int main (int argc, char **argv)
 {
   med_err ret = 0;
   med_idt fid;
-  char des[MED_COMMENT_SIZE+1]="Ceci est un courte description du mon fichier test1.med";
+  char des[MED_COMMENT_SIZE+1]="Ceci est une courte description de mon fichier test1.med";
 
-  /* creation du fichier "test1.med" */
+  /* Creation du fichier "test1.med" */
   fid = MEDfileOpen("test1.med",MODE_ACCES);
   if (fid < 0) {
     MESSAGE("Erreur à la creation du fichier");
     return -1;
   }
 
-  /* ecriture d'un en-tete dans le fichier */
+  /* Ecriture d'un en-tete dans le fichier */
   if (MEDfileCommentWr(fid,des) < 0) {
     MESSAGE("Erreur à l'ecriture de l'en-tete du fichier");
     ret = -1;
   }
 
-  /* fermeture du fichier */
+  /* Fermeture du fichier */
   if ((ret = MEDfileClose(fid)) < 0) {
     MESSAGE("Erreur à la fermeture du fichier");
     return -1;
   }
 
-  /* re-ouverture du fichier en lecture seule */
+  /* Re-ouverture du fichier en lecture seule */
   fid = MEDfileOpen("test1.med",MED_ACC_RDONLY);
   if (fid < 0) {
     MESSAGE("Erreur à l'ouverture du fichier en mode MED_LECTURE");
     return -1;
   }
 
-  /* fermeture du fichier */
+  /* Fermeture du fichier */
   if (MEDfileClose(fid) < 0)
     ret = -1;
 
