@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -304,7 +304,7 @@ med_err getFieldsOn(med_idt fid, char * nomcha, med_field_type typcha, med_int n
 
   int j,k,l,m,n,nb_geo=0;
   med_int nbpdtnor=0,pflsize,*pflval,ngauss=0,ngroup,*vale=NULL,nval;
-  med_int numdt=0,numo=0,_nbofprofile;
+  med_int numdt=0,numo=0,_nprofile;
   med_float *valr=NULL,dt=0.0;
   med_err ret=0;
   char pflname [MED_NAME_SIZE+1]="";
@@ -355,7 +355,7 @@ med_err getFieldsOn(med_idt fid, char * nomcha, med_field_type typcha, med_int n
 	ret = -1; continue;
       }
 
-      if ( (_nbofprofile = MEDfieldnProfile(fid,nomcha,numdt,numo,entite,type_geo[k],
+      if ( (_nprofile = MEDfieldnProfile(fid,nomcha,numdt,numo,entite,type_geo[k],
 					    pflname,locname   ) ) < 0 ) {
 	MESSAGE("Erreur a la demande du nombre de profils referencés par le champ : ");
 	SSCRUTE(nomcha);
@@ -365,7 +365,7 @@ med_err getFieldsOn(med_idt fid, char * nomcha, med_field_type typcha, med_int n
 	ret = -1; continue;
       };
 
-      for (l=0;l<_nbofprofile;l++) {
+      for (l=0;l<_nprofile;l++) {
 
 
 	if ( (nval = MEDfieldnValueWithProfile(fid, nomcha, numdt, numo, entite, type_geo[k],
