@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -40,6 +40,7 @@ int main (int argc, char **argv)
   med_idt   fid=0;
   med_int   majeur=0, mineur=0, release=0;
   med_bool  hdfok=MED_FALSE,medok=MED_FALSE;
+  char      medversion[MED_SNAME_SIZE+1]="";
 
   /* Creation du fichier test18.med */
   if ((fid = MEDfileOpen("test18.med",MODE_ACCES)) < 0) {
@@ -95,6 +96,12 @@ int main (int argc, char **argv)
   }
   fprintf(stdout,"- Ce fichier a ete cree avec MED "IFORMAT"."IFORMAT"."IFORMAT" \n",majeur,mineur,release); 
 
+  if ( MEDfileStrVersionRd(fid, medversion) < 0 ) {
+    MESSAGE("Erreur à la lecture de la version du fichier MED");
+    return -1;
+  }
+  fprintf(stdout,"- Ce fichier a ete cree avec %s\n",medversion);
+
   if (MEDfileClose(fid) < 0) {
     MESSAGE("Erreur a la fermeture du fichier");
     return -1;
