@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -44,6 +44,7 @@ int main (int argc, char **argv)
   med_bool hdfok=MED_FALSE, medok=MED_FALSE;
   char axisname[3*MED_SNAME_SIZE+1]="";
   char axisunit[3*MED_SNAME_SIZE+1]="";
+  int  cstp = 0;
 
   strcat(axisname,"x               ");
   strcat(axisname,"y               ");
@@ -108,43 +109,6 @@ int main (int argc, char **argv)
     ret = -1;
   }
 
-  if ( MEDmeshComputationStepCr(fid,"maa1",MED_NO_DT,MED_NO_IT,
-			      MED_NO_DT,MED_NO_IT,0) < 0) {
-    MESSAGE("Erreur a la creation du premier pas de temps du maillage maa1");
-/*     ret = -1; */
-  }
-
- if ( MEDmeshComputationStepCr(fid,"maa1",MED_NO_DT,MED_NO_IT,
-			      1,3,1.1) < 0) {
-    MESSAGE("Erreur a la creation du second pas de temps du maillage maa1");
-/*     ret = -1; */
-  }
-
- if ( MEDmeshComputationStepCr(fid,"maa1",MED_NO_DT,MED_NO_IT,
-			      0,0,1.1) < 0) {
-    MESSAGE("Erreur a la creation du second pas de temps du maillage maa1");
-/*     ret = -1; */
-  }
-
- if ( MEDmeshComputationStepCr(fid,"maa1",MED_NO_DT,MED_NO_IT,
-			      0,-1,1.1) < 0) {
-    MESSAGE("Erreur a la creation du second pas de temps du maillage maa1");
-/*     ret = -1; */
-  }
-
- if ( MEDmeshComputationStepCr(fid,"maa1",MED_NO_DT,MED_NO_IT,
-			      -1,20,1.1) < 0) {
-    MESSAGE("Erreur a la creation du second pas de temps du maillage maa1");
-/*     ret = -1; */
-  }
-
- if ( MEDmeshComputationStepCr(fid,"maa1",MED_NO_DT,MED_NO_IT,
-			      20,-1,1.1) < 0) {
-    MESSAGE("Erreur a la creation du second pas de temps du maillage maa1");
-/*     ret = -1; */
-  }
-
-
   /* Creation du maillage "maa2" de type MED_UNSTRUCTURED_MESH
      et de dimension 2 dans un espace de dimension 3*/
   if (MEDmeshCr(fid,"maa2",3,2,MED_UNSTRUCTURED_MESH,
@@ -154,8 +118,98 @@ int main (int argc, char **argv)
     ret = -1;
   }
 
-  /* Creation du maillage "maa3" de type MED_STRUCTURED_MESH
-     et de dimension 1 */
+  cstp = 1;
+  if ( MEDmeshComputationStepCr(fid,"maa2",MED_NO_DT,MED_NO_IT,
+			      MED_NO_DT,MED_NO_IT,0) < 0) {
+    fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+  cstp++;
+  if ( MEDmeshComputationStepCr(fid,"maa2",MED_NO_DT,MED_NO_IT,
+			      1,3,1.1) < 0) {
+    fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+  cstp++;
+  if ( MEDmeshComputationStepCr(fid,"maa2",MED_NO_DT,MED_NO_IT,
+				0,0,1.1) < 0) {
+    fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+  cstp++;
+  if ( MEDmeshComputationStepCr(fid,"maa2",MED_NO_DT,MED_NO_IT,
+				0,-1,1.1) < 0) {
+    fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+  cstp++;
+ if ( MEDmeshComputationStepCr(fid,"maa2",MED_NO_DT,MED_NO_IT,
+			      -1,20,1.1) < 0) {
+    fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+ cstp++;
+ fprintf(stderr,"Erreur attendue : \n");
+ if ( MEDmeshComputationStepCr(fid,"maa2",MED_NO_DT,MED_NO_IT,
+			      20,-1,1.1) < 0) {
+   fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+ cstp++;
+ fprintf(stderr,"Erreur attendue : \n");
+ if ( MEDmeshComputationStepCr(fid,"maa2",0,0,
+			      20,-1,1.1) < 0) {
+   fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+ cstp++;
+ if ( MEDmeshComputationStepCr(fid,"maa2",20,-1,
+			      20,-1,1.1) < 0) {
+   fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+ cstp++;
+ fprintf(stderr,"Erreur attendue car l'tape a t cre prcedement: \n");
+ if ( MEDmeshComputationStepCr(fid,"maa2",1,3,
+			       20,-1,1.1) < 0) {
+   fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+ cstp++;
+ if ( MEDmeshComputationStepCr(fid,"maa2",20,-1,
+			       20,10,1.1) < 0) {
+   fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+ cstp++;
+ fprintf(stderr,"Erreur attendue car cette tape ne se place pas en dernire position : \n");
+ if ( MEDmeshComputationStepCr(fid,"maa2",20,5,
+			       20,5,1.1) < 0) {
+   fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+ cstp++;
+ fprintf(stderr,"Erreur attendue car la cration de cette tape chevauche la (20,10) : \n");
+ if ( MEDmeshComputationStepCr(fid,"maa2",20,-1,
+			       20,20,1.1) < 0) {
+   fprintf(stderr,"Erreur  la cration de l'tape de calcul n%d du maillage maa2\n",cstp);
+/*     ret = -1; */
+  }
+
+
+  /* Creation du maillage "maa3" de type MED_UNSTRUCTURED_MESH
+     et de dimension 1 un espace de dimension 3*/
   if (MEDmeshCr(fid,"maa3",3,1,MED_UNSTRUCTURED_MESH,
 		"un troisieme maillage","s",MED_SORT_DTIT,
 		MED_CARTESIAN,axisname,axisunit) < 0) {
