@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -48,7 +48,7 @@ int main (int argc, char **argv)
   med_int    mdim= 0, sdim=0, axe=0, j=0;
   med_float *indices=NULL;
   med_int    nind=0,nmaa=0, nnoeuds=0;
-  med_bool   chgt=MED_FALSE,trsf=MED_FALSE;;
+  med_bool   chgt=MED_FALSE,trsf=MED_FALSE;
   char maa     [MED_NAME_SIZE+1]        ="";
   char axisname[MAXDIM*MED_SNAME_SIZE+1]="";
   char axisunit[MAXDIM*MED_SNAME_SIZE+1]="";
