@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -54,7 +54,7 @@ int main (int argc, char **argv)
   med_int *nufatr3;
   char maa[MED_NAME_SIZE+1] ="maa1";
   med_int mdim=0,sdim=0;
-  med_bool inoele=MED_FALSE,inuele=MED_FALSE,chgt=MED_FALSE,trsf=MED_FALSE;;
+  med_bool inoele=MED_FALSE,inuele=MED_FALSE,chgt=MED_FALSE,trsf=MED_FALSE;
   med_int tse2,ttr3;
   char str[MED_SNAME_SIZE+1];
   med_int flt[2] = { 2, 3 }, fltsize=2;
