@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -88,9 +88,8 @@ int main (int argc, char **argv)
      - 2 familles de noeuds (1,2) */
   nfame = 3;
   for (i=0;i<nfame;i++) {
-    strcpy(nomfam,"FAMILLE_ELEMENT_");
     numfam = -(i+1);
-    sprintf(nomfam,"%s"IFORMAT,nomfam,-numfam);
+    sprintf(nomfam,"%s"IFORMAT,"FAMILLE_ELEMENT_",-numfam);
     strcpy(gro,"groupe1");
     ngro = 1;
     printf("%s - "IFORMAT" - "IFORMAT" \n",nomfam,numfam,
@@ -104,9 +103,8 @@ int main (int argc, char **argv)
 
   nfamn = 2;
   for (i=0;i<nfamn;i++) {
-    strcpy(nomfam,"FAMILLE_NOEUD_");
     numfam = i+1;
-    sprintf(nomfam,"%s"IFORMAT,nomfam,numfam);
+    sprintf(nomfam,"%s"IFORMAT,"FAMILLE_NOEUD_",numfam);
     strcpy(gro,"groupe1");
     ngro = 1;
     if (MEDfamilyCr(fid,maa,nomfam,numfam,ngro,gro) < 0) {
