@@ -1,6 +1,6 @@
 C*  This file is part of MED.
 C*
-C*  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+C*  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
 C*  MED is free software: you can redistribute it and/or modify
 C*  it under the terms of the GNU Lesser General Public License as published by
 C*  the Free Software Foundation, either version 3 of the License, or
@@ -60,12 +60,6 @@ C	CHAMP N°2
 	integer      ncomp2, nval2
 	integer      valr2(5*3),   valr2p(3*3)
 
-C	CHAMP N°3
-	character*32 nomcha3
-	character*16 comp3(2), unit3(2)
-	integer      ncomp3, nval3
-	integer      valr3(5*4*2),   valr3p(3*4*2)
-
 C	PROFILS UTILISES
 	character*32 nomprofil1
         integer      profil1(2) , profil2(3)
@@ -94,9 +88,6 @@ C       MODEL N°3 DE LOC. DES PTS DE GAUSS PR CHAMP1
 C       CHAMP N°2
 	parameter ( nomcha2="champ entier")
         parameter ( ncomp2 = 3, nval2= 5  )
-C       CHAMP N°3
-	parameter ( nomcha3="champ entier 3")
-        parameter ( ncomp3 = 2, nval3= 5*4  )
 C       PROFILS
 	parameter ( nomprofil1  = "PROFIL(champ(1))" )
 	
@@ -123,19 +114,6 @@ C       CHAMP N°2
         data unit2 /"unit1","unit2", "unit3"/
 	data valr2 / 0,1,2, 10,11,12, 20,21,22, 30,31,32, 40,41,42 /
 	data valr2p / 0,1,2,           20,21,22,           40,41,42 /
-C       CHAMP N°3
-	data comp3 /"comp1", "comp2"/
-        data unit3 /"unit1","unit2"/
-	data valr3 / 0,1, 10,11, 20,21, 30,31,
-     1           40,41, 50,51, 60,61, 70,71,
-     1           80,81, 90,91, 100,101, 110,111,
-     1           120,121, 130,131, 140,141, 150,151,
-     1           160,161, 170,171, 180,181, 190,191 /
-	data valr3p / 0,1, 10,11, 20,21, 30,31,
-     1            80,81, 90,91, 100,101, 110,111,
-     1            160,161, 170,171, 180,181, 190,191 /
-
-
 C       PROFILS
 	data profil1 /2,3/
 	data profil2 /1,3,5/
@@ -202,21 +180,21 @@ C     ** creation du champ réel n°1                        **
 	call efchac(fid,nomcha1,MED_FLOAT64,comp1,unit1,ncomp1,ret)
         if (ret .ne. 0 ) then
 	   print *,'Erreur à la création du champ : ', nomcha1
-	   call efexit(-1)
+	   ret = -1
 	endif
  	     
 C     ** creation du champ entier n°2                      **
 	call efchac(fid,nomcha2,MED_INT32,comp2,unit2,ncomp2,ret)
         if (ret .ne. 0 ) then
 	   print *,'Erreur à la création du champ : ', nomcha2
-	   call efexit(-1)
+	   ret = -1
 	endif
  
 C     ** creation du lien au fichier distant contenant maa2 **
 	call efliee(fid,lien_maa2,maa2,ret)
         if (ret .ne. 0 ) then
 	   print *,'Erreur à la création du lien : ', lien_maa2
-	   call efexit(-1)
+	   ret = -1
 	endif
  
 C     ** creation de la localisation des points de Gauss modèle n°1 **
@@ -224,7 +202,7 @@ C     ** creation de la localisation des points de Gauss modèle n°1 **
      1	             ngauss1_1, gscoo1_1, wg1_1, gauss1_1, ret)
         if (ret .ne. 0 ) then
 	   print *,'Erreur à la création du modèle n°1 : ', gauss1_1
-	   call efexit(-1)
+	   ret = -1
 	endif
 
 C     ** creation de la localisation des points de Gauss modèle n°2 **
@@ -232,7 +210,7 @@ C     ** creation de la localisation des points de Gauss modèle n°2 **
      1	             ngauss1_2, gscoo1_2, wg1_2, gauss1_2, ret)
         if (ret .ne. 0 ) then
 	   print *,'Erreur à la création du modèle n°2 : ', gauss1_2
-	   call efexit(-1)
+	   ret = -1
 	endif
 
 	
@@ -246,7 +224,7 @@ C     ** - pas de pas de temps, ni de numero d'ordre
      3               MED_NOPDT,dtunit1,dt,MED_NONOR,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.1'
-	   call efexit(-1)
+	   ret = -1
 	endif
 
 C     ** Nouvelle Ecriture du champ reel en mode remplacement
@@ -258,7 +236,7 @@ C     ** - pas de pas de temps, ni de numero d'ordre
      3               MED_NOPDT,dtunit1,dt,MED_NONOR,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.2'
-	   call efexit(-1)
+	   ret = -1
 	endif
 	 
 C     ** Ecriture sur le champ reel
@@ -273,7 +251,7 @@ C     ** - maa2 est distant
      3               1,"ms",dt,MED_NONOR,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.3'
-	   call efexit(-1)
+	   ret = -1
 	endif
 
 C     ** Ecriture sur le champ reel
@@ -288,7 +266,7 @@ C     ** - maa1 est local
      3               1,"ms",dt,MED_NONOR,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.4'
-	   call efexit(-1)
+	   ret = -1
 	endif
 
       
@@ -304,7 +282,7 @@ C     ** - maa3 est local
      3               1,"ms",dt,2,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.5'
-	   call efexit(-1)
+	   ret = -1
 	endif
     
 C     ** Creation de profil
@@ -312,7 +290,7 @@ C     ** - qui selectionne uniquement le 2e element du tableau valr1
 	call efpfle(fid,profil1,1,nomprofil1,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à la création du profil : ', nomprofil1
-	   call efexit(-1)
+	   ret = -1
 	endif
 
 
@@ -328,7 +306,7 @@ C     ** - Numero d'ordre = 2
      3               2,"ms",dt,2,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.6'
-	   call efexit(-1)
+	   ret = -1
 	endif
 
 C     ** Ecriture du champ reel 
@@ -343,7 +321,7 @@ C     ** - Numero d'ordre = 2
      3               2,"ms",dt,2,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.7'
-	   call efexit(-1)
+	   ret = -1
 	endif
 
 
@@ -359,7 +337,7 @@ C     ** - Numero d'ordre = 2
      3               3,"ms",dt,2,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.8'
-	   call efexit(-1)
+	   ret = -1
 	endif
 
 
@@ -372,7 +350,7 @@ C     ** - pas de pas de temps, ni de numero d'ordre
      1               MED_SEG2,MED_NOPDT,nounit,dt,MED_NONOR,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha2,'et.1'
-	   call efexit(-1)
+	   ret = -1
 	endif   
 
 C     ** Ecriture du champ entier n°2
@@ -385,7 +363,7 @@ C     **   le type d'élément (aucun sens phys.))
      1               0,MED_NOPDT,nounit,dt,MED_NONOR,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha2,'et.2'
-	   call efexit(-1)
+	   ret = -1
 	endif   
 
 
@@ -399,7 +377,7 @@ C     **   le type d'élément (aucun sens phys.))
      1               MED_TRIA6,MED_NOPDT,nounit,dt,MED_NONOR,ret)
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du champ : ', nomcha2,'et.3'
-	   call efexit(-1)
+	   ret = -1
 	endif   
 
 C     ** Creation de profil
@@ -408,7 +386,7 @@ C     ** - selectionne les elements 1,3,5 du tableau valr2
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du profil : ',
      1              'profil2(champ2)'
-	   call efexit(-1)
+	   ret = -1
 	endif   
 
 
@@ -424,57 +402,7 @@ C     **   le type d'élément (aucun sens phys.))
 	if (ret .ne. 0 ) then
 	   print *,'Erreur à l''écriture du profil : ',
      1             'profil2(champ2)'
-	   call efexit(-1)
-	endif   
-
-C     ** creation du champ entier n°3                      **
-	call efchac(fid,nomcha3,MED_INT32,comp3,unit3,ncomp3,ret)
-        if (ret .ne. 0 ) then
-	   print *,'Erreur à la création du champ : ', nomcha3
-	   call efexit(-1)
-	endif
- 
-C     ** Ecriture du champ entier n°3
-C     ** - 1ere composante des éléments de valr3
-C     ** - pas de pas de temps, ni de numero d'ordre
-C     ** - pour des raisons de complétude des tests on change
-C     **   le type d'élément (aucun sens phys.))
-	call efchae(fid,maa1,nomcha3,valr3,USER_INTERLACE,nval3,
-     1     MED_NOGAUSS,1,MED_NOPFL,MED_NO_PFLMOD,MED_NOEUD_MAILLE,
-     1               MED_QUAD4,MED_NOPDT,nounit,dt,MED_NONOR,ret)
-	if (ret .ne. 0 ) then
-	   print *,'Erreur à l''écriture du champ : ', nomcha3,'et.1'
-	   call efexit(-1)
-	endif   
-
-C     ** Ecriture du champ entier n°3
-C     ** - les composantes des éléments de valr3
-C     ** - pas de pas de temps, ni de numero d'ordre
-C     ** - pour des raisons de complétude des tests on change
-C     **   le type d'élément (aucun sens phys.))
-	call efchae(fid,maa2,nomcha3,valr3,USER_INTERLACE,nval3,
-     1     MED_NOGAUSS,MED_ALL,MED_NOPFL,MED_NO_PFLMOD,
-     1               MED_NOEUD_MAILLE,
-     1               MED_QUAD4,MED_NOPDT,nounit,dt,MED_NONOR,ret)
-	if (ret .ne. 0 ) then
-	   print *,'Erreur à l''écriture du champ : ', nomcha3,'et.2'
-	   call efexit(-1)
-	endif   
-
-C     ** Ecriture du champ entier n°3
-C     ** - les composantes des éléments de valr3
-C     ** - pas de pas de temps, ni de numero d'ordre
-C     ** - profils
-C     ** - pour des raisons de complétude des tests on change
-C     **   le type d'élément (aucun sens phys.))
-	call efchae(fid,maa3,nomcha3,valr3p,USER_INTERLACE,nval3,
-     1     MED_NOGAUSS,MED_ALL,"PROFIL(champ2)",USER_MODE,
-     1               MED_NOEUD_MAILLE,
-     1               MED_QUAD4,MED_NOPDT,nounit,dt,MED_NONOR,ret)
-	if (ret .ne. 0 ) then
-	   print *,'Erreur à l''écriture du profil : ',
-     1             'profil2(champ2)'
-	   call efexit(-1)
+	   ret = -1
 	endif   
 
 C     ** Fermeture du fichier *
