@@ -3,14 +3,16 @@
 file=test31
 ${CP} ${BUILDDIR}/test4.med ${BUILDDIR}/${file}.med && chmod 644 ${BUILDDIR}/${file}.med
 ${EXECDIR}/${file} test31.med > /dev/null 2>&1 && ${H5DUMP} ${BUILDDIR}/${file}.med > ${BUILDDIR}/${file}.dump  && ( \
-sed -e 's/DATATYPE  H5T_STD_I32BE//g' -e 's/DATATYPE  H5T_STD_I32LE//g'	 \
-    -e 's/DATATYPE  H5T_STD_I64BE//g' -e 's/DATATYPE  H5T_STD_I64LE//g'  \
-    -e 's/DATATYPE  H5T_IEEE_F64BE//g' -e 's/DATATYPE  H5T_IEEE_F64LE//g'  \
+sed -e 's/H5T_STD_I32BE//g' -e 's/H5T_STD_I32LE//g'	 \
+    -e 's/H5T_STD_I64BE//g' -e 's/H5T_STD_I64LE//g'  \
+    -e 's/H5T_IEEE_F64BE//g' -e 's/H5T_IEEE_F64LE//g'  \
+    -e 's/H5T_STD_I8LE//g' -e 's/H5T_STD_U8BE//g'  \
     -e 's/HDF5.*{//g' \
 	${BUILDDIR}/${file}.dump > ${BUILDDIR}/${file}.dump.tmp && \
-sed -e 's/DATATYPE  H5T_STD_I32BE//g' -e 's/DATATYPE  H5T_STD_I32LE//g'	 \
-    -e 's/DATATYPE  H5T_STD_I64BE//g' -e 's/DATATYPE  H5T_STD_I64LE//g'  \
-    -e 's/DATATYPE  H5T_IEEE_F64BE//g' -e 's/DATATYPE  H5T_IEEE_F64LE//g'  \
+sed -e 's/H5T_STD_I32BE//g' -e 's/H5T_STD_I32LE//g'	 \
+    -e 's/H5T_STD_I64BE//g' -e 's/H5T_STD_I64LE//g'  \
+    -e 's/H5T_IEEE_F64BE//g' -e 's/H5T_IEEE_F64LE//g'  \
+    -e 's/H5T_STD_I8LE//g' -e 's/H5T_STD_U8BE//g'  \
     -e 's/HDF5.*{//g' \
 	 ${BUILDDIR}/dumps.ref/${file}.dump > ${BUILDDIR}/${file}.dump.ref && \
 diff ${BUILDDIR}/${file}.dump.ref ${BUILDDIR}/${file}.dump.tmp && \
