@@ -1,6 +1,6 @@
 C*  This file is part of MED.
 C*
-C*  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+C*  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
 C*  MED is free software: you can redistribute it and/or modify
 C*  it under the terms of the GNU Lesser General Public License as published by
 C*  the Free Software Foundation, either version 3 of the License, or
@@ -381,7 +381,23 @@ C     ** - Numero d'ordre = 2
      &              nent1_3,valr1_3p,ret)
 	print *,ret
 	if (ret .ne. 0 ) then
-	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.8'
+	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.8a'
+	   call efexit(-1)
+	endif
+
+C     ** Ecriture du champ reel 
+C     ** - 1e composante du 2e element du champ
+C     ** - Extrait a partir du profil de nom "profil1(1)"
+C     ** - Pas de temps = 5.7
+C     ** - Numero d'ordre = 2 
+	dt = 5.7
+	call mfdrpw(fid,nomcha1,3,2,dt,MED_CELL,MED_TRIA6,
+     &              USER_MODE, nomprofil1, MED_NO_LOCALIZATION,
+     &              USER_INTERLACE,1,
+     &              nent1_3,valr1_3p,ret)
+	print *,ret
+	if (ret .ne. 0 ) then
+	   print *,'Erreur à l''écriture du champ : ', nomcha1,'et.8b'
 	   call efexit(-1)
 	endif
 
