@@ -1,6 +1,6 @@
 !*  This file is part of MED.
 !*
-!*  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+!*  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
 !*  MED is free software: you can redistribute it and/or modify
 !*  it under the terms of the GNU Lesser General Public License as published by
 !*  the Free Software Foundation, either version 3 of the License, or
@@ -26,7 +26,7 @@
 program test11
 
   implicit none
-  include 'med.hf'
+  include 'med.hf90'
 
 
   integer       cret,ret,lret,retmem, fid
@@ -272,7 +272,7 @@ end program test11
 
 integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage, ncst)
   implicit none
-  include 'med.hf'
+  include 'med.hf90'
 
   integer      ::fid,typcha,ncomp,entite,stockage, ncst
   character(LEN=*)  nomcha
@@ -435,7 +435,7 @@ integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage, ncst)
                 & 'Il y a ',nent,' valeurs en mode ',USER_MODE, &
                 & '. Chaque entite ',TRIM(FMED_ENTITE_MAILLAGE_AFF(entite)), &
                 & ' de type geometrique ',TRIM(AFF(k)),' associes au profil |',&
-                & TRIM(pflname)//'| a ',ngauss,' valeur(s) par entité une localization de nom |',TRIM(locname)//'|'
+                & TRIM(pflname)//'| a ',ngauss,' valeur(s) par entité, et une localization de nom |',TRIM(locname)//'|'
 
            ! **Lecture des valeurs du champ **
            if (typcha .eq. MED_FLOAT64) then
