@@ -1,6 +1,6 @@
 !*  This file is part of MED.
 !*
-!*  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+!*  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
 !*  MED is free software: you can redistribute it and/or modify
 !*  it under the terms of the GNU Lesser General Public License as published by
 !*  the Free Software Foundation, either version 3 of the License, or
@@ -25,7 +25,7 @@
 program test30
   
   implicit none
-  include 'med.hf'
+  include 'med.hf90'
 !
 !
   integer      ret,cret,fid,edim
@@ -103,7 +103,7 @@ program test30
    call mficlo (fid,cret)
    print '(I2)',cret
    
-   call flush(6)
+!   call flush(6)
 
 
 !  ** Code retour
@@ -115,7 +115,7 @@ program test30
  subroutine affCorr(fid,maa,jnt,entlcl,geolcl,entdst,geodst)
    
    implicit none
-   include 'med.hf'
+   include 'med.hf90'
 
    character*(*) maa,jnt
    character*200 des;
@@ -134,7 +134,7 @@ program test30
       print '(A,I4,A,I4,A,I4,A,I4,A)','correspondance entre les types : (',entlcl,'/',geolcl,') et (',entdst,'/',geodst,')'
       print '(A,I4)','nombre de type de couples d''entite en regard ',ncor
 
-      call flush(6)
+!      call flush(6)
       
       allocate(cortab(ncor*2),STAT=ret)
       call msdcrr(fid,maa,jnt,MED_NO_DT,MED_NO_IT,entlcl,geolcl,entdst,geodst,cortab,cret)
