@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -17,8 +17,6 @@
 
 #define MAX(a,b) ((a) > (b) ? (a) : (b))
 
-#define MED_HAVE_MPI
-
 #include <med.h>
 #define MESGERR 1
 #include "med_utils.h"
@@ -90,7 +88,7 @@ int main (int argc, char **argv)
   MPI_Comm comm = MPI_COMM_WORLD;
   MPI_Info info = MPI_INFO_NULL;
 
-  med_int    _nbofentitiesfiltered=0;
+  med_int    _nentitiesfiltered=0;
   med_int    *_filterarray=NULL;
 
 
@@ -99,8 +97,9 @@ int main (int argc, char **argv)
   MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
 
 
-  med_err generateFieldFile( const med_size nbofentities, const med_size nbofvaluesperentity, const med_size nbofconstituentpervalue,
-			     const med_switch_mode constituentmode,void (*getBlockOfEntities)(), const med_int nbblocksperproc, void (*generateDatas)(),
+  med_err generateFieldFile( const med_size nentities, const med_size nvaluesperentity, const med_size nconstituentpervalue,
+			     const med_switch_mode constituentmode,GetBlocksOfEntitiesType getBlockOfEntities, const med_int nbblocksperproc,
+			     GenerateDataType generateDatas,
 			     const med_storage_mode storagemode, const med_size profilearraysize,  const char * const fieldnameprefix ) {
 
 /*     static int   _fileno=0; */
@@ -118,20 +117,20 @@ int main (int argc, char **argv)
     med_size     _blocksize=0,_lastblocksize=0,_count=0,_stride=0,_start=0,_index=0;
     med_float    *_arrayvalues;
     med_filter   filter = MED_FILTER_INIT;
-    med_size     _nbofusedentities        = nbofentities;
+    med_size     _nusedentities        = nentities;
     med_size     _io_count                = nbblocksperproc;
     med_idt      _fidseq;
 
     /*TODO : EXTERNALISER CES DEFINITIONS ET GENERALISER LE PRINCIPE */
-    char         *_MED_MODE_SWITCH_MSG[3]={"MED_UNDEF_INTERLACE","MED_FULL_INTERLACE", "MED_NO_INTERLACE"};
+    char         *_MED_MODE_SWITCH_MSG[3]={"MED_FULL_INTERLACE", "MED_NO_INTERLACE","MED_UNDEF_INTERLACE",};
     char         *_MED_STORAGE_MODE_MSG[3]={"MED_NO_PFLMODE","MED_GLOBAL_PFLMODE", "MED_COMPACT_PFLMODE"};
 
     med_geometry_type     _geotype       = MED_TRIA6;
     med_int               _geodim        = _geotype/100;
-    med_int               _geonbofnodes  = _geotype%100;
+    med_int               _geonnodes  = _geotype%100;
     char       _ipointname[MED_NAME_SIZE+1];
     med_float* _ipointrefcoo = 0;
-    med_int    _ipoint       = nbofvaluesperentity;
+    med_int    _ipoint       = nvaluesperentity;
     med_float* _ipointcoo    = 0;
     med_float* _ipointwg     = 0;
 
@@ -151,13 +150,13 @@ int main (int argc, char **argv)
       goto ERROR;
     };
 
-    componentname = (char*) malloc((nbofconstituentpervalue*MED_SNAME_SIZE+1)*sizeof(char));
-    componentunit = (char*) malloc((nbofconstituentpervalue*MED_SNAME_SIZE+1)*sizeof(char));
+    componentname = (char*) malloc((nconstituentpervalue*MED_SNAME_SIZE+1)*sizeof(char));
+    componentunit = (char*) malloc((nconstituentpervalue*MED_SNAME_SIZE+1)*sizeof(char));
     /*TODO : Compléter le nom */
     strcpy(componentname,"");
     strcpy(componentunit,"");
     strcpy(_fieldname,fieldnameprefix);
-    if ( MEDfieldCr(_fid,_fieldname,MED_FLOAT64,nbofconstituentpervalue,componentname,componentunit,"s",_meshname ) < 0) {
+    if ( MEDfieldCr(_fid,_fieldname,MED_FLOAT64,nconstituentpervalue,componentname,componentunit,"s",_meshname ) < 0) {
       MED_ERR_(_ret,MED_ERR_CREATE,MED_ERR_FIELD,_fieldname);
       goto ERROR;
     };
@@ -172,7 +171,7 @@ int main (int argc, char **argv)
       strcat(_ipointname,"_loc");
 
       /*Attention ancienne spec*/
-      _ipointrefcoo = (med_float *) calloc(_geodim*_geonbofnodes,sizeof(med_float));
+      _ipointrefcoo = (med_float *) calloc(_geodim*_geonnodes,sizeof(med_float));
       _ipointcoo    = (med_float *) calloc(_ipoint*_geodim,sizeof(med_float));
       _ipointwg     = (med_float *) calloc(_ipoint,sizeof(med_float));
 
@@ -202,20 +201,20 @@ int main (int argc, char **argv)
 	MED_ERR_(_ret,MED_ERR_CREATE,MED_ERR_PROFILE,_profilename);
 	goto ERROR;
       };
-      _nbofusedentities = profilearraysize;
+      _nusedentities = profilearraysize;
     } else {
       strcpy(_profilename,MED_NO_PROFILE);
     }
 
 
     MESSAGE("Generating partition...");
-    getBlockOfEntities ( mpi_rank , mpi_size, _nbofusedentities,
+    getBlockOfEntities ( mpi_rank , mpi_size, _nusedentities,
 			 &_start, &_stride, &_io_count, &_blocksize,
 			 &_lastusedrank, &_lastblocksize);
 
     _count=_io_count;
     MESSAGE("Generating filter...");
-    if ( MEDfilterBlockOfEntityCr(_fid, nbofentities, nbofvaluesperentity, nbofconstituentpervalue,
+    if ( MEDfilterBlockOfEntityCr(_fid, nentities, nvaluesperentity, nconstituentpervalue,
 				  MED_ALL_CONSTITUENT, constituentmode, storagemode, _profilename,
 				  _start,_stride,_count,_blocksize,_lastblocksize,  &filter) < 0 ) {
 	MED_ERR_(_ret,MED_ERR_CREATE,MED_ERR_FILTER,"");
@@ -226,7 +225,7 @@ int main (int argc, char **argv)
     generateDatas(mpi_rank, _lastusedrank, sizeof(med_float),
 		  storagemode, profilearraysize, _profilearray,
 		  _start, _stride, _count, _blocksize, _lastblocksize,
-		  nbofentities, nbofvaluesperentity, nbofconstituentpervalue,
+		  nentities, nvaluesperentity, nconstituentpervalue,
 		  &_arrayvalues );
 
     MESSAGE("Writing field...");
@@ -238,7 +237,7 @@ int main (int argc, char **argv)
     }
 
     /* Test de lecture du même fichier avec filtre simple par un seul processeur */
-    /*TODO : Créer MEDflush */
+    /* TODO : Créer MEDflush */
     H5Fflush(_fid, H5F_SCOPE_GLOBAL );
 
     /*Le flush suffit pas besoin de synchroniser les processus : MPI_Barrier(MPI_COMM_WORLD); */
@@ -246,7 +245,7 @@ int main (int argc, char **argv)
       MESSAGE("Reading field...");
 
 
-      med_int    _nbofentitiesarrayvalues=0;
+      med_int    _nentitiesarrayvalues=0;
       med_float  *_filteredarrayvalues=NULL;
       med_filter filter2=MED_FILTER_INIT;
       int        _ind=0;
@@ -265,15 +264,15 @@ int main (int argc, char **argv)
       /*Génère un filtre de selection simple s'il n'a pas déjà été généré lors d'un précédent appel */
       /*TODO : Déplacer cette appel dans le main après avoir externaliser la génération du profile */
       if (!_filterarray)
-	if ( generateFilterArray(  nbofentities,  nbofvaluesperentity, nbofconstituentpervalue,
+	if ( generateFilterArray(  nentities,  nvaluesperentity, nconstituentpervalue,
 				   profilearraysize, _profilearray,
-				   &_nbofentitiesfiltered, &_filterarray ) < 0 ) {
+				   &_nentitiesfiltered, &_filterarray ) < 0 ) {
 	  goto ERROR;
 	}
 
-      ISCRUTE(_nbofentitiesfiltered);
+      ISCRUTE(_nentitiesfiltered);
       /*Stocke le filtre utilisé dans le fichier .ascii*/
-      for (_i=0; _i < _nbofentitiesfiltered; ++_i ) {
+      for (_i=0; _i < _nentitiesfiltered; ++_i ) {
 /* 	ISCRUTE(_filterarray[_i]); */
 	fprintf(_asciifile,"%d ",_filterarray[_i]) ;
       }
@@ -282,24 +281,26 @@ int main (int argc, char **argv)
 
       /*Pas de profile possible (profilearraysize == 0) en MED_GLOBAL_PFLMODE sur un fichier géré en parallel */
       if ( profilearraysize ) {
-	_nbofentitiesarrayvalues = profilearraysize;
+	_nentitiesarrayvalues = profilearraysize;
       } else {
-	_nbofentitiesarrayvalues = nbofentities;
+	_nentitiesarrayvalues = nentities;
       }
 
-      _filteredarrayvalues = (med_float*) malloc(_nbofentitiesarrayvalues*
-						 nbofvaluesperentity*
-						 nbofconstituentpervalue*sizeof(med_float));
+      /*Attention allocation mémoire potentiellement grosse car réalisée uniquement par le processus 0
+       qui rassemble les données.*/
+      _filteredarrayvalues = (med_float*) malloc(_nentitiesarrayvalues*
+						 nvaluesperentity*
+						 nconstituentpervalue*sizeof(med_float));
 
       /* Permet de vérifier une erreur d'indiçage après la lecture */
-      for (_i=0;_i<_nbofentitiesarrayvalues*nbofvaluesperentity*nbofconstituentpervalue; ++_i)
+      for (_i=0;_i<_nentitiesarrayvalues*nvaluesperentity*nconstituentpervalue; ++_i)
 	_filteredarrayvalues[_i]=-_i;
 
 
       /*Création d'un filtre de sélection simple, pour une lecture séquentielle par le processys 0*/
-      if ( MEDfilterEntityCr(_fidseq, nbofentities, nbofvaluesperentity, nbofconstituentpervalue,
+      if ( MEDfilterEntityCr(_fidseq, nentities, nvaluesperentity, nconstituentpervalue,
 			     MED_ALL_CONSTITUENT, constituentmode, storagemode, _profilename,
-			     _nbofentitiesfiltered,_filterarray, &filter2) < 0 ) {
+			     _nentitiesfiltered,_filterarray, &filter2) < 0 ) {
 	MED_ERR_(_ret,MED_ERR_CREATE,MED_ERR_FILTER,"");
 	goto ERROR;
       }
@@ -316,19 +317,19 @@ int main (int argc, char **argv)
       if ( storagemode == MED_GLOBAL_PFLMODE ) {
 	switch (constituentmode) {
 	case MED_FULL_INTERLACE:
-	  for (_i=0; _i < _nbofentitiesfiltered; ++_i)
-	    for (_j=0; _j < nbofvaluesperentity; ++_j)
-	      for (_k=0; _k < nbofconstituentpervalue; ++_k) {
-		_ind = (_filterarray[_i]-1)*nbofvaluesperentity*nbofconstituentpervalue+ _j*nbofconstituentpervalue+_k;
+	  for (_i=0; _i < _nentitiesfiltered; ++_i)
+	    for (_j=0; _j < nvaluesperentity; ++_j)
+	      for (_k=0; _k < nconstituentpervalue; ++_k) {
+		_ind = (_filterarray[_i]-1)*nvaluesperentity*nconstituentpervalue+ _j*nconstituentpervalue+_k;
 /* 		fprintf(stdout,"%s%3d%s = %f\n","_filteredarrayvaluesFULLGLB[",_ind,"]",_filteredarrayvalues[_ind]) ; */
 		fprintf(_asciifile,"%f\n",_filteredarrayvalues[_ind]) ;
 	      }
 	  break;
 	case MED_NO_INTERLACE:
-	  for (_j=0; _j < _nbofentitiesfiltered; ++_j)
-	    for (_k=0; _k < nbofvaluesperentity; ++_k)
-	      for (_i=0; _i < nbofconstituentpervalue; ++_i) {
-		_ind =_i*nbofentities*nbofvaluesperentity+ (_filterarray[_j]-1)*nbofvaluesperentity +_k;
+	  for (_j=0; _j < _nentitiesfiltered; ++_j)
+	    for (_k=0; _k < nvaluesperentity; ++_k)
+	      for (_i=0; _i < nconstituentpervalue; ++_i) {
+		_ind =_i*nentities*nvaluesperentity+ (_filterarray[_j]-1)*nvaluesperentity +_k;
 /* 		fprintf(stdout,"%s%3d%s = %f\n","_filteredarrayvaluesNOGLB[",_ind,"]",_filteredarrayvalues[_ind]); */
 		fprintf(_asciifile,"%f\n",_filteredarrayvalues[_ind]);
 	      }
@@ -337,19 +338,19 @@ int main (int argc, char **argv)
       }  else
 	switch (constituentmode) {
 	case MED_FULL_INTERLACE:
-	  for (_i=0; _i < _nbofentitiesfiltered; ++_i )
-	    for (_j=0; _j < nbofvaluesperentity; ++_j)
-	      for (_k=0; _k < nbofconstituentpervalue; ++_k) {
-		_ind = (_filterarray[_i]-1)*nbofvaluesperentity*nbofconstituentpervalue+_j*nbofconstituentpervalue+_k;
+	  for (_i=0; _i < _nentitiesfiltered; ++_i )
+	    for (_j=0; _j < nvaluesperentity; ++_j)
+	      for (_k=0; _k < nconstituentpervalue; ++_k) {
+		_ind = (_filterarray[_i]-1)*nvaluesperentity*nconstituentpervalue+_j*nconstituentpervalue+_k;
 /* 		fprintf(stdout,"%s%3d%s = %f\n","_filteredarrayvaluesFULLCP[",_ind,"]",_filteredarrayvalues[_ind]) ; */
 		fprintf(_asciifile,"%f\n",_filteredarrayvalues[_ind]) ;
 	  }
 	  break;
 	case MED_NO_INTERLACE:
-	  for (_j=0; _j < _nbofentitiesfiltered; ++_j)
-	    for (_k=0; _k < nbofvaluesperentity; ++_k)
-	      for (_i=0; _i < nbofconstituentpervalue; ++_i) {
-		_ind =_i*_nbofentitiesarrayvalues*nbofvaluesperentity+ (_filterarray[_j]-1)*nbofvaluesperentity +_k;
+	  for (_j=0; _j < _nentitiesfiltered; ++_j)
+	    for (_k=0; _k < nvaluesperentity; ++_k)
+	      for (_i=0; _i < nconstituentpervalue; ++_i) {
+		_ind =_i*_nentitiesarrayvalues*nvaluesperentity+ (_filterarray[_j]-1)*nvaluesperentity +_k;
 /* 		fprintf(stdout,"%s%3d%s = %f\n","_filteredarrayvaluesNOCP[",_ind,"]",_filteredarrayvalues[_ind]); */
 		fprintf(_asciifile,"%f\n",_filteredarrayvalues[_ind]);
 	      }
@@ -366,7 +367,7 @@ int main (int argc, char **argv)
 	goto ERROR;
       }
 
-  }
+    } /*fin if (mpi_rank == 0) */
 
   if ( MEDfilterClose(&filter) < 0 ) {
     MED_ERR_(_ret,MED_ERR_CLOSE,MED_ERR_FILTER,"");
@@ -397,9 +398,9 @@ int main (int argc, char **argv)
 
   /* MAIN */
   med_size            _nbblocksperproc    = 0;
-  int           _nbofentities             = 0;
-  int           _nbofvaluesperentity      = 0;
-  int           _nbofconstituentpervalue  = 0;
+  int           _nentities             = 0;
+  int           _nvaluesperentity      = 0;
+  int           _nconstituentpervalue  = 0;
 
   if (mpi_rank == 0 ) {
 
@@ -409,37 +410,42 @@ int main (int argc, char **argv)
 
     srandom((*_tm).tm_sec * (*_tm).tm_min );
     _nbblocksperproc         = 1 + (int) (mpi_size * (random() / (RAND_MAX + 1.0)));
-    _nbofentities            = 1 + (int) (1000.0 * (random() / (RAND_MAX + 1.0)));
-    _nbofvaluesperentity     = 1 + (int) (11.0 * (random() / (RAND_MAX + 1.0)));
-    _nbofconstituentpervalue = 1 + (int) (7.0 * (random() / (RAND_MAX + 1.0)));
+    _nentities            = 1 + (int) (1000.0 * (random() / (RAND_MAX + 1.0)));
+    _nvaluesperentity     = 1 + (int) (11.0 * (random() / (RAND_MAX + 1.0)));
+    _nconstituentpervalue = 1 + (int) (7.0 * (random() / (RAND_MAX + 1.0)));
 /*     _nbblocksperproc         = 1 + (int) (mpi_size * (random() / (RAND_MAX + 1.0))); */
-/*     _nbofentities            = 1 + (int) (5.0 * (random() / (RAND_MAX + 1.0))); */
-/*     _nbofvaluesperentity     = 1 + (int) (3.0 * (random() / (RAND_MAX + 1.0))); */
-/*     _nbofconstituentpervalue = 1 + (int) (3.0 * (random() / (RAND_MAX + 1.0))); */
+/*     _nentities            = 1 + (int) (5.0 * (random() / (RAND_MAX + 1.0))); */
+/*     _nvaluesperentity     = 1 + (int) (3.0 * (random() / (RAND_MAX + 1.0))); */
+/*     _nconstituentpervalue = 1 + (int) (3.0 * (random() / (RAND_MAX + 1.0))); */
 /*     _nbblocksperproc         = 2; */
-/*     _nbofentities            = 4; */
-/*     _nbofvaluesperentity     = 1; */
-/*     _nbofconstituentpervalue = 1; */
+/*     _nentities            = 4; */
+/*     _nvaluesperentity     = 1; */
+/*     _nconstituentpervalue = 1; */
 
   }
 
-  assert(sizeof(med_size) == (sizeof(MPI_LONG)));
+  if ( (sizeof(med_size)%(sizeof(MPI_LONG)))==0 ) {
 
-  MPI_Bcast(&_nbblocksperproc         , 1, MPI_LONG, 0, MPI_COMM_WORLD);
-  MPI_Bcast(&_nbofentities            , 1, MPI_LONG, 0, MPI_COMM_WORLD);
-  MPI_Bcast(&_nbofvaluesperentity     , 1, MPI_LONG, 0, MPI_COMM_WORLD);
-  MPI_Bcast(&_nbofconstituentpervalue , 1, MPI_LONG, 0, MPI_COMM_WORLD);
+    MPI_Bcast(&_nbblocksperproc         , sizeof(med_size)/sizeof(MPI_LONG), MPI_LONG, 0, MPI_COMM_WORLD);
+    MPI_Bcast(&_nentities            , sizeof(med_size)/sizeof(MPI_LONG), MPI_LONG, 0, MPI_COMM_WORLD);
+    MPI_Bcast(&_nvaluesperentity     , sizeof(med_size)/sizeof(MPI_LONG), MPI_LONG, 0, MPI_COMM_WORLD);
+    MPI_Bcast(&_nconstituentpervalue , sizeof(med_size)/sizeof(MPI_LONG), MPI_LONG, 0, MPI_COMM_WORLD);
+  } else {
+    assert(sizeof(med_size) == (sizeof(MPI_LONG)));
+  }
 
-  char                _fieldnameprefix[255] = "";
+  char                _fieldnameprefix[256] = "";
 
-  sprintf(_fieldnameprefix,"NENT-%03d_NVAL-%03d_NCST-%03d_NBL-%03llu",_nbofentities,_nbofvaluesperentity,
-	  _nbofconstituentpervalue,_nbblocksperproc);
+  sprintf(_fieldnameprefix,"NENT-%03d_NVAL-%03d_NCST-%03d_NBL-%03llu",_nentities,_nvaluesperentity,
+	  _nconstituentpervalue,_nbblocksperproc);
 
-  void (*generateDatas)() = 0;
+  GenerateDataType generateDatas = 0;
   med_switch_mode  _switchmode  = MED_UNDEF_INTERLACE;
   med_storage_mode _storagemode = MED_UNDEF_PFLMODE;
+  /*Pour que les 4 fichiers générés soient identiques, on désactive l'utilisation des profils
+    qui n'est pas utilisable en mode GLOBAL et // */
   med_int          _profilearraysize=0;
-/*   med_int       _profilearraysize=_nbofentities/2; */
+  /*   med_int       _profilearraysize=_nentities/2; */
 
   for (_switchmode = MED_FULL_INTERLACE ; _switchmode <= MED_NO_INTERLACE; ++_switchmode) {
 
@@ -450,7 +456,7 @@ int main (int argc, char **argv)
 
       if ( (_storagemode == MED_GLOBAL_PFLMODE ) && (_profilearraysize) ) _profilearraysize=0;
 
-      if ( generateFieldFile( _nbofentities,  _nbofvaluesperentity, _nbofconstituentpervalue,
+      if ( generateFieldFile( _nentities,  _nvaluesperentity, _nconstituentpervalue,
 			      _switchmode, getCyclicBlocksOfEntities, _nbblocksperproc, generateDatas,
 			      _storagemode, _profilearraysize,  _fieldnameprefix ) < 0 ) {
 	MED_ERR_(_ret,MED_ERR_WRITE,MED_ERR_FIELD,_fieldnameprefix);
@@ -467,12 +473,13 @@ int main (int argc, char **argv)
 
   if (_filterarray) free(_filterarray);
 
+  /*pour arch. BLueGene : Sync entre GPFS et LSF : sleep(360) */
+
   /* MPI_Finalize must be called AFTER MEDclose which may use MPI calls */
   MPI_Finalize();
 
-  return -1;
   /* Catcher l'erreur en retour mpirun  et .sh*/
-  /*   return _ret; */
+  return _ret;
 }
 
 
