@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -22,8 +22,8 @@
 #include <med.h>
 #define MESGERR 1
 
-med_err generateFilterArray( const med_size nbofentities, const med_size nbofvaluesperentity, const med_size nbofconstituentpervalue,
+med_err generateFilterArray( const med_size nentities, const med_size nvaluesperentity, const med_size nconstituentpervalue,
 			     const med_size profilearraysize, const med_int * const profilearray,
-			     med_int  * const nbofentitiesfiltered, med_int **filterarray );
+			     med_int  * const nentitiesfiltered, med_int **filterarray );
 
 #endif
