@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -25,14 +25,17 @@
 
 #include "getBlocksOfEntitiesPartition.h"
 
+typedef void (*GetBlocksOfEntitiesType)(const int myrank, const int nproc, const int nentities,
+				   med_size * const start, med_size * const stride, med_size * const count, med_size * blocksize,
+				   int * const lastusedrank, med_size * const lastblocksize );
 
-void getContinuousBlocksOfEntities(const int myrank, const int nproc, const int nbofentities,
+void getContinuousBlocksOfEntities(const int myrank, const int nproc, const int nentities,
+				   med_size * const start, med_size * const stride, med_size * const count, med_size * blocksize,
+				   int * const lastusedrank, med_size * const lastblocksize );
+void getCyclicBlocksOfEntities(const int myrank, const int nproc, const int nentities,
 				   med_size * const start, med_size * const stride, med_size * const count, med_size * blocksize,
 				   int * const lastusedrank, med_size * const lastblocksize );
 
-void getCyclicBlocksOfEntities(const int myrank, const int nproc, const int nbofentities,
-			       med_size * const start, med_size * const stride,  med_size * const io_count, med_size * blocksize,
-			       int * const lastusedrank, med_size * const lastblocksize );
 #endif
 
 
