@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -471,11 +471,11 @@ void lecture_joint_maillage(med_idt fid,const char * const nommaa,med_int njnt)
 		NULL);
 	if (nent > 0) {
 	  if (typ_ent_local == MED_NODE) strcpy(nom_geo_ent_local,"MED_NOEUD");
-	  else  ret = _MEDgetGeometryTypeName(nom_geo_ent_local,typ_geo_local);
-	  EXIT_IF(ret < 0,"Erreur à l'appel de _MEDgetGeometryTypeName", NULL);
+	  else  ret = _MEDgetExternalGeometryTypeName(nom_geo_ent_local,typ_geo_local);
+	  EXIT_IF(ret < 0,"Erreur à l'appel de _MEDgetExternalGeometryTypeName", NULL);
 	  if (typ_ent_distant == MED_NODE) strcpy(nom_geo_ent_distant,"MED_NOEUD");
-	  else ret = _MEDgetGeometryTypeName(nom_geo_ent_distant,typ_geo_distant);
-	  EXIT_IF(ret < 0,"Erreur à l'appel de _MEDgetGeometryTypeName", NULL);
+	  else ret = _MEDgetExternalGeometryTypeName(nom_geo_ent_distant,typ_geo_distant);
+	  EXIT_IF(ret < 0,"Erreur à l'appel de _MEDgetExternalGeometryTypeName", NULL);
 	  fprintf(stdout,"\n\t\t- nb de couples d'entites en regard (local,distant)=(%s,%s) : "IFORMAT" \n",
 		  nom_geo_ent_local,nom_geo_ent_distant,  nent);
 	  /*TODO : Supprimer la ligne suivante*/
@@ -1947,7 +1947,7 @@ med_err getFieldsOn(const med_idt fid,
 
   int i,j,k,l,m,n,nb_geo=0;
   med_int nbpdtnor=0,pflsize,*pflval,ngauss=0,ngauss_maa_ass=0,ngroup,*vale=NULL,nval;
-  med_int numdt=0,numo=0,_nbofprofile;
+  med_int numdt=0,numo=0,_nprofile;
   med_int meshnumdt=0,meshnumit=0;
   med_float *valr=NULL,dt=0.0;
   med_err ret=0;
@@ -2005,7 +2005,7 @@ med_err getFieldsOn(const med_idt fid,
 
       for (i=0;i< nmesh;++i) {
 
-	if ( (_nbofprofile = MEDfield23nProfile(fid,nomcha,numdt,numo,entite,type_geo[k],i+1,meshname,
+	if ( (_nprofile = MEDfield23nProfile(fid,nomcha,numdt,numo,entite,type_geo[k],i+1,meshname,
 						pflname,locname   ) ) < 0 ) {
 	  MESSAGE("Erreur a la demande du nombre de profils referencés par le champ : ");
 	  SSCRUTE(nomcha); ISCRUTE(numdt); ISCRUTE(numo);SSCRUTE(meshname);
@@ -2014,7 +2014,7 @@ med_err getFieldsOn(const med_idt fid,
 	  ret = -1; continue;
 	};
 
-	for (l=0;l<_nbofprofile;l++) {
+	for (l=0;l<_nprofile;l++) {
 
 	  if ( (nval = MEDfield23nValueWithProfile(fid, nomcha, numdt, numo,  entite, type_geo[k],meshname,
 						   l+1,  USER_MODE, pflname,&pflsize,
@@ -2027,7 +2027,7 @@ med_err getFieldsOn(const med_idt fid,
 	  };
 	  if (!strcmp(meshname,maa_ass) ) ngauss_maa_ass = ngauss;
 
-	  if (_nbofprofile > 1 )
+	  if (_nprofile > 1 )
 	    printf("\n  +Pas de Temps n."IFORMAT" (%f) [%s], n. d'ordre "IFORMAT", avec "IFORMAT" valeur(s) par entité.\n",numdt,dt,dtunit,numo,ngauss);
 	  else {
 	    printf("\n  +Pas de Temps n."IFORMAT" (%f) [%s], n. d'ordre "IFORMAT", avec "IFORMAT" pts de gauss sur le maillage par defaut.\n",numdt,dt,dtunit,numo,ngauss_maa_ass);
@@ -2036,7 +2036,7 @@ med_err getFieldsOn(const med_idt fid,
 
 	  if ( (!strcmp(meshname,maillage)) && (meshnumdt == mnumdt) && (meshnumit == mnumit) ) {
 
-	    if (_nbofprofile > 1 ) {
+	    if (_nprofile > 1 ) {
 	      printf("\t- Il y a "IFORMAT" entités qui portent des valeurs en mode %i. Chaque entite %s\
  de type geometrique %s associes au profile |%s| a "IFORMAT" valeurs associées \n",
 		     nval,USER_MODE,AFF_ENT[(int)entite],AFF[k],pflname,ngauss);
@@ -2104,7 +2104,7 @@ med_err getFieldsOn(const med_idt fid,
 	      }
 	    }
 
-	    if ( strlen(locname) && (_nbofprofile > 1) )
+	    if ( strlen(locname) && (_nprofile > 1) )
 	      printf("\t- Modèle de localisation des points de Gauss de nom |%s|\n",locname);
 
 	    if (entite == MED_NODE_ELEMENT)
@@ -2228,7 +2228,7 @@ void lecture_resultats(const med_idt fid,
   char     nommaa[MED_NAME_SIZE+1]="";
   med_bool localmaa = MED_FALSE;
   char     dtunit[MED_SNAME_SIZE+1]="";
-  med_int  nbofcstp=0;
+  med_int  ncstp=0;
 
   med_int locsdim=0;
   char    geointerpname       [MED_NAME_SIZE+1]="";
@@ -2275,7 +2275,7 @@ void lecture_resultats(const med_idt fid,
     EXIT_IF(unit == NULL,NULL,NULL);
 
     if ( MEDfieldInfo(fid, i+1, nomcha, nommaa, &localmaa,
-		     &typcha, comp, unit, dtunit, &nbofcstp) < 0 ) {
+		     &typcha, comp, unit, dtunit, &ncstp) < 0 ) {
       MESSAGE("Erreur à la demande d'information sur les champs : ");
       ret = -1; continue;
     }
@@ -2286,26 +2286,26 @@ void lecture_resultats(const med_idt fid,
     /* TODO: réactiver */
 /*     if (strlen(dtunit)) */
 /*       printf("Unité des dates : |%s|\n",dtunit); */
-/*     if ( nbofcstp > 1 ) */
-/*       printf("Nombre d'étapes de calcul : |"IFORMAT"| \n",nbofcstp); */
+/*     if ( ncstp > 1 ) */
+/*       printf("Nombre d'étapes de calcul : |"IFORMAT"| \n",ncstp); */
 
     free(comp);
     free(unit);
     
     /* champs aux noeuds */
-    lret = getFieldsOn(fid, maillage, mnumdt, mnumit, nomcha, dtunit, typcha, ncomp, MED_NODE,mode_coo, nbofcstp);
+    lret = getFieldsOn(fid, maillage, mnumdt, mnumit, nomcha, dtunit, typcha, ncomp, MED_NODE,mode_coo, ncstp);
     
     /* champs sur les elements et aux points de Gauss */
-    if (lret == 0) lret = getFieldsOn(fid, maillage, mnumdt, mnumit , nomcha, dtunit, typcha, ncomp, MED_CELL,mode_coo, nbofcstp);
+    if (lret == 0) lret = getFieldsOn(fid, maillage, mnumdt, mnumit , nomcha, dtunit, typcha, ncomp, MED_CELL,mode_coo, ncstp);
     else { MESSAGE("Erreur à la lecture des champs aux noeuds "); ret = -1; continue;}
    
-    if (lret == 0) lret = getFieldsOn(fid, maillage, mnumdt, mnumit , nomcha, dtunit, typcha, ncomp, MED_DESCENDING_FACE,mode_coo, nbofcstp);
+    if (lret == 0) lret = getFieldsOn(fid, maillage, mnumdt, mnumit , nomcha, dtunit, typcha, ncomp, MED_DESCENDING_FACE,mode_coo, ncstp);
     else { MESSAGE("Erreur à la lecture des champs aux mailles "); ret = -1; continue;}
    
-    if (lret == 0) lret = getFieldsOn(fid, maillage, mnumdt, mnumit , nomcha, dtunit, typcha, ncomp, MED_DESCENDING_EDGE,mode_coo, nbofcstp);
+    if (lret == 0) lret = getFieldsOn(fid, maillage, mnumdt, mnumit , nomcha, dtunit, typcha, ncomp, MED_DESCENDING_EDGE,mode_coo, ncstp);
     else {MESSAGE("Erreur à la lecture des champs aux faces "); ret = -1; continue;}
     
-    if (lret == 0) lret = getFieldsOn(fid, maillage, mnumdt, mnumit , nomcha, dtunit, typcha, ncomp, MED_NODE_ELEMENT,mode_coo, nbofcstp);
+    if (lret == 0) lret = getFieldsOn(fid, maillage, mnumdt, mnumit , nomcha, dtunit, typcha, ncomp, MED_NODE_ELEMENT,mode_coo, ncstp);
     else {MESSAGE("Erreur a la lecture des champs aux aretes "); ret = -1; continue;}
     
     if  (lret != 0) {MESSAGE("Erreur a la lecture des champs aux noeuds des mailles "); ret = -1;};
