@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -41,7 +41,7 @@ int main(int argc, char *argv[]) {
   ret=MEDlibraryNumVersion(&majeur, &mineur, &release);
   EXIT_IF( ret<0 ,
 	   "Erreur d'appel de la routine MEDlibraryNumVersion.", NULL	);
-  fprintf(stdout,"- Version de MED-fichier utilisée par medconforme : %d.%d.%d \n",majeur,mineur,release); 
+  fprintf(stdout,"- Version de MED-fichier utilisée par medconforme : "IFORMAT"."IFORMAT"."IFORMAT" \n",majeur,mineur,release); 
 
   /*
    * Le fichier à lire est-il au bon format de fichier HDF ?
@@ -75,7 +75,7 @@ int main(int argc, char *argv[]) {
   ret = MEDfileNumVersionRd(fid, &majeur, &mineur, &release);
   EXIT_IF(ret < 0,"Lecture du numéro de version",NULL);
 
-  fprintf(stdout,"- Ce fichier a ete créé avec MED V%d.%d.%d \n",majeur,mineur,release);
+  fprintf(stdout,"- Ce fichier a ete créé avec MED V"IFORMAT"."IFORMAT"."IFORMAT" \n",majeur,mineur,release);
 
   ret = MEDfileClose(fid);
   EXIT_IF(ret < 0,"Fermeture du fichier",argv[1]);
