@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -16,26 +16,24 @@
  */
 
 
-#ifndef MESGERR
-#define MESGERR 1
-#endif
-
-#ifdef __cplusplus
-extern "C" {
-#endif
 
+#include "med_config.h"
+#include "med_outils.h"
 #include <string.h>
 
-#ifdef __cplusplus
-}
-#endif
+/* #ifdef __cplusplus */
+/* } */
+/* #endif */
 
-#include "med_hdfi231.h"
-#include "MAJ_231_232.h"
+#include "MAJ_236_300.h"
 
-int MAJ_231_232_chaine(char * nomi, char * nomf) {
+/*Supression des blancs terminaux 
+  Si ils existent --> ret 1
+  Si ils n'existent pas --> ret 0
+*/
+int MAJ_236_300_chaine(char * nomi, char * nomf) {
   int i,n;
-  
+
   n=strlen(nomi);
   i=n-1;
   if ( nomi[i] == ' ') {
