@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2009  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -18,8 +18,8 @@
 #ifndef MEDIMPORT_WIN_DLL_H
 #define MEDIMPORT_WIN_DLL_H
 
-#ifdef WIN32
-# ifdef MEDIMPORT_DLL_EXPORTS
+#ifdef PPRO_NT
+# ifdef medimport_EXPORTS
 #  define MEDIMPORT_EXPORT __declspec( dllexport )
 # else
 #  define MEDIMPORT_EXPORT __declspec( dllimport )
