@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2012  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -21,10 +21,6 @@
    - Si -DWITH_EXCEPTION EXITIF renvoie une exception MEDerreur
    - Sinon exécute l'instruction return */
 
-#ifndef MESGERR
-#define MESGERR 1
-#endif
-
 
 #ifdef HAVE_STDBOOL_H
 # include <stdbool.h>
@@ -217,7 +213,7 @@ int MEDimport(char * filein, char *  fileout) {
 /*   La mise à jour MAJ_version(fid); doit être différée pour que les majs des fichiers anciens
  fonctionnent correctement*/
 /*   MAJ_version(fid); */
-  MAJ_version_num(fid,2,3,6);
+  MAJ_write_version_num(fid,2,3,6);
   fprintf(stdout,"  Numéro de version : ... OK ... \n");
 
   if (MAJ_21_22) {
@@ -282,6 +278,8 @@ int MEDimport(char * filein, char *  fileout) {
 
   }
 
+  MAJ_write_version_num(fid,MED_NUM_MAJEUR,MED_NUM_MINEUR,MED_NUM_RELEASE);
+
   /* Fermeture du fichier */
   ret = MEDfileClose(fid);
   EXIT_IF(ret < 0,"Fermeture du fichier",_fileout);
